(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    366415,       7624]
NotebookOptionsPosition[    349079,       7348]
NotebookOutlinePosition[    349475,       7364]
CellTagsIndexPosition[    349432,       7361]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Jig Body Shape", "Title",
 CellChangeTimes->{{3.855643320969562*^9, 
  3.8556433323299437`*^9}},ExpressionUUID->"9956dd7b-78bc-4fa9-bd3f-\
f48c57d3d15b"],

Cell["\<\
Notebook by Bruce Torrence, to accompany the Bridges 2022 paper \
\[OpenCurlyDoubleQuote]Drill Jigs for Wooden Ball-and-Stick Models.\
\[CloseCurlyDoubleQuote] 
You can find this paper in the Bridges Archive: \
https://archive.bridgesmathart.org\
\>", "Text",
 CellChangeTimes->{{3.855660928277967*^9, 3.855660972684905*^9}, {
  3.861777502114592*^9, 
  3.861777544076935*^9}},ExpressionUUID->"0458f607-d3b7-418e-b84f-\
6224dae5cc8d"],

Cell[CellGroupData[{

Cell["Initialization Code", "Section",
 CellChangeTimes->{{3.855637298121481*^9, 3.855637299640686*^9}, {
  3.855640471039195*^9, 
  3.8556404750218163`*^9}},ExpressionUUID->"c7f204ba-eccb-485e-9b15-\
1e3da8ab36bb"],

Cell[TextData[{
 "This code was produced using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " version 13.0. (You should be able to get away with version 10 or later.)"
}], "Text",
 CellChangeTimes->{{3.8556566343610764`*^9, 3.8556567340324087`*^9}, {
  3.8556610514667788`*^9, 3.855661106175014*^9}, {3.8558202403681107`*^9, 
  3.855820254461063*^9}, {3.861775837335546*^9, 3.861775849663636*^9}, {
  3.8617759133101387`*^9, 
  3.8617759242622967`*^9}},ExpressionUUID->"3b1f2b7b-1af8-4646-9ae0-\
32d481c9853a"],

Cell[TextData[{
 "This code replicates the output of the ",
 StyleBox["Avis-Fukuda algorithm",
  FontSlant->"Italic"],
 " for a special case of the ",
 StyleBox["vertex enumeration problem",
  FontSlant->"Italic"],
 ". The code is not quite as efficient at A-F, but is much simpler due to the \
fact that in our setting we assume all normals have equal length and all \
points lie at the tips of the normals. This leads to a beautiful and simple \
geometric formulation."
}], "Text",
 CellChangeTimes->{{3.855820356143793*^9, 3.855820603940884*^9}, {
  3.85599046765152*^9, 
  3.855990511104642*^9}},ExpressionUUID->"549307b2-bd09-4b0e-819e-\
3546b8c493d4"],

Cell["\<\
Footnote: A 1993 Mathematica package for A-F can be found here: \
https://library.wolfram.com/infocenter/MathSource/440/
However, while I had it working in version 12 of Mathematica, I could not get \
it to work when I upgraded to 13. That led me to produce the code below.\
\>", "Text",
 CellChangeTimes->{{3.855996968465394*^9, 3.855996970105783*^9}, {
   3.8559970515066557`*^9, 3.855997191564356*^9}, 
   3.8559972283759127`*^9},ExpressionUUID->"d467f942-8fcb-4c4e-a034-\
dafe5fa97b0f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "intersectionPt", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"intersectionPt", "[", 
   RowBox[{"{", 
    RowBox[{"n1_", ",", "n2_", ",", "n3_"}], "}"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"det", "=", 
      RowBox[{"Det", "[", 
       RowBox[{"{", 
        RowBox[{"n1", ",", "n2", ",", "n3"}], "}"}], "]"}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"det", "==", "0"}], ",", 
      RowBox[{"{", "}"}], ",", 
      FractionBox[
       RowBox[{"Cross", "[", 
        RowBox[{
         RowBox[{"n2", "-", "n1"}], ",", 
         RowBox[{"n3", "-", "n1"}]}], "]"}], "det"]}], "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.855572035200273*^9, 3.855572129495438*^9}, {
   3.8555722072201223`*^9, 3.85557222331182*^9}, {3.855573970546692*^9, 
   3.855574012412142*^9}, {3.855575945556769*^9, 3.8555759698375998`*^9}, {
   3.855576047391841*^9, 3.855576095010447*^9}, {3.855576268927726*^9, 
   3.8555762769033127`*^9}, {3.855577413582922*^9, 3.855577414161171*^9}, {
   3.855635523063511*^9, 3.855635691760618*^9}, {3.855636019467537*^9, 
   3.855636055136181*^9}, {3.855821038456257*^9, 3.855821161571979*^9}, 
   3.855821707389983*^9, 3.855826475511916*^9, 3.861340391021617*^9, {
   3.861341009894449*^9, 3.86134113656859*^9}, {3.8614412019365664`*^9, 
   3.8614412046239*^9}, 3.8614412604009027`*^9, {3.861682971635764*^9, 
   3.861682979984338*^9}, {3.861683995635219*^9, 3.861683998296657*^9}, 
   3.861684331313249*^9, {3.861684381230947*^9, 3.861684384710967*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"7de1543b-eefc-42a4-b64c-703ae7209bea"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", "jigBody", "]"}], ";", 
  RowBox[{
   RowBox[{"jigBody", "[", 
    RowBox[{"generators_", ",", 
     RowBox[{"r_", ":", "1"}], ",", 
     RowBox[{"\[Delta]_", ":", "0.001"}]}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "normalizedGenerators", ",", "starFull", ",", "dMesh", ",", "triples", 
       ",", "candidates", ",", "vertices"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"normalizedGenerators", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Normalize", "[", 
          RowBox[{"N", "[", "#", "]"}], "]"}], "&"}], "/@", "generators"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"starFull", "=", 
       RowBox[{"DeleteDuplicates", "[", 
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{"normalizedGenerators", ",", 
           RowBox[{
            RowBox[{"-", "1"}], "*", "normalizedGenerators"}]}], "]"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Norm", "[", 
            RowBox[{"#1", "-", "#2"}], "]"}], "<", "\[Delta]"}], "&"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"dMesh", "=", 
       RowBox[{"RegionBoundary", "[", 
        RowBox[{"DelaunayMesh", "[", "starFull", "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"triples", "=", 
       RowBox[{
        RowBox[{"MeshCells", "[", 
         RowBox[{"dMesh", ",", "2"}], "]"}], "/.", 
        RowBox[{
         RowBox[{"Polygon", "[", "x_", "]"}], ":>", "x"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"candidates", "=", 
       RowBox[{"DeleteDuplicates", "[", 
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"intersectionPt", "[", 
              RowBox[{"starFull", "[", 
               RowBox[{"[", "#", "]"}], "]"}], "]"}], "&"}], "/@", 
            "triples"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"Length", "[", "#", "]"}], ">", "0"}], "&"}]}], "]"}], 
         ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Norm", "[", 
            RowBox[{"#1", "-", "#2"}], "]"}], "<", "\[Delta]"}], "&"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"vertices", "=", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Max", "[", 
               RowBox[{"Abs", "[", 
                RowBox[{"starFull", ".", "#"}], "]"}], "]"}], ">", "1"}], ",", 
             RowBox[{"{", "}"}], ",", "#"}], "]"}], "&"}], "/@", 
          "candidates"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Length", "[", "#", "]"}], ">", "0"}], "&"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"ConvexHullMesh", "[", 
       RowBox[{"r", "*", "vertices"}], "]"}]}]}], "\[IndentingNewLine]", 
    "]"}]}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.855635739621293*^9, 3.855636002197132*^9}, {
   3.8556361312801228`*^9, 3.8556361619399776`*^9}, {3.855636315841517*^9, 
   3.855636338498105*^9}, {3.855636481032673*^9, 3.855636539430925*^9}, {
   3.855636643236548*^9, 3.855636668484057*^9}, {3.855636730806184*^9, 
   3.8556367523981123`*^9}, 3.855636829376425*^9, {3.855636867056499*^9, 
   3.85563695574222*^9}, {3.855637076747797*^9, 3.8556371553134747`*^9}, {
   3.855637214463499*^9, 3.85563721645442*^9}, {3.855637592448699*^9, 
   3.855637618839793*^9}, {3.855637662399308*^9, 3.855637663441395*^9}, {
   3.85563784097081*^9, 3.855637845066882*^9}, {3.855637876440536*^9, 
   3.855637877912836*^9}, {3.8556379850814037`*^9, 3.855637986847991*^9}, {
   3.855638109571567*^9, 3.8556381116059504`*^9}, {3.855638177794656*^9, 
   3.855638180468104*^9}, {3.855638317885159*^9, 3.855638323643029*^9}, {
   3.855638575267571*^9, 3.855638647974778*^9}, 3.855638696637998*^9, {
   3.8556387327378387`*^9, 3.85563879427232*^9}, {3.85564995277055*^9, 
   3.855649987512528*^9}, {3.855650017875587*^9, 3.855650093838174*^9}, 
   3.855659088362956*^9, {3.855982365623708*^9, 3.855982380301714*^9}, {
   3.855997591556758*^9, 3.855997618567102*^9}, {3.855997795360725*^9, 
   3.8559977966772537`*^9}, {3.856070060255808*^9, 3.856070066704315*^9}, {
   3.856070914537979*^9, 3.8560709350179768`*^9}, {3.861440019184115*^9, 
   3.8614400496467037`*^9}, 3.861440211907296*^9, {3.861440963737862*^9, 
   3.8614409646482077`*^9}, {3.861518031305852*^9, 3.861518037581324*^9}, {
   3.861612435231517*^9, 3.86161247452069*^9}, {3.861612518137121*^9, 
   3.861612518522696*^9}, {3.8616277869926558`*^9, 3.861627801220211*^9}, {
   3.861682534240044*^9, 3.86168253731635*^9}, {3.8616829223653803`*^9, 
   3.8616829457532177`*^9}, 3.861682992266724*^9, {3.861683885404355*^9, 
   3.861683896261585*^9}, {3.861684363879693*^9, 3.8616843656878643`*^9}, {
   3.8617716384305353`*^9, 3.861771652848377*^9}, {3.861777181504805*^9, 
   3.8617771838275957`*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"e8fc1517-70ab-4b4d-8f8d-634895a8ee22"],

Cell[CellGroupData[{

Cell["Brief explanation of the code above", "Subsection",
 CellChangeTimes->{{3.8556417428539963`*^9, 3.855641751838159*^9}, {
  3.855642012185169*^9, 3.85564202739994*^9}, {3.855645927825975*^9, 
  3.855645939581326*^9}, {3.8556543733118362`*^9, 
  3.855654374213436*^9}},ExpressionUUID->"94cac2de-3900-4605-adf0-\
d8d5ae3e3ec9"],

Cell[CellGroupData[{

Cell["intersectionPt", "Subsubsection",
 CellChangeTimes->{{3.855811077683893*^9, 
  3.855811081352544*^9}},ExpressionUUID->"278c524f-b2f5-4c25-a92e-\
fb4b5144bba0"],

Cell[TextData[{
 "Given 3 vectors ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "1"], TraditionalForm]],ExpressionUUID->
  "46d19e42-15d1-4fae-bf5e-61f8e052c104"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "2"], TraditionalForm]],ExpressionUUID->
  "d7bbe22d-be2e-4d3d-883c-d9b965f6bcd2"],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "3"], TraditionalForm]],ExpressionUUID->
  "72d745e7-08a9-44a9-8309-71436bb9cab9"],
 " of uniform length ",
 Cell[BoxData[
  FormBox[
   RowBox[{"R", ">", "0"}], TraditionalForm]],ExpressionUUID->
  "f5d53e7b-db60-4469-9e71-1b08add9725d"],
 ", we think of them as vectors rooted at the origin ",
 Cell[BoxData[
  FormBox[
   StyleBox["O",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "64bfdda8-eccf-4da5-9b89-6790bb23f4b1"],
 " so their heads determine 3 points on a sphere of radius ",
 Cell[BoxData[
  FormBox["R", TraditionalForm]],ExpressionUUID->
  "6826811e-11f6-46d9-8a1d-73dd9596122f"],
 ". We wish to find the point ",
 Cell[BoxData[
  FormBox[
   StyleBox["C",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "55ca3b3c-48a4-4d68-b62e-725391bd9c3f"],
 " (if it exists) where the three tangent planes to the sphere at these \
points intersect. "
}], "Text",
 CellChangeTimes->{{3.8558110871196117`*^9, 3.855811318593267*^9}, {
   3.855811374517004*^9, 3.855811474761566*^9}, {3.8558115186614513`*^9, 
   3.855811625613267*^9}, {3.8558116791628036`*^9, 3.855811738577331*^9}, {
   3.855811928533588*^9, 3.8558119333648863`*^9}, {3.855814137674884*^9, 
   3.8558141558540287`*^9}, {3.8559827316178102`*^9, 3.855982742073432*^9}, 
   3.8559838663800507`*^9},ExpressionUUID->"173139c0-98d7-48c3-aab0-\
212cd3d3e679"],

Cell[TextData[{
 "If ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "1"], TraditionalForm]],ExpressionUUID->
  "048404b8-2d9a-4de4-92ec-81dd59e8c722"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "2"], TraditionalForm]],ExpressionUUID->
  "78c9251a-91e1-4279-8a9d-9624dc312e86"],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "3"], TraditionalForm]],ExpressionUUID->
  "2c37d6f6-685c-4c79-a4f8-6142f52bf336"],
 " are coplanar vectors, that is, if the three points on the sphere all lie \
on a great circle, then no such intersection point will exist. In this case, \
the command ",
 StyleBox["intersectionPt",
  FontWeight->"Bold"],
 " will output an empty list  {\[VeryThinSpace] }."
}], "Text",
 CellChangeTimes->{{3.8558110871196117`*^9, 3.855811318593267*^9}, {
   3.855811374517004*^9, 3.855811474761566*^9}, {3.8558115186614513`*^9, 
   3.855811625613267*^9}, {3.8558116791628036`*^9, 3.855811738577331*^9}, {
   3.855811928533588*^9, 3.8558119333648863`*^9}, {3.855814137674884*^9, 
   3.8558141558540287`*^9}, {3.8559827316178102`*^9, 3.855982742073432*^9}, 
   3.855993058342433*^9, {3.855993109411346*^9, 3.855993110771585*^9}, {
   3.85606922454051*^9, 3.8560692259224997`*^9}, {3.856069279055855*^9, 
   3.856069286727313*^9}},ExpressionUUID->"b03bcc8e-ea4c-4c7d-ac4b-\
3eeb3be4db3d"],

Cell[TextData[{
 "Suppose now that vectors  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "1"], TraditionalForm]],ExpressionUUID->
  "73606aff-233e-4bc3-952d-4a1275647ff2"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "2"], TraditionalForm]],ExpressionUUID->
  "a23c6bfd-fbf6-46f0-9830-2d4fa5658acf"],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "3"], TraditionalForm]],ExpressionUUID->
  "a91036f9-4540-4a0f-a94d-d0b72be7a8af"],
 " are ",
 StyleBox["not",
  FontSlant->"Italic"],
 " coplanar, so their heads form a non-degenerate triangle ",
 Cell[BoxData[
  FormBox[
   StyleBox["T",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "1c4adadd-dc9c-456a-abad-8c1c75ff3714"],
 " whose vertices lie on the sphere , and the plane \[ScriptCapitalP] \
containing this triangle does not contain the origin. Then there is a \
distinct plane ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[ScriptCapitalP]", "'"}], TraditionalForm]],ExpressionUUID->
  "bfb06fcd-9446-4132-acc6-14af710cf578"],
 "parallel to \[ScriptCapitalP] that ",
 StyleBox["does",
  FontSlant->"Italic"],
 " contain the origin, and all three vertices of ",
 Cell[BoxData[
  FormBox[
   StyleBox["T",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "c80be307-9edc-4b15-8578-085911b08253"],
 " lie in the same open hemisphere obtained by cutting the sphere with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[ScriptCapitalP]", "'"}], TraditionalForm]],ExpressionUUID->
  "4f472ca3-64a7-47da-8e02-0b8ff00f285d"],
 ". This guarantees the existence of a single point ",
 Cell[BoxData[
  FormBox[
   StyleBox["C",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "0129ae50-507e-48d8-bd7f-11a500f569e9"],
 " where the three tangent planes at the heads of  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "1"], TraditionalForm]],ExpressionUUID->
  "cf05e4d7-a565-457d-ab0a-9598d75cda7c"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "2"], TraditionalForm]],ExpressionUUID->
  "20275f12-0ec3-460a-870e-d360c0af37b7"],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "3"], TraditionalForm]],ExpressionUUID->
  "dca19d9f-96cd-455c-863e-a2f18dd5459d"],
 " meet. "
}], "Text",
 CellChangeTimes->{{3.855811760057687*^9, 3.855811806583414*^9}, {
   3.855811847164672*^9, 3.8558118772279377`*^9}, {3.8558119814317427`*^9, 
   3.855812060933773*^9}, {3.855812096766786*^9, 3.8558121705745077`*^9}, {
   3.855812219624844*^9, 3.855812388876577*^9}, {3.855812426835253*^9, 
   3.85581259391925*^9}, {3.8558127022611637`*^9, 3.8558128140760927`*^9}, {
   3.8558129184597282`*^9, 3.855813037414878*^9}, {3.855813098450066*^9, 
   3.855813106421566*^9}, {3.8558143126047297`*^9, 3.855814333268612*^9}, {
   3.855815297672599*^9, 3.8558152987312317`*^9}, {3.855815395718792*^9, 
   3.855815438518009*^9}, {3.855821280362604*^9, 3.855821309965612*^9}, {
   3.855982801998968*^9, 3.855982843229022*^9}, {3.855982900874241*^9, 
   3.855982913897999*^9}, {3.855982949376405*^9, 3.8559830906960278`*^9}, {
   3.85598313591084*^9, 3.8559831573531923`*^9}, {3.8559832186389112`*^9, 
   3.8559832838060083`*^9}, {3.855983336190089*^9, 3.855983337420105*^9}, {
   3.855983440971491*^9, 3.855983442051169*^9}, {3.855990620966075*^9, 
   3.85599063879071*^9}, 3.855993412845634*^9, {3.8612974405880747`*^9, 
   3.861297442466915*^9}, 3.8612975272080603`*^9, {3.8616844556586313`*^9, 
   3.861684458487226*^9}},ExpressionUUID->"4bf057ad-0581-4671-b9ca-\
3ac1d6daa0b0"],

Cell[TextData[{
 "For each ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "i"], TraditionalForm]],ExpressionUUID->
  "cc5f60fe-e7e0-48ee-8224-7ef8aee235b0"],
 ", consider another triangle:  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "\[VeryThinSpace]", 
    SubscriptBox["n", 
     StyleBox["i",
      FontWeight->"Plain"]], "\[VeryThinSpace]", "C"}], TraditionalForm]],
  FontWeight->"Bold",ExpressionUUID->"4f913b95-2e15-46a0-85bc-a7ab16c22682"],
 " . (We are thinking now of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "i"], TraditionalForm]],ExpressionUUID->
  "8a5cb596-c104-49e7-9315-abc761db362a"],
 " as the point on the sphere at the head of the vector ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "i"], TraditionalForm]],ExpressionUUID->
  "7876e63b-147c-45b4-822f-e41ae7056db7"],
 " when it is rooted at the origin.) The leg ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["n",
      FontWeight->"Bold"], "i"], 
    StyleBox["\[VeryThinSpace]",
     FontWeight->"Bold"], 
    StyleBox["C",
     FontWeight->"Bold"]}], TraditionalForm]],ExpressionUUID->
  "8f87889c-7b95-47e6-b8ff-bc993a76fc3d"],
 " is the vector ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["C",
     FontWeight->"Bold"], "-", 
    SubscriptBox[
     StyleBox["n",
      FontWeight->"Bold"], "i"]}], TraditionalForm]],ExpressionUUID->
  "15a3893d-440d-4e8b-8c23-0ee5d965e2a0"],
 ", and as this lies in the tangent plane at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "i"], TraditionalForm]],ExpressionUUID->
  "2b9ab13c-647f-44b0-90b8-1ebd128e2266"],
 " it is orthogonal to vector ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "i"], TraditionalForm]],ExpressionUUID->
  "c9d21073-f928-4445-bcc3-f20a6ca64e72"],
 ", so this is a right triangle. Since there are three such right triangles, \
and all share hypotenuse ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"O", "\[VeryThinSpace]", "C"}],
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "ca66eb27-a608-41d1-844d-73a6c6bf7685"],
 " and have a leg of common length ",
 Cell[BoxData[
  FormBox["R", TraditionalForm]],ExpressionUUID->
  "c1e44c98-c369-4904-9e62-6f8ebbc440bb"],
 ", these triangles are congruent. Indeed, the triangle ",
 Cell[BoxData[
  FormBox[
   StyleBox["T",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "59422f64-b9a9-460a-a429-5f48b2a4537f"],
 " determines a circle on the surface of the open half-sphere, and if we form \
the cone with this circle as its base and apex at the point ",
 Cell[BoxData[
  FormBox[
   StyleBox["C",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "4f757a38-8b62-40c0-a6dc-2a2aa993c7f1"],
 ", we see that the 3 tangent planes are all tangent to the conical surface \
of this cone. "
}], "Text",
 CellChangeTimes->{{3.855811760057687*^9, 3.855811806583414*^9}, {
   3.855811847164672*^9, 3.8558118772279377`*^9}, {3.8558119814317427`*^9, 
   3.855812060933773*^9}, {3.855812096766786*^9, 3.8558121705745077`*^9}, {
   3.855812219624844*^9, 3.855812388876577*^9}, {3.855812426835253*^9, 
   3.85581259391925*^9}, {3.8558127022611637`*^9, 3.8558128140760927`*^9}, {
   3.8558129184597282`*^9, 3.855813037414878*^9}, {3.855813098450066*^9, 
   3.855813106421566*^9}, {3.8558143126047297`*^9, 3.855814333268612*^9}, {
   3.855815297672599*^9, 3.8558152987312317`*^9}, {3.855815395718792*^9, 
   3.855815438518009*^9}, {3.855821280362604*^9, 3.855821309965612*^9}, {
   3.855982801998968*^9, 3.855982843229022*^9}, {3.855982900874241*^9, 
   3.855982913897999*^9}, {3.855982949376405*^9, 3.8559830906960278`*^9}, {
   3.85598313591084*^9, 3.8559831573531923`*^9}, {3.8559832186389112`*^9, 
   3.855983308119196*^9}, {3.855983493575285*^9, 3.855983496767521*^9}, {
   3.85598354947584*^9, 3.8559835523204317`*^9}, {3.855983585526258*^9, 
   3.8559835909340067`*^9}, {3.855983641838091*^9, 3.855983735400688*^9}, {
   3.8559935021354733`*^9, 3.855993548280883*^9}, {3.855993589286704*^9, 
   3.8559935957657557`*^9}, {3.855993749307096*^9, 3.855993776203771*^9}, {
   3.85599397410688*^9, 3.85599399941041*^9}, 3.8559940583577957`*^9, {
   3.8614326536288347`*^9, 
   3.861432654801899*^9}},ExpressionUUID->"5a82032e-6151-4101-b1b2-\
a426394b01c5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"c3", "=", "3.5"}], ",", "z", ",", "n1", ",", "n2", ",", "n3"}], 
    "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"z", "=", 
     FractionBox[
      SqrtBox[
       RowBox[{
        SuperscriptBox["c3", "2"], "-", "1"}]], "c3"]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"n1", "=", 
     RowBox[{"{", 
      RowBox[{"z", ",", "0", ",", 
       FractionBox["1", "c3"]}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"n2", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "z", ",", 
       FractionBox["1", "c3"]}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"n3", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], "z"}], ",", 
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          SqrtBox["3"], "2"]}], "z"}], ",", 
       FractionBox["1", "c3"]}], "}"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Row", "[", 
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Graphics3D", "[", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Opacity", "[", ".5", "]"}], ",", 
             RowBox[{"Sphere", "[", "]"}]}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Opacity", "[", ".15", "]"}], ",", 
             RowBox[{"Cone", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0", ",", 
                   FractionBox["1", "c3"]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0", ",", "c3"}], "}"}]}], "}"}], ",", 
               "z"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"PointSize", "[", ".01", "]"}], ",", 
             RowBox[{"Point", "[", 
              RowBox[{"{", 
               RowBox[{"n1", ",", "n2", ",", "n3", ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0", ",", "c3"}], "}"}]}], "}"}], "]"}]}], 
            "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Opacity", "[", ".4", "]"}], ",", 
             RowBox[{"Triangle", "[", 
              RowBox[{"{", 
               RowBox[{"n1", ",", "n2", ",", "n3"}], "}"}], "]"}]}], "}"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Dashed", ",", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0", ",", "c3"}], "}"}]}], "}"}], "]"}]}], 
            "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "n1", ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "0", ",", "c3"}], "}"}]}], "}"}], "]"}]}], 
            "}"}]}], "\[IndentingNewLine]", "}"}], ",", 
         RowBox[{"Boxed", "->", "False"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", "450"}]}], "]"}], 
       "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
       RowBox[{"Graphics", "[", 
        RowBox[{
         RowBox[{"{", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Circle", "[", "]"}], ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"PointSize", "[", ".02", "]"}], ",", 
             RowBox[{"Point", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"z", ",", 
                  FractionBox["1", "c3"]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "c3"}], "}"}]}], "}"}], "]"}]}], "}"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Red", ",", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"z", ",", 
                  FractionBox["1", "c3"]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "c3"}], "}"}]}], "}"}], "]"}]}], "}"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Dashed", ",", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"0", ",", "0"}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", "c3"}], "}"}]}], "}"}], "]"}]}], "}"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"z", ",", 
                 FractionBox["1", "c3"]}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "z"}], ",", 
                 FractionBox["1", "c3"]}], "}"}]}], "}"}], "]"}], "}"}]}], 
          "\[IndentingNewLine]", "}"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", "180"}]}], "]"}]}], 
      "\[IndentingNewLine]", "}"}], "]"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.85599406363904*^9, 3.8559940903426933`*^9}, {
   3.8559941309934483`*^9, 3.855994131655726*^9}, {3.855994163211793*^9, 
   3.855994236985135*^9}, 3.8559942702805567`*^9, {3.855994548619892*^9, 
   3.855994561884718*^9}, {3.855994598677622*^9, 3.855994598990672*^9}, {
   3.855994748829561*^9, 3.855994801819043*^9}, {3.855994853047646*^9, 
   3.855994931937989*^9}, {3.855995102733477*^9, 3.855995164899034*^9}, {
   3.855995278832893*^9, 3.85599530513206*^9}, {3.855995376055859*^9, 
   3.855995430016961*^9}, {3.8559954743852663`*^9, 3.855995677453114*^9}, 
   3.855995800749758*^9, {3.855995868715074*^9, 3.8559959989958057`*^9}, {
   3.855996073240698*^9, 3.855996118068122*^9}, {3.8559961494298687`*^9, 
   3.855996294790846*^9}, {3.855996346119843*^9, 3.8559964207670517`*^9}, {
   3.8559964693650007`*^9, 3.855996528150324*^9}, {3.8559965601345053`*^9, 
   3.855996560348637*^9}, {3.855996654753955*^9, 3.855996760363821*^9}},
 CellLabel->
  "In[427]:=",ExpressionUUID->"377d0458-7232-47b7-86e2-56a702d5e384"],

Cell[BoxData[
 TemplateBox[{
   Graphics3DBox[{{
      Opacity[0.5], 
      SphereBox[{0, 0, 0}]}, {
      Opacity[0.15], 
      ConeBox[{{0, 0, 0.2857142857142857}, {0, 0, 3.5}}, 
       0.9583148474999099]}, {
      PointSize[0.01], 
      Point3DBox[{{0.9583148474999099, 0, 0.2857142857142857}, {
        0, 0.9583148474999099, 0.2857142857142857}, {
        0.47915742374995496`, -0.8299250027587322, 0.2857142857142857}, {
        0, 0, 3.5}}]}, {
      Opacity[0.4], 
      TagBox[
       Polygon3DBox[{{0.9583148474999099, 0, 0.2857142857142857}, {
         0, 0.9583148474999099, 0.2857142857142857}, {
         0.47915742374995496`, -0.8299250027587322, 0.2857142857142857}}], 
       "Triangle"]}, {
      Dashing[{Small, Small}], 
      Line3DBox[{{0, 0, 0}, {0, 0, 3.5}}]}, {
      RGBColor[1, 0, 0], 
      Line3DBox[{{0, 0, 0}, {0.9583148474999099, 0, 0.2857142857142857}, {
        0, 0, 3.5}}]}}, Boxed -> False, ImageSize -> {450., 450.}, 
    SphericalRegion -> True, ViewAngle -> 0.2874622071830931, 
    ViewPoint -> {1.7419808361347062`, -2.598598211280615, 
     1.2894921879827799`}, 
    ViewVertical -> {0.31909569595588444`, -0.3690434453194085, 
     0.8729174487253709}], 
   GraphicsBox[{
     CircleBox[{0, 0}], {
      PointSize[0.02], 
      PointBox[{{0, 0}, {0.9583148474999099, 0.2857142857142857}, {
        0, 3.5}}]}, {
      RGBColor[1, 0, 0], 
      LineBox[{{0, 0}, {0.9583148474999099, 0.2857142857142857}, {0, 3.5}}]}, {
      Dashing[{Small, Small}], 
      LineBox[{{0, 0}, {0, 3.5}}]}, {
      LineBox[{{0.9583148474999099, 0.2857142857142857}, {-0.9583148474999099,
        0.2857142857142857}}]}}, ImageSize -> 180]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.855996119051708*^9, {3.855996156409306*^9, 3.8559961827156076`*^9}, 
   3.855996221183659*^9, {3.8559962719092712`*^9, 3.8559962961252604`*^9}, {
   3.855996346909802*^9, 3.855996390687628*^9}, 3.855996423437036*^9, {
   3.855996474403201*^9, 3.855996528379402*^9}, 3.855996560709387*^9, 
   3.855996655442894*^9, {3.855996717281417*^9, 
   3.855996760732171*^9}},ExpressionUUID->"f151aaf0-cc98-48d8-b6c0-\
dd0a142d984c"]
}, {2}]],

Cell[TextData[{
 "In particular, the cone axis (the vector ",
 Cell[BoxData[
  FormBox[
   StyleBox["C",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "5e84b9c2-64a6-4237-b758-0de908b877f0"],
 " when rooted at the origin) is orthogonal to the plane \[ScriptCapitalP] \
containing triangle ",
 Cell[BoxData[
  FormBox[
   StyleBox["T",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "6e32aa3c-079c-480b-ad9b-109405f08aca"],
 ". But the cross product  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["cr",
     FontWeight->"Bold"], "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubscriptBox[
        StyleBox["n",
         FontWeight->"Bold"], "2"], "-", 
       SubscriptBox[
        StyleBox["n",
         FontWeight->"Bold"], "1"]}], ")"}], "\[Cross]", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox[
        StyleBox["n",
         FontWeight->"Bold"], "3"], "-", 
       SubscriptBox[
        StyleBox["n",
         FontWeight->"Bold"], "1"]}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"996bdf5d-2047-4477-8618-67ab49e70aac"],
 " is also orthogonal to \[ScriptCapitalP], as its factors are the \
displacement vectors along two legs of triangle ",
 Cell[BoxData[
  FormBox[
   StyleBox["T",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "f940db61-dc3e-4974-a3ac-96dfe3791ae1"],
 ". This means that for some nonzero scalar \[Alpha], we have ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["C",
     FontWeight->"Bold"], "=", 
    RowBox[{"\[Alpha]", " ", 
     StyleBox["cr",
      FontWeight->"Bold"]}]}], TraditionalForm]],ExpressionUUID->
  "944530b5-294c-4843-a23e-ee920b1fb88b"],
 ". A little algebra is all that is needed to find the value of \[Alpha]. \
Noting that ",
 Cell[BoxData[
  FormBox[
   StyleBox["C",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "e3ba6c04-1a94-4406-b446-fa36620c12de"],
 " lies in the tangent plane at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "1"], TraditionalForm]],ExpressionUUID->
  "8f870cf3-c301-4d5a-b474-e42c8baa885a"],
 " we have:"
}], "Text",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGCQAmIQPekG47SEXW8cQ1Zfmg2i/7k8XQCiXbyXLwHR1y6s
3QiiKx7O3Q2imzslDoDouKSgkyB657/i8yD6Nc+cJyA6ZVfUSxBdn2X7D0SX
RJ/gTgTSUfmHJEG0xLZzaiB6ndtaUxD9Mc3PFkRX1PragehPkcJXwfwZK66D
6HetpgFJQNohLRxMRzCUx4DojskXEkF0ySxum1Qg7f1snz2I7vluL7UFSKuF
pMuD6BM/Z6uB6Iw9Nhoguol7jQ6IvuMaZgeiZ6n+dQbRUb6r3UD0t8IQPxBd
cqE5EkTvydhUAKI7+iUKQbSo1fpyEP3LgasCREtfN6gB0UmP74LpJRetmkF0
waU3fSD6TOiR4J2gcP3TEQmi1+msjAPRQo0V8SB69+WVRSDau5WtDERPyD7c
B6JFlN5OBNEAwqvpCg==
  
  "],ExpressionUUID->"862b712b-d73c-4898-83ce-009779d9f18f"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox[
      StyleBox["n",
       FontWeight->"Bold"], "1"], "\[CenterDot]", 
     RowBox[{"(", 
      RowBox[{
       StyleBox["C",
        FontWeight->"Bold"], "-", 
       SubscriptBox[
        StyleBox["n",
         FontWeight->"Bold"], "1"]}], ")"}]}], "=", "0"}], TraditionalForm]],
  ExpressionUUID->"6a578e55-ff9a-4eee-b696-b53efac77899"],
 "\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["n",
      FontWeight->"Bold"], "1"], "\[CenterDot]"}], TraditionalForm]],
  ExpressionUUID->"77d2d8fa-4f56-4d72-b19b-9a9d00065b2a"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Alpha]", " ", 
       StyleBox["cr",
        FontWeight->"Bold"]}], "-", 
      SubscriptBox[
       StyleBox["n",
        FontWeight->"Bold"], "1"]}], ")"}], "=", "0"}], TraditionalForm]],
  ExpressionUUID->"8e9da11c-2a6d-4acc-be91-d87084e57386"],
 "      Note that  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox[
      StyleBox["n",
       FontWeight->"Bold"], "1"], "\[CenterDot]", 
     SubscriptBox[
      StyleBox["n",
       FontWeight->"Bold"], "1"]}], "=", 
    SuperscriptBox["R", "2"]}], TraditionalForm]],ExpressionUUID->
  "807338dd-56cb-42c6-b042-dd987f6d992d"],
 ", so we get:\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Alpha]", " ", 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox[
        StyleBox["n",
         FontWeight->"Bold"], "1"], "\[CenterDot]", 
       StyleBox["cr",
        FontWeight->"Bold"]}], ")"}]}], "=", 
    SuperscriptBox["R", "2"]}], TraditionalForm]],ExpressionUUID->
  "a8b6666d-83ee-40cd-9cf9-0acee4fe7bf7"],
 "           And therefore:"
}], "Text",
 CellChangeTimes->{{3.855813126586699*^9, 3.8558131646983137`*^9}, {
  3.855813857583331*^9, 3.855813867747264*^9}, {3.855814003304799*^9, 
  3.855814117549747*^9}, {3.855814172850272*^9, 3.8558141876641407`*^9}, {
  3.855814358161734*^9, 3.855814365593433*^9}, {3.8558213327652683`*^9, 
  3.85582135123767*^9}, {3.855821392147956*^9, 3.855821396275878*^9}, {
  3.855983726607902*^9, 3.855983730373108*^9}, {3.855983769792651*^9, 
  3.8559837881351147`*^9}},ExpressionUUID->"991fb734-5623-44cc-aebb-\
346b8f859818"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{"\[Alpha]", "=", 
   FractionBox[
    SuperscriptBox["R", "2"], 
    RowBox[{
     SubscriptBox[
      StyleBox["n",
       FontWeight->"Bold"], "1"], "\[CenterDot]", 
     StyleBox["cr",
      FontWeight->"Bold"]}]]}], 
  TraditionalForm]],ExpressionUUID->"68334ca4-b2a9-4795-a41f-cc43fbee2bf3"]], \
"Text",
 CellChangeTimes->{{3.8558142151220493`*^9, 3.8558142360116987`*^9}, {
  3.855814275211088*^9, 3.855814296163466*^9}, {3.855821417861216*^9, 
  3.8558214268666573`*^9}},ExpressionUUID->"75646237-2b85-4e6b-a67c-\
b9e7a7add96e"],

Cell[TextData[{
 "So we have a formula for the intersection point: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["C",
     FontWeight->"Bold"], "=", 
    RowBox[{
     RowBox[{"\[Alpha]", " ", 
      StyleBox["cr",
       FontWeight->"Bold"]}], "=", 
     FractionBox[
      RowBox[{
       SuperscriptBox["R", "2"], 
       StyleBox["cr",
        FontWeight->"Bold"]}], 
      RowBox[{
       SubscriptBox[
        StyleBox["n",
         FontWeight->"Bold"], "1"], "\[CenterDot]", 
       StyleBox["cr",
        FontWeight->"Bold"]}]]}]}], TraditionalForm]],ExpressionUUID->
  "20d8285c-a5db-491b-a0f2-367959ddcdc1"],
 "."
}], "Text",
 CellChangeTimes->{{3.8558146311247587`*^9, 3.85581465771944*^9}, {
   3.855814834130412*^9, 3.8558148779295607`*^9}, 3.855814913789012*^9, {
   3.855821458945921*^9, 3.855821487922908*^9}, 
   3.861433072896637*^9},ExpressionUUID->"a310fc98-3456-4257-bdf0-\
421ef5d438bb"],

Cell[TextData[{
 "In our implementation for ",
 StyleBox["intersectionPt",
  FontWeight->"Bold"],
 ", we have ",
 Cell[BoxData[
  FormBox[
   RowBox[{"R", "=", "1"}], TraditionalForm]],ExpressionUUID->
  "844720a3-8b9e-4932-8be2-93ebad62f4c2"],
 ", so the formula becomes ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["C",
     FontWeight->"Bold"], "=", 
    FractionBox[
     StyleBox["cr",
      FontWeight->"Bold"], 
     RowBox[{
      SubscriptBox[
       StyleBox["n",
        FontWeight->"Bold"], "1"], "\[CenterDot]", 
      StyleBox["cr",
       FontWeight->"Bold"]}]]}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "cae4ff6f-6e52-44f3-a837-be938f57d397"],
 "."
}], "Text",
 CellChangeTimes->{{3.855814972802969*^9, 3.855815087509527*^9}, {
  3.861340510523946*^9, 3.8613405178931427`*^9}, {3.861432735998993*^9, 
  3.861432735999139*^9}},ExpressionUUID->"0dde4d8e-410e-4dfa-b356-\
0d8837a3ebcf"],

Cell[TextData[{
 "Algebraically, note that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["n",
      FontWeight->"Bold"], "1"], "\[CenterDot]", 
    StyleBox["cr",
     FontWeight->"Bold"]}], TraditionalForm]],ExpressionUUID->
  "daeec9b2-9c05-456b-ac4b-c0d972885a68"],
 " is just the determinant of the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"3", " ", "3"}], TraditionalForm]],ExpressionUUID->
  "a286b759-6012-490f-bb60-af69d5cc1ffe"],
 " matrix with rows  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "1"], TraditionalForm]],ExpressionUUID->
  "65903850-fb85-4833-bdc3-99ebb17686bf"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "2"], TraditionalForm]],ExpressionUUID->
  "66c47cfd-5e3a-4462-a27d-9c4d3311782b"],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["n",
     FontWeight->"Bold"], "3"], TraditionalForm]],ExpressionUUID->
  "c665c5c1-679b-4516-b7c3-b96729d95a06"],
 ": "
}], "Text",
 CellChangeTimes->{{3.855814583758102*^9, 3.855814621501381*^9}, {
  3.8558215093907127`*^9, 3.855821546421494*^9}, {3.8613413396935873`*^9, 
  3.86134134384484*^9}},ExpressionUUID->"1c05b340-befd-47ed-a590-\
3079079fa3f8"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "n1", ",", "n2", ",", "n3", ",", "n11", ",", "n12", ",", "n13", ",", "n21",
     ",", "n22", ",", "n23", ",", "n31", ",", "n32", ",", "n33"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n1", "=", 
   RowBox[{"{", 
    RowBox[{"n11", ",", "n12", ",", "n13"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n2", "=", 
   RowBox[{"{", 
    RowBox[{"n21", ",", "n22", ",", "n23"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n3", "=", 
   RowBox[{"{", 
    RowBox[{"n31", ",", "n32", ",", "n33"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{"n1", ".", 
    RowBox[{"Cross", "[", 
     RowBox[{
      RowBox[{"n2", "-", "n1"}], ",", 
      RowBox[{"n3", "-", "n1"}]}], "]"}]}], "==", 
   RowBox[{"Det", "[", 
    RowBox[{"{", 
     RowBox[{"n1", ",", "n2", ",", "n3"}], "}"}], "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.855570495537732*^9, 3.855570709698578*^9}, {
  3.855570818583516*^9, 3.855570819455308*^9}, {3.8558145033092003`*^9, 
  3.8558145517633343`*^9}, {3.8558147492350187`*^9, 3.855814749481958*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"0e137e64-bab0-45ee-9e33-9638fe7c34d8"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.855814440305221*^9, {3.8558145356474247`*^9, 3.8558145523107758`*^9}, 
   3.8558147542001343`*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"d457b07e-8f24-4c3a-8a72-30e77ff7c74c"]
}, Open  ]],

Cell[TextData[{
 "So we may express the intersection point ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["C",
     FontWeight->"Bold"], 
    StyleBox["=",
     FontWeight->"Plain"], 
    StyleBox[
     FractionBox[
      RowBox[{
       RowBox[{
        StyleBox["(",
         FontWeight->"Plain"], 
        RowBox[{
         StyleBox[
          SubscriptBox[
           StyleBox["n",
            FontWeight->"Bold"], 
           StyleBox["2",
            FontWeight->"Plain"]],
          FontWeight->"Bold"], 
         StyleBox["-",
          FontWeight->"Plain"], 
         StyleBox[
          SubscriptBox[
           StyleBox["n",
            FontWeight->"Bold"], 
           StyleBox["1",
            FontWeight->"Plain"]],
          FontWeight->"Bold"]}], 
        StyleBox[")",
         FontWeight->"Plain"]}], 
       StyleBox["\[Cross]",
        FontWeight->"Plain"], 
       RowBox[{
        StyleBox["(",
         FontWeight->"Plain"], 
        RowBox[{
         StyleBox[
          SubscriptBox[
           StyleBox["n",
            FontWeight->"Bold"], 
           StyleBox["3",
            FontWeight->"Plain"]],
          FontWeight->"Bold"], 
         StyleBox["-",
          FontWeight->"Plain"], 
         StyleBox[
          SubscriptBox[
           StyleBox["n",
            FontWeight->"Bold"], 
           StyleBox["1",
            FontWeight->"Plain"]],
          FontWeight->"Bold"]}], 
        StyleBox[")",
         FontWeight->"Plain"]}]}], 
      StyleBox[
       RowBox[{"Det", "[", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox[
           StyleBox["n",
            FontWeight->"Bold"], "1"], ",", 
          SubscriptBox[
           StyleBox["n",
            FontWeight->"Bold"], "2"], ",", 
          SubscriptBox[
           StyleBox["n",
            FontWeight->"Bold"], "3"]}], "}"}], "]"}],
       FontWeight->"Plain"]],
     FontWeight->"Bold"]}], TraditionalForm]],ExpressionUUID->
  "f2eea1bc-2366-4096-af12-ab343bcfe698"],
 "."
}], "Text",
 CellChangeTimes->{{3.855821570532401*^9, 3.855821652986083*^9}, {
  3.855826164468104*^9, 3.855826231799006*^9}, {3.8613407201343393`*^9, 
  3.861340784654232*^9}, {3.861341368908607*^9, 3.861341404539405*^9}, {
  3.861341438740906*^9, 3.861341438741096*^9}, {3.861341473138291*^9, 
  3.86134152872619*^9}, {3.861341578386537*^9, 3.861341587485505*^9}, {
  3.861433196443541*^9, 
  3.861433198520772*^9}},ExpressionUUID->"95e94bcc-2d98-49e3-9ab5-\
e7ed8aec85a2"]
}, Closed]],

Cell[CellGroupData[{

Cell["jigBody", "Subsubsection",
 CellChangeTimes->{{3.855814921660309*^9, 
  3.85581492704432*^9}},ExpressionUUID->"127c5efd-fe1d-4def-9196-\
841a8e966791"],

Cell[TextData[{
 StyleBox["generators",
  FontWeight->"Bold"],
 " is a list of the star vectors indicating axes directions for the drill \
holes. These should be ",
 StyleBox["unit vectors",
  FontSlant->"Italic"],
 ", so they are normalized automatically to form the list ",
 StyleBox["normalizedGenerators",
  FontWeight->"Bold"],
 ". We numerically approximate all coordinates to keep the computations \
speedy. It suffices to include one direction vector for each desired hole \
axis in the jig, but it is also fine to give two vectors (",
 Cell[BoxData[
  FormBox[
   StyleBox["v",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "76d50fcc-e428-45be-93d0-db6b6bca56af"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", 
    StyleBox["v",
     FontWeight->"Bold"]}], TraditionalForm]],ExpressionUUID->
  "a609d86e-2d3e-4892-8ca1-3491efdc04b7"],
 ") for each axis if that is more convenient (for instance, if you are \
getting generators by copying vertex coordinates for a polyhedron that is \
centrally symmetric). The code is flexible in this respect. It will \
automatically add the negative of each normalized generator to form the list ",
 StyleBox["starFull",
  FontWeight->"Bold"],
 ", which is then culled to delete any duplicates. This slows things down a \
tad, but the flexibility is nice. "
}], "Text",
 CellChangeTimes->{{3.855640497703361*^9, 3.8556406366323833`*^9}, {
  3.85565438910495*^9, 3.8556545732534447`*^9}, {3.855661189922494*^9, 
  3.8556611937287807`*^9}, {3.855724238561427*^9, 3.855724268296835*^9}, {
  3.855815534402005*^9, 3.8558155600418863`*^9}, {3.855815590904621*^9, 
  3.855815593048807*^9}, {3.855815642009808*^9, 3.8558156625991364`*^9}, {
  3.85581570313486*^9, 3.8558158132006607`*^9}, {3.855821860514593*^9, 
  3.85582190992633*^9}, {3.855984197166917*^9, 3.8559842631471357`*^9}, {
  3.861684791557222*^9, 3.86168479853303*^9}, {3.86177774746567*^9, 
  3.8617777670310802`*^9}},ExpressionUUID->"e21f978d-aa10-4823-bfd3-\
7354370e2d60"],

Cell[TextData[{
 "Note that when culling duplicates, points are regarded as identical \
provided the norm of their difference is less than ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Delta]", "=", "0.001"}], TraditionalForm]],ExpressionUUID->
  "a6d51057-3fa5-4317-93cf-0a1f17f7b7a1"],
 " (by default, but you can set this to whatever value you like). This is an \
arbitrary choice on my part, but in practice it should easily suffice, as it \
will be impossible to drill two holes this close together. However, if you \
get overly enthusiastic and decide to iteratively apply jigBody, that is, \
apply jigBody to the vertices of a previously computed jigBody, you may \
eventually get into trouble with this or any other single choice of \
\[Delta]."
}], "Text",
 CellChangeTimes->{{3.855640497703361*^9, 3.8556406366323833`*^9}, {
   3.85565438910495*^9, 3.8556545732534447`*^9}, {3.855661189922494*^9, 
   3.8556611937287807`*^9}, {3.855724238561427*^9, 3.855724268296835*^9}, {
   3.855815534402005*^9, 3.8558155600418863`*^9}, {3.855815590904621*^9, 
   3.855815593048807*^9}, {3.855815642009808*^9, 3.8558156625991364`*^9}, {
   3.85581570313486*^9, 3.8558158132006607`*^9}, {3.855821860514593*^9, 
   3.85582190992633*^9}, {3.855984197166917*^9, 3.855984353153842*^9}, {
   3.855989791673594*^9, 3.855989867903969*^9}, {3.855989921067198*^9, 
   3.855990147157032*^9}, {3.855997672829121*^9, 3.855997725047624*^9}, {
   3.856069856307671*^9, 3.8560698569959373`*^9}, 
   3.861684841323172*^9},ExpressionUUID->"eb305c61-1b21-4054-8fac-\
0490471e18ce"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   StyleBox["r",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "c143aa71-30e3-4d7d-8a4b-503744545eed"],
 " is the desired radius from the center of the jig body to each of the \
drill-hole entry points on the surface of the jig. Set it here to the desired \
value in millimeters, and your exported STL will not need scaling later. In \
practice, the code will first compute the vertices for a jig of radius 1, and \
in the final step each vertex is scaled by the factor ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "e752a431-02a7-4dc1-b687-e831f71e0d73"],
 "."
}], "Text",
 CellChangeTimes->{{3.85564064459182*^9, 3.8556406762331343`*^9}, {
  3.855640740509646*^9, 3.855640749349176*^9}, {3.855654844740089*^9, 
  3.855654859314019*^9}, {3.8556612125073843`*^9, 3.855661263914831*^9}, {
  3.8557242896524*^9, 3.855724291293569*^9}, {3.855815854330143*^9, 
  3.855815898624909*^9}, {3.8560698868740273`*^9, 
  3.856069890289874*^9}},ExpressionUUID->"698cbbb0-4dd6-4b93-93a1-\
27a89128f3ae"],

Cell[TextData[{
 StyleBox["dMesh",
  FontWeight->"Bold"],
 " is a ",
 StyleBox["triangulated mesh",
  FontSlant->"Italic"],
 " for the normalized points in starFull. We use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s built-in command DelaunayMesh to produce a mesh with \
the given vertices. In a 3D setting, the Delaunay mesh comprises tetrahedra \
whose vertices are 4-tuples of starFull generators, so we take the \
RegionBoundary to get the outer shell, which we call dMesh. "
}], "Text",
 CellChangeTimes->{{3.855641020153372*^9, 3.855641098844883*^9}, {
   3.855641143436777*^9, 3.855641236252778*^9}, {3.855641820109911*^9, 
   3.855641969762405*^9}, {3.855642114388124*^9, 3.855642117601426*^9}, {
   3.855655028646225*^9, 3.855655029738242*^9}, {3.855681610815988*^9, 
   3.8556816517155647`*^9}, {3.8556817631662407`*^9, 3.855681801311521*^9}, {
   3.85568185949551*^9, 3.8556822447196283`*^9}, {3.855682822329097*^9, 
   3.8556828395023613`*^9}, 3.855682889833053*^9, {3.855683330327318*^9, 
   3.855683340371846*^9}, {3.855815930015624*^9, 3.855815947191648*^9}, {
   3.8558163320195847`*^9, 3.85581636720912*^9}, {3.8558252156171303`*^9, 
   3.8558253579312553`*^9}, {3.85582562912715*^9, 3.855825653253509*^9}, {
   3.8559844148446007`*^9, 3.855984419105239*^9}, {3.85598446087519*^9, 
   3.8559844626592712`*^9}, {3.856069954040996*^9, 3.856069955167643*^9}, {
   3.8616846286949453`*^9, 3.8616847639740067`*^9}, {3.861684872178281*^9, 
   3.861685081351824*^9}, {3.861685117652676*^9, 3.861685159470335*^9}, 
   3.8616852080945873`*^9, {3.861771679399951*^9, 3.861771702301099*^9}, {
   3.861771753337953*^9, 
   3.8617717859441137`*^9}},ExpressionUUID->"d6deb725-8e0c-4a59-851c-\
ad4bd165ed2c"],

Cell[TextData[{
 "The triangular faces of this mesh are triples of unit generators that are \
\[OpenCurlyDoubleQuote]near\[CloseCurlyDoubleQuote] one another in the sense \
that their heads on the unit sphere are the vertices of triangular face of \
the mesh. These triangles are sufficient to find all vertices of the convex \
body of the drill jig. This is because the body of the jig is by definition \
the convex region enclosed by ",
 StyleBox["all",
  FontSlant->"Italic"],
 " pairs of parallel planes orthogonal to the hole axes; its vertices are \
necessarily the intersection points of planes orthogonal to generators that \
are near to one another. The use of the dMesh is a matter of efficiency. The \
brute force alternative is to compute plane intersection points for ",
 StyleBox["all",
  FontSlant->"Italic"],
 " triples of generators in the list starFull, which is typically an order of \
magnitude larger than the number of triangles in the dMesh. The list of ",
 StyleBox["all",
  FontSlant->"Italic"],
 " triples will also contain numerous instances where two of the three \
vertices are antipodal, and all such cases lead to degenerate intersection \
points.  "
}], "Text",
 CellChangeTimes->CompressedData["
1:eJwdz2kow3EAxvGlJGQJDfHC3mikyJFFyajlWGlLzFm0P8n1BuHNwgovUOYI
czT5v1BbQttCrkhWiBzLmDtTZCzH7I3f83vx9Knn3Zdf2ShjPDgcDp8M1tlV
yX4rr6Is7xIRDPp7E8NtXo8MKlRdE3CaEephV61kE96nLVFvdUPcIKJ+2khV
hxd784n2pxYutEiZcOj+ieJDobVRAOO9RuXwu9s8A+WBDi39W03zMGX2bAF2
5ggfoS2mhtoa6rRDXunAC0xb/XhPImoVv9SyYwlbSYyQblONmWOXMH/m+Bmy
n9F9CqKh+WIQlutkaob4oamhXo2np1aj178iA8Zec7PhqduVCz/Vp3lQLAwu
hAXV/RVwqnefqrQO1MNIX0MHjNBcGeDIjtEE1xK6HcvEqtJJF7Qp5xw24iGj
/YKsq6l5aPdVFOcYboNb/YwSil0WaovpQAXtrLMHCqZyFuG4zzX1Zq5ob514
ctduhg28jZAtYoAoOQwarA8b0OIZZoZVuftH8DzRTf0HnbInvQ==
  
  "],ExpressionUUID->"bd91a53e-5e5e-40a0-9148-d9b776ae561e"],

Cell[TextData[{
 StyleBox["triples",
  FontWeight->"Bold"],
 " is just a list of the indices (from the starFull list) for all the \
triangles of the dMesh. For example, the triple {1,5,2} is the triangle \
formed by vertices at positions 1, 5, and 2 in the list starFull."
}], "Text",
 CellChangeTimes->{{3.855641244498884*^9, 3.855641325358881*^9}, {
  3.855655076353067*^9, 3.855655077041301*^9}, {3.855682268799252*^9, 
  3.8556823055511827`*^9}, {3.855682461122974*^9, 3.855682496248558*^9}, {
  3.8556835121672792`*^9, 3.855683633719296*^9}, {3.861685470351766*^9, 
  3.861685470839477*^9}, {3.861771886055188*^9, 
  3.861771886287273*^9}},ExpressionUUID->"2287bfc1-0222-4b53-a0b6-\
107198563f10"],

Cell[TextData[{
 StyleBox["candidates",
  FontWeight->"Bold"],
 " is a list of all the intersection points of triples of tangent planes, \
obtained by applying ",
 StyleBox["intersectionPt",
  FontWeight->"Bold"],
 " to all of our triples. The vertices for the drill jig are a ",
 StyleBox["subset",
  FontSlant->"Italic"],
 " of the list of candidates; some candidates may lie outside the convex \
region bounded by all pairs of parallel planes."
}], "Text",
 CellChangeTimes->{{3.855641332854556*^9, 3.855641382619926*^9}, {
  3.855642174491983*^9, 3.8556421764282217`*^9}, {3.855655096024898*^9, 
  3.855655111028873*^9}, {3.855682518392169*^9, 3.855682545352059*^9}, {
  3.855682583453155*^9, 3.855682687814066*^9}, {3.8558160954982767`*^9, 
  3.855816154851232*^9}, {3.85598464214913*^9, 3.855984670634848*^9}, {
  3.861685700839465*^9, 
  3.861685705951357*^9}},ExpressionUUID->"2ebc7348-8a33-4530-a91d-\
3e097351e07c"],

Cell[TextData[{
 "From the list of candidates, we delete any duplicates (again using \[Delta] \
to determine if two candidates are the same), and then we discard any points \
that are not situated between ",
 StyleBox["all",
  FontSlant->"Italic"],
 " pairs of parallel face planes (how this is done is described below). The \
result is the desired list of ",
 StyleBox["vertices",
  FontWeight->"Bold"],
 " for the jigBody. "
}], "Text",
 CellChangeTimes->{{3.8556413939954576`*^9, 3.855641479401351*^9}, {
   3.855641534668457*^9, 3.855641588071322*^9}, {3.855641619009*^9, 
   3.855641677023768*^9}, {3.855642221825346*^9, 3.855642225265946*^9}, 
   3.855655225916078*^9, {3.8556837071472893`*^9, 3.8556837093876333`*^9}, {
   3.855816601756791*^9, 3.855816602069084*^9}, {3.856071515694263*^9, 
   3.856071531868106*^9}, {3.856071686718162*^9, 3.856071740498315*^9}, {
   3.861612772666092*^9, 
   3.861612781385725*^9}},ExpressionUUID->"853dab33-00c2-401e-99e7-\
a0a8b9f2582a"],

Cell[TextData[{
 "Finally, we take the ",
 StyleBox["convex hull ",
  FontSlant->"Italic"],
 "of the final vertices to get the jigBody. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s built-in command ConvexHullMesh is used here."
}], "Text",
 CellChangeTimes->{{3.8556417052949457`*^9, 3.855641726958426*^9}, {
   3.855682753443362*^9, 3.8556827739517317`*^9}, 3.855683344571855*^9, {
   3.855816205449465*^9, 3.855816229360977*^9}, {3.861685756487233*^9, 
   3.861685757327189*^9}, {3.8617719463410263`*^9, 
   3.861771954723599*^9}},ExpressionUUID->"eef161d0-c1e7-43b8-a19c-\
acd77dde6664"],

Cell["\<\
The only issue left to resolve is how to determine whether a candidate point \
should be a vertex in our jig body. This requires some notation.\
\>", "Text",
 CellChangeTimes->{{3.855816197449708*^9, 3.855816199777625*^9}, {
  3.855816239195862*^9, 3.8558162909929523`*^9}, {3.8558166427314787`*^9, 
  3.855816642939619*^9}, {3.8558200352174397`*^9, 3.855820036057344*^9}, {
  3.8559847030890007`*^9, 
  3.8559847031929827`*^9}},ExpressionUUID->"83def9d8-ce7f-424d-a263-\
530dbc65c77b"],

Cell[TextData[{
 "Suppose our jig has ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "30de7669-6659-48f8-a6b6-a38fa5207541"],
 " generators (direction axes). The list starFull then has ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "n"}], TraditionalForm]],ExpressionUUID->
  "670b4ace-a56e-4895-8811-432f38dad74a"],
 " unit vectors, since for each direction vector ",
 Cell[BoxData[
  FormBox[
   StyleBox["u",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "9fcdf10a-8d6b-42b2-a1a6-7aeb9e798173"],
 " in the list, the vector ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", 
    StyleBox["u",
     FontWeight->"Bold"]}], TraditionalForm]],ExpressionUUID->
  "8fadcf2f-88d9-4a1c-ad1a-ad20e7f4e6d1"],
 " is also present. There is a plane with normal vector ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["u",
     FontWeight->"Bold"], "=", 
    RowBox[{"\[LeftAngleBracket]", 
     RowBox[{
      SubscriptBox["u", "1"], ",", 
      SubscriptBox["u", "2"], ",", 
      SubscriptBox["u", "3"]}], "\[RightAngleBracket]"}]}], TraditionalForm]],
  ExpressionUUID->"321bb513-731a-463b-a3ce-d3aa7eb60be9"],
 " passing through the point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["u", "1"], ",", 
     SubscriptBox["u", "2"], ",", 
     SubscriptBox["u", "3"]}], ")"}], TraditionalForm]],ExpressionUUID->
  "e0da92c7-f094-4acf-a189-83d191fc8d02"],
 ", and a second parallel plane passing through the point ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["u", "1"]}], ",", 
     RowBox[{"-", 
      SubscriptBox["u", "2"]}], ",", 
     RowBox[{"-", 
      SubscriptBox["u", "3"]}]}], ")"}], TraditionalForm]],ExpressionUUID->
  "bb5a15c7-48e7-468d-8b75-eb3f66b638ce"],
 ". We wish to characterize the region between these planes."
}], "Text",
 CellChangeTimes->{{3.8558187946266947`*^9, 3.8558188751117353`*^9}, {
  3.8558189055128117`*^9, 3.8558189819835663`*^9}, {3.8617767430878353`*^9, 
  3.861776754471201*^9}},ExpressionUUID->"e8767919-5b58-499a-8059-\
9a24702ada02"],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["P",
     FontWeight->"Bold"], "=", 
    RowBox[{"\[LeftAngleBracket]", 
     RowBox[{"x", ",", "y", ",", "z"}], "\[RightAngleBracket]"}]}], 
   TraditionalForm]],ExpressionUUID->"8caa2dc5-7e53-4fb3-a20d-496e3dbd601f"],
 " represent a point in space. The two planes mentioned above comprise those \
points ",
 Cell[BoxData[
  FormBox[
   StyleBox["P",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "e1f7e857-a134-4fc8-935b-53f2d6ce422f"],
 " satisfying  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["u",
      FontWeight->"Bold"], "\[CenterDot]", 
     RowBox[{"(", 
      RowBox[{
       StyleBox["P",
        FontWeight->"Bold"], "-", 
       StyleBox["u",
        FontWeight->"Bold"]}], ")"}]}], "=", "0"}], TraditionalForm]],
  ExpressionUUID->"6fc37e85-ac48-4366-b395-7143e862000f"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox["(",
       FontWeight->"Plain"], 
      RowBox[{
       StyleBox["-",
        FontWeight->"Plain"], 
       StyleBox["u",
        FontWeight->"Bold"]}], ")"}], "\[CenterDot]", 
     RowBox[{"(", 
      RowBox[{
       StyleBox["P",
        FontWeight->"Bold"], 
       StyleBox["+",
        FontWeight->"Plain"], 
       StyleBox["u",
        FontWeight->"Bold"]}], ")"}]}], "=", "0"}], TraditionalForm]],
  ExpressionUUID->"b11934d7-05e2-4704-87ce-5a351c7ee7ba"],
 ", respectively. We may rewrite these as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["u",
      FontWeight->"Bold"], "\[CenterDot]", 
     StyleBox["P",
      FontWeight->"Bold"]}], "=", "1"}], TraditionalForm]],ExpressionUUID->
  "43ed210a-e716-495d-8898-e085f64cf36a"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["u",
      FontWeight->"Bold"], "\[CenterDot]", 
     StyleBox["P",
      FontWeight->"Bold"]}], "=", 
    RowBox[{"-", "1"}]}], TraditionalForm]],ExpressionUUID->
  "f5feef10-4e44-4a2e-8bf1-146f5a917136"],
 "."
}], "Text",
 CellChangeTimes->{{3.8556417428539963`*^9, 3.855641751838159*^9}, {
   3.855642012185169*^9, 3.85564202739994*^9}, {3.855645927825975*^9, 
   3.855645958444989*^9}, {3.855646154700383*^9, 3.855646173795925*^9}, 
   3.855652871392763*^9, 3.855652901743675*^9, {3.85565535331177*^9, 
   3.8556553576852713`*^9}, {3.855655474198979*^9, 3.8556554742013903`*^9}, {
   3.855684014163957*^9, 3.855684034185611*^9}, {3.8556843181358023`*^9, 
   3.855684319597435*^9}, {3.855684376737146*^9, 3.8556844010763702`*^9}, {
   3.855722445723529*^9, 3.855722447755933*^9}, {3.8557224865075617`*^9, 
   3.855722488651136*^9}, {3.85572454088571*^9, 3.855724549972814*^9}, 
   3.855819016813128*^9, {3.855819263338382*^9, 3.8558192845861263`*^9}, {
   3.85582013720922*^9, 
   3.855820140784856*^9}},ExpressionUUID->"9679140f-5767-46f5-b937-\
4b821b1bd8c2"],

Cell[TextData[{
 "Taking ",
 Cell[BoxData[
  FormBox[
   StyleBox["P",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "773b2ff0-7742-4f6e-8960-8a8523fa1b21"],
 " to be the origin, and noting that in this case  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     StyleBox["u",
      FontWeight->"Bold"], "\[CenterDot]", 
     StyleBox["P",
      FontWeight->"Bold"]}], "=", 
    RowBox[{"0", "=", 
     RowBox[{
      RowBox[{
       StyleBox["(",
        FontWeight->"Plain"], 
       RowBox[{
        StyleBox["-",
         FontWeight->"Plain"], 
        StyleBox["u",
         FontWeight->"Bold"]}], ")"}], "\[CenterDot]", 
      StyleBox["P",
       FontWeight->"Bold"]}]}]}], TraditionalForm]],ExpressionUUID->
  "2d300ac2-9a00-42fd-81aa-9ac62a5d731e"],
 ", we see that the region ",
 StyleBox["between",
  FontSlant->"Italic"],
 " the planes, since it contains the origin, comprises those points ",
 Cell[BoxData[
  FormBox[
   StyleBox["P",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "14347318-d7f1-4e5f-9447-963d47a71632"],
 " for which  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"-", "1"}], "<=", 
    RowBox[{
     StyleBox["u",
      FontWeight->"Bold"], "\[CenterDot]", 
     StyleBox["P",
      FontWeight->"Bold"]}], "<=", "1"}], TraditionalForm]],ExpressionUUID->
  "ea0db134-c2fb-4e62-81f4-5d2a003ac7b3"],
 " . "
}], "Text",
 CellChangeTimes->{{3.8556417428539963`*^9, 3.855641751838159*^9}, {
   3.855642012185169*^9, 3.85564202739994*^9}, {3.855645927825975*^9, 
   3.855645958444989*^9}, {3.855646154700383*^9, 3.855646173795925*^9}, 
   3.855652871392763*^9, 3.855652904492291*^9, {3.85565556503889*^9, 
   3.855655567406014*^9}, {3.855684450305909*^9, 3.8556844596984243`*^9}, {
   3.855724554244911*^9, 3.855724580116519*^9}, {3.855819297504569*^9, 
   3.855819349705429*^9}, {3.8558201087701683`*^9, 3.855820115941486*^9}, {
   3.8560716137537203`*^9, 3.856071630519472*^9}, {3.86162587223804*^9, 
   3.8616259040037622`*^9}, {3.86162595018163*^9, 3.861625991332165*^9}, {
   3.86162603578786*^9, 3.861626039767013*^9}, {3.8617720137870398`*^9, 
   3.8617720143673353`*^9}},ExpressionUUID->"44e94d11-136a-443e-8123-\
2720624ffa02"],

Cell[TextData[{
 "So given the starFull list of unit normal generators  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["u",
      FontWeight->"Bold"], "i"], "=", 
    RowBox[{"\[LeftAngleBracket]", 
     RowBox[{
      SubscriptBox[
       SubscriptBox["u", "i"], "1"], ",", 
      SubscriptBox[
       SubscriptBox["u", "i"], "2"], ",", 
      SubscriptBox[
       SubscriptBox["u", "i"], "3"]}], "\[RightAngleBracket]"}]}], 
   TraditionalForm]],ExpressionUUID->"ec982fc8-d7b4-4347-bb13-aeebd99045a6"],
 ", where ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]],ExpressionUUID->
  "e5615b8a-86af-476a-95e1-72927be3ea3c"],
 " ranges from 1 to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "n"}], TraditionalForm]],ExpressionUUID->
  "0f363f64-3545-4c2a-9227-b71cd27b84c5"],
 ",  the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "n"}], ")"}], "\[Times]", "3"}], TraditionalForm]],
  ExpressionUUID->"5a903791-9282-408a-8157-47bc949f7df4"],
 " matrix ",
 Cell[BoxData[
  FormBox[
   StyleBox["M",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "49fc4d2f-ee9a-4e92-a7d1-3cd1331904da"],
 " with rows ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    StyleBox["u",
     FontWeight->"Bold"], "i"], TraditionalForm]],ExpressionUUID->
  "d9dc023a-5d4b-46cd-b49b-1d1ceaa75775"],
 " is just the list starFull, and for any point ",
 Cell[BoxData[
  FormBox[
   StyleBox["P",
    FontWeight->"Bold"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "7d3d357a-39c8-419f-a7c5-79778226cd1d"],
 ", the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", "n"}], ")"}], "\[Times]", "1"}], TraditionalForm]],
  ExpressionUUID->"46f31a56-6dfa-4787-9476-825613eda5c0"],
 " column vector ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["M",
     FontWeight->"Bold"], "\[CenterDot]", 
    SuperscriptBox[
     StyleBox["P",
      FontWeight->"Bold"], "T"]}], TraditionalForm]],ExpressionUUID->
  "990ea665-84f9-4f87-9245-0b3d902ab389"],
 " has entries ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     StyleBox["u",
      FontWeight->"Bold"], "i"], "\[CenterDot]", 
    StyleBox["P",
     FontWeight->"Bold"]}], TraditionalForm]],ExpressionUUID->
  "f31701b1-8973-4031-be89-1e45c94deb3e"],
 ". We wish to find the collection of candidate points ",
 Cell[BoxData[
  FormBox[
   StyleBox["P",
    FontWeight->"Bold"], TraditionalForm]],ExpressionUUID->
  "6cbff151-e208-4439-83ec-d92b012bec10"],
 " for which each entry of this column vector is between ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1"}], TraditionalForm]],ExpressionUUID->
  "7c8b9dc9-6ada-4544-9387-06ac5f9a4b58"],
 " and ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "4eeaf1e7-40ba-4de6-8fbc-8d718063d9c3"],
 ". These are precisely the points where the maximum of the absolute values \
of the coordinates is at most ",
 Cell[BoxData[
  FormBox["1", TraditionalForm]],ExpressionUUID->
  "8b506ba5-a30d-4ac9-9cf7-95909a3abe3b"],
 ". This is the criterion used in the calculation for ",
 StyleBox["vertices",
  FontWeight->"Bold"],
 " in the jigBody code; it tosses out any candidate point (a point of \
intersection of 3 face planes) that fails to meet this criterion. "
}], "Text",
 CellChangeTimes->{{3.8556417428539963`*^9, 3.855641751838159*^9}, {
   3.855642012185169*^9, 3.85564202739994*^9}, {3.855645927825975*^9, 
   3.855645958444989*^9}, {3.855646154700383*^9, 3.855646173795925*^9}, 
   3.855652871392763*^9, 3.8556529078823013`*^9, {3.855655668609178*^9, 
   3.855655708487759*^9}, {3.855660051573793*^9, 3.8556600632940903`*^9}, {
   3.855684638903673*^9, 3.855684663182333*^9}, {3.855684714309223*^9, 
   3.855684722107458*^9}, {3.855684773484803*^9, 3.855684774581024*^9}, {
   3.8557226002293453`*^9, 3.8557226012597733`*^9}, {3.855724605677339*^9, 
   3.8557246107393227`*^9}, {3.855819390737773*^9, 3.855819394196924*^9}, {
   3.855819435331855*^9, 3.855819521969276*^9}, {3.855826079644106*^9, 
   3.855826099330821*^9}, {3.855836014036214*^9, 3.855836030306938*^9}, {
   3.8558360701636477`*^9, 3.855836075828496*^9}, {3.855984813728779*^9, 
   3.8559848380779667`*^9}, {3.8559848691485777`*^9, 3.855984880332877*^9}, 
   3.856071668623859*^9, {3.8616267676639347`*^9, 3.861626769254505*^9}, {
   3.861772068092806*^9, 
   3.8617720774416857`*^9}},ExpressionUUID->"84f4964e-6c0f-48af-9c96-\
7872928851a4"]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Section",
 CellChangeTimes->{{3.8556399784949503`*^9, 
  3.8556399797678003`*^9}},ExpressionUUID->"bd02c5f7-b037-456f-8f41-\
92ba2f41fb7d"],

Cell[CellGroupData[{

Cell["\<\
Jig axes are 3-fold and 4-fold rotational symmetry axes of Octahedron\
\>", "Subsection",
 CellChangeTimes->{{3.855640039188676*^9, 3.85564005498094*^9}, {
  3.855640393835045*^9, 3.8556404027544947`*^9}, {3.855642473580441*^9, 
  3.855642485139719*^9}, {3.85564291124047*^9, 3.855642913023053*^9}, {
  3.855660646438903*^9, 3.855660647788875*^9}, {3.855661371267353*^9, 
  3.855661372505282*^9}},ExpressionUUID->"4068db0d-c743-4553-9557-\
5d3b430e75e8"],

Cell["Generators for the seven hole axes:", "Text",
 CellChangeTimes->{{3.855660835735312*^9, 3.855660839743354*^9}, {
  3.855665975230383*^9, 3.855665976943329*^9}, {3.855998315516206*^9, 
  3.855998318243452*^9}},ExpressionUUID->"c7e13241-642b-4922-b877-\
3610e2015f5e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8556391920091467`*^9, 3.855639202273176*^9}, 
   3.855639239558659*^9, {3.85563971362216*^9, 3.855639714187256*^9}, {
   3.855640415293953*^9, 3.855640424912155*^9}, {3.855642494740925*^9, 
   3.855642495294331*^9}, {3.85564253469829*^9, 3.8556426083747463`*^9}, 
   3.85582648943088*^9},
 CellLabel->
  "In[101]:=",ExpressionUUID->"bad8573e-6548-482b-914d-5d520ecd6f58"],

Cell["Jig body polyhedron (with unit radius):", "Text",
 CellChangeTimes->{{3.855997904703805*^9, 
  3.8559979140233507`*^9}},ExpressionUUID->"82cffc53-821a-46a6-9507-\
48146cba3251"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"jigBody", "[", "star", "]"}]], "Input",
 CellChangeTimes->{
  3.855997827779951*^9, {3.861682621667869*^9, 3.861682630740012*^9}},
 CellLabel->
  "In[103]:=",ExpressionUUID->"9abe7fcf-c668-4665-a690-3c8ee4d834ca"],

Cell[BoxData[
 Graphics3DBox[
  TagBox[
   DynamicModuleBox[{Typeset`mesh = HoldComplete[
     BoundaryMeshRegion[CompressedData["
1:eJxTTMoPSmViYGCQAGJmBnTwYX/wzA0XvuY8t4eJQPn7ofK4xPfjMGc/dj5u
/ejqUO3FUGePQz1Oc1H9h/APjI/uf3T7cPjXHrv5GO7BCD8c6jHch+Zfgu4g
4H6c/sYV3zD70N0LAA7SoPc=
      "], {
       Polygon[{{7, 2, 17, 21}, {1, 6, 4, 19}, {13, 15, 3, 9}, {11, 14, 23, 
        22}, {16, 12, 18, 20}, {10, 5, 8, 24}}], 
       Polygon[{{11, 12, 16, 15, 13, 14}, {6, 5, 10, 9, 3, 4}, {4, 3, 15, 16, 
        20, 19}, {5, 6, 1, 2, 7, 8}, {21, 17, 18, 12, 11, 22}, {2, 1, 19, 20, 
        18, 17}, {14, 13, 9, 10, 24, 23}, {7, 21, 22, 23, 24, 8}}]}, 
      Method -> {
       "EliminateUnusedCoordinates" -> True, "DeleteDuplicateCoordinates" -> 
        Automatic, "DeleteDuplicateCells" -> Automatic, "VertexAlias" -> 
        Identity, "CheckOrientation" -> Automatic, "CoplanarityTolerance" -> 
        Automatic, "CheckIntersections" -> Automatic, 
        "BoundaryNesting" -> {{0, 0}}, "SeparateBoundaries" -> False, 
        "TJunction" -> Automatic, "PropagateMarkers" -> True, "ZeroTest" -> 
        Automatic, "Hash" -> 7659306444788149687}]]}, 
    TagBox[GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAGJmBnTwYX/wzA0XvuY8t4eJQPn7ofK4xPfjMGc/dj5u
/ejqUO3FUGePQz1Oc1H9h/APjI/uf3T7cPjXHrv5GO7BCD8c6jHch+Zfgu4g
4H6c/sYV3zD70N0LAA7SoPc=
      "], 
      {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
       TagBox[
        Polygon3DBox[{{7, 2, 17, 21}, {1, 6, 4, 19}, {13, 15, 3, 9}, {11, 14, 
          23, 22}, {16, 12, 18, 20}, {10, 5, 8, 24}, {11, 12, 16, 15, 13, 
          14}, {6, 5, 10, 9, 3, 4}, {4, 3, 15, 16, 20, 19}, {5, 6, 1, 2, 7, 
          8}, {21, 17, 18, 12, 11, 22}, {2, 1, 19, 20, 18, 17}, {14, 13, 9, 
          10, 24, 23}, {7, 21, 22, 23, 24, 8}}],
        Annotation[#, "Geometry"]& ]}],
     MouseAppearanceTag["LinkHand"]],
    AllowKernelInitialization->False],
   "MeshGraphics3D",
   AutoDelete->True,
   Editable->False,
   Selectable->False],
  Boxed->False,
  DefaultBaseStyle->{
   "MeshGraphics3D", FrontEnd`GraphicsHighlightColor -> Hue[0.1, 1, 0.7]},
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{
  3.856069060838976*^9, 3.856071770316515*^9, {3.8616826228191233`*^9, 
   3.861682631606421*^9}},
 CellLabel->
  "Out[103]=",ExpressionUUID->"b2b191c8-9680-472a-9c80-c967bfae92d0"]
}, Open  ]],

Cell["\<\
Below: Jig body with 15mm radius (from center of the jig body to the hole \
entry points on the surface of the jig), with drill-hole locations shown in \
red:\
\>", "Text",
 CellChangeTimes->{{3.855660843079196*^9, 3.855660880766427*^9}, {
  3.855665999830008*^9, 3.855666009990575*^9}, {3.8557260433275633`*^9, 
  3.855726044129677*^9}, {3.855726952090398*^9, 3.855726993475712*^9}, {
  3.855997845950692*^9, 3.855997847438739*^9}, {3.86168267516057*^9, 
  3.861682676337282*^9}},ExpressionUUID->"65342108-dc23-4f95-aec0-\
74b797cdd485"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}, {3.855997643759848*^9, 3.85599765423835*^9}, {
  3.861682711383554*^9, 3.8616827158553543`*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"690de0fc-b734-42d1-8adf-4400a9d45baa"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAGJmBnSgd2Bf/9JitW+qDjARKP8AVB6X+AEc5hzAzset
H10dqr0Y6hxwqMdpLqr/EP6B8dH9j24fDv86YDcfwz1wcQLqMdyH5l+C7iDg
fgz7sIcnhjoM9wIAp7t1pw==
    "], 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{7, 2, 17, 21}, {1, 6, 4, 19}, {13, 15, 3, 9}, {11, 14, 
        23, 22}, {16, 12, 18, 20}, {10, 5, 8, 24}, {11, 12, 16, 15, 13, 14}, {
        6, 5, 10, 9, 3, 4}, {4, 3, 15, 16, 20, 19}, {5, 6, 1, 2, 7, 8}, {21, 
        17, 18, 12, 11, 22}, {2, 1, 19, 20, 18, 17}, {14, 13, 9, 10, 24, 
        23}, {7, 21, 22, 23, 24, 8}}],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIDYGAz0HBhyAWPnFYg7Oc/IVcdEHCIgTkneA2nOA
gDsIyuOwF91+Yt2FoQ8A03BSvQ==
     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{
  3.856069073652793*^9, 3.856071772624016*^9, {3.861682712268002*^9, 
   3.861682716517891*^9}},
 CellLabel->
  "Out[107]=",ExpressionUUID->"e38104dc-7e8a-45be-a9e9-df854eebccaa"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Jig axes are vertices of Icosahedron and/or Dodecahedron", "Subsection",
 CellChangeTimes->{{3.855639993455254*^9, 3.855640002415152*^9}, {
  3.855642932358026*^9, 
  3.855642941629764*^9}},ExpressionUUID->"e9fb95c3-6c33-48f5-8978-\
6392df9f5862"],

Cell["\<\
The jig body for either set of axes is just the dual polyhedron.\
\>", "Text",
 CellChangeTimes->{{3.855643200073801*^9, 3.855643230125321*^9}, {
  3.8556586010157967`*^9, 
  3.8556586307967167`*^9}},ExpressionUUID->"7beeed32-8a08-47e0-ab83-\
f2e5b74b02cc"],

Cell[BoxData[
 RowBox[{"PolyhedronData", "[", "\"\<Dodecahedron\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.855639072517928*^9, 3.855639074909686*^9}, {
  3.855640207471583*^9, 3.8556402083502493`*^9}},
 CellLabel->
  "(Debug) In[848]:=",ExpressionUUID->"a8fae508-e035-4f91-b013-0567274c0042"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"PolyhedronData", "[", 
    RowBox[{"\"\<Dodecahedron\>\"", ",", "\"\<VertexCoordinates\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "star", "]"}]}], "Input",
 CellChangeTimes->{{3.85563749515095*^9, 3.855637544262084*^9}, {
   3.8556380920606613`*^9, 3.8556380960848217`*^9}, {3.8556381882302*^9, 
   3.855638189238912*^9}, {3.8556383689887342`*^9, 3.855638374899458*^9}, {
   3.855638412395669*^9, 3.8556384167631207`*^9}, {3.855638808887814*^9, 
   3.8556388460389433`*^9}, {3.855638915064519*^9, 3.855638941914418*^9}, {
   3.85563908215079*^9, 3.855639083895178*^9}, {3.855639126100025*^9, 
   3.855639127944468*^9}, {3.855639747690493*^9, 3.85563975244311*^9}, 
   3.855640226528442*^9, 3.856071921754286*^9, {3.8560719533056107`*^9, 
   3.8560719554253883`*^9}},
 CellLabel->
  "In[108]:=",ExpressionUUID->"6d431e4e-5376-478e-9b65-718b2c731460"],

Cell[BoxData["20"], "Output",
 CellChangeTimes->{{3.8556375284607677`*^9, 3.855637545398603*^9}, 
   3.855638098428989*^9, 3.8556381384299498`*^9, 3.855638190369357*^9, 
   3.855638376270917*^9, 3.8556384175415783`*^9, 3.855638705146554*^9, {
   3.8556388116244307`*^9, 3.855638846772299*^9}, {3.855638920169354*^9, 
   3.855638943523416*^9}, 3.855639084842663*^9, 3.855639131437209*^9, {
   3.85563974002225*^9, 3.855639752999628*^9}, 3.855640227626932*^9, 
   3.855827499798832*^9, 3.8560718894266453`*^9, 3.8560719226887007`*^9, 
   3.856071956417343*^9, 3.861682807677093*^9},
 CellLabel->
  "Out[109]=",ExpressionUUID->"ebe1bcd1-0c4a-4d6f-9b7f-1f1f90ef3bf5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}, {3.861682803582732*^9, 3.861682812535643*^9}},
 CellLabel->
  "In[112]:=",ExpressionUUID->"86cf3e00-3d0c-46a7-9f57-fd021c002721"],

Cell[BoxData[
 Graphics3DBox[{
   GraphicsComplex3DBox[{{
    13.658894959650437`, -9.92376807374411, -8.441661333828597}, {
    13.658894959650437`, 
    9.92376807374411, -8.441661333828598}, {-5.217233625821851, 
    16.05699403978905, -8.441661333828597}, {5.21723362582184, 
    16.056994039789046`, 
    8.441661333828602}, {-13.65889495965044, -9.923768073744116, 
    8.441661333828597}, {-13.65889495965044, 9.923768073744116, 
    8.441661333828597}, {5.217233625821848, -16.056994039789053`, 
    8.441661333828591}, {9.541517857067212*^-16, -2.9365772428359453`*^-15, 
    18.876128585472284`}, {-5.217233625821851, -16.05699403978905, \
-8.441661333828597}, {-16.883322667657193`, -2.251772553261343*^-16, \
-8.441661333828598}, {16.88332266765719, 2.804184456187913*^-15, 
    8.441661333828597}, {0., 0., -18.876128585472284`}}, 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{3, 12, 10}, {12, 9, 10}, {3, 2, 12}, {6, 3, 10}, {7, 1, 
       11}, {9, 1, 7}, {1, 9, 12}, {2, 1, 12}, {1, 2, 11}, {8, 7, 11}, {2, 4, 
       11}, {4, 2, 3}, {6, 4, 3}, {8, 4, 6}, {4, 8, 11}, {5, 9, 7}, {9, 5, 
       10}, {5, 6, 10}, {8, 5, 7}, {5, 8, 6}}],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGDQAGJmIJY6lTD100rdAwxQUFRZW+e0ks0BKu6AJn4ggVcp
LDBU6ECb2/afrmY6Bwqh6tHEHWDie7MPfl34X91hsZiD85x8xQNF2MUdYOIw
e2DqYerQxOH6JcHulD1wIv5dTnCv6IF9EPEDaOIOMHGIv2QdYOph5qCJw81P
BPtLCR4OMHNg9CKoO6H+RReHhcMBqDkH0MyBhxPMHJh+NHG4+5Mg4eyAFv7o
4nB7ccUjrnhPwGFOAg57oeF0AC0e0cVh8Q6Pf7R4RBeH65dEi5d9qPHugBbv
sHg8gBaPB9DE4ebjihcYjRaP6OLweMKVTmDhhBaPDmjicPcn4chHSTjyHQCT
hKVm
     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{{3.855639570470196*^9, 3.855639591248064*^9}, 
   3.855639626017581*^9, 3.855639765515862*^9, 3.8556402421179943`*^9, 
   3.855827508535493*^9, 3.856071892091525*^9, 3.8560719257721167`*^9, {
   3.861682809541387*^9, 3.861682814167577*^9}},
 CellLabel->
  "Out[113]=",ExpressionUUID->"5b2cdc4c-867b-4c68-8329-f27b52097c9a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"PolyhedronData", "[", 
    RowBox[{"\"\<Icosahedron\>\"", ",", "\"\<VertexCoordinates\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "star", "]"}]}], "Input",
 CellChangeTimes->{{3.85563749515095*^9, 3.855637544262084*^9}, {
   3.8556380920606613`*^9, 3.8556380960848217`*^9}, {3.8556381882302*^9, 
   3.855638189238912*^9}, {3.8556383689887342`*^9, 3.855638374899458*^9}, {
   3.855638412395669*^9, 3.8556384167631207`*^9}, {3.855638808887814*^9, 
   3.8556388460389433`*^9}, {3.855638915064519*^9, 3.855638941914418*^9}, {
   3.85563908215079*^9, 3.855639083895178*^9}, {3.855639126100025*^9, 
   3.855639127944468*^9}, {3.855639747690493*^9, 3.85563975244311*^9}, 
   3.855640226528442*^9, {3.855640266282907*^9, 3.855640267381486*^9}, {
   3.856071931106339*^9, 3.856071946497541*^9}},
 CellLabel->
  "In[114]:=",ExpressionUUID->"a9ea7ed5-1b89-4a59-95e4-b11a11449d3e"],

Cell[BoxData["12"], "Output",
 CellChangeTimes->{{3.8556375284607677`*^9, 3.855637545398603*^9}, 
   3.855638098428989*^9, 3.8556381384299498`*^9, 3.855638190369357*^9, 
   3.855638376270917*^9, 3.8556384175415783`*^9, 3.855638705146554*^9, {
   3.8556388116244307`*^9, 3.855638846772299*^9}, {3.855638920169354*^9, 
   3.855638943523416*^9}, 3.855639084842663*^9, 3.855639131437209*^9, {
   3.85563974002225*^9, 3.855639752999628*^9}, 3.855640227626932*^9, 
   3.855640268597116*^9, 3.855827515657014*^9, 3.856071894942252*^9, {
   3.8560719372815657`*^9, 3.856071947044159*^9}, 3.861682818163432*^9},
 CellLabel->
  "Out[115]=",ExpressionUUID->"fd556048-381f-4bf9-84a8-a2008204b000"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}, {3.861682821453987*^9, 3.861682824846917*^9}},
 CellLabel->
  "In[118]:=",ExpressionUUID->"da6c4b14-9a49-433b-b9ce-33fae269aec5"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGAQAWJmIL4W+lyWKYTH4b3okd03Tqse+A8Gugd2v9rj3NCl
dID5uf5NwY9ScPFurbaK/6/UDjCgAD2HXWD1RnDxC1Bzoeod0NQfgKp3QFN/
AOaejxD3OMDUw9zDAnEPXBxivpjDdha9KwaLDA9chZoDdS/cXzBzofQBqPkH
YO6Hmu+A5l+o+8UO7EA1H27/O1TzD6CZ74DDfAc082Hud8Dhfpi70d3jgMM9
cH8CAFdsztw=
    "], 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{13, 14, 2, 1, 9}, {14, 13, 11, 3, 4}, {2, 14, 4, 20, 
       8}, {3, 11, 12, 16, 15}, {18, 6, 5, 7, 17}, {5, 1, 2, 8, 7}, {9, 1, 5, 
       6, 10}, {6, 18, 16, 12, 10}, {13, 9, 10, 12, 11}, {18, 17, 19, 15, 
       16}, {20, 4, 3, 15, 19}, {8, 20, 19, 17, 7}}],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAGJmBkxgDAZ6B3CIO6zezXbzH5M2XB7Clz4AFXdAE3do
8bjtH3lL1UFjc/BkgYPyB2Dq0cQd0MQPoKl3QBOHqXeIu7r+2OaNAgfWCHMZ
9m7QhJuPJu6AJu6Apt4BTRxuPq5wwBVuuMIBV7jh8heBcMAVbhjhjMtfBMIB
V7hhhDMAnZ7aXw==
     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{
  3.855640271923271*^9, 3.855827520583819*^9, 3.856071896880381*^9, {
   3.861682822314341*^9, 3.8616828254978743`*^9}},
 CellLabel->
  "Out[119]=",ExpressionUUID->"5bc1a26f-4356-4377-8dd5-97ed9a71621a"]
}, Open  ]],

Cell["\<\
The jig above can be used to make a rhombic icosahedron, a rhombic \
triacontahedron, an icosahedron, among other models. \
\>", "Text",
 CellChangeTimes->{{3.855660323628811*^9, 
  3.855660380399025*^9}},ExpressionUUID->"24441d7e-0b62-4492-8c72-\
1899dab17f50"],

Cell["\<\
Combining both sets of axes for our generators gives a jig body that is a \
Buckyball with irregular hexagons:\
\>", "Text",
 CellChangeTimes->{{3.855643117950259*^9, 3.855643140947105*^9}, {
  3.855658667526911*^9, 3.855658696194034*^9}, {3.855727106650275*^9, 
  3.855727112583778*^9}},ExpressionUUID->"b7df3bbd-d2ca-424b-86d2-\
b6537acbbd9d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"Join", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"PolyhedronData", "[", 
      RowBox[{"\"\<Icosahedron\>\"", ",", "\"\<VertexCoordinates\>\""}], 
      "]"}], ",", 
     RowBox[{"PolyhedronData", "[", 
      RowBox[{"\"\<Dodecahedron\>\"", ",", "\"\<VertexCoordinates\>\""}], 
      "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "star", "]"}]}], "Input",
 CellChangeTimes->{{3.85563749515095*^9, 3.855637544262084*^9}, {
   3.8556380920606613`*^9, 3.8556380960848217`*^9}, {3.8556381882302*^9, 
   3.855638189238912*^9}, {3.8556383689887342`*^9, 3.855638374899458*^9}, {
   3.855638412395669*^9, 3.8556384167631207`*^9}, {3.855638808887814*^9, 
   3.8556388460389433`*^9}, {3.855638915064519*^9, 3.855638941914418*^9}, {
   3.85563908215079*^9, 3.855639083895178*^9}, {3.855639126100025*^9, 
   3.855639127944468*^9}, {3.855639747690493*^9, 3.85563975244311*^9}, 
   3.855640226528442*^9, {3.855640266282907*^9, 3.855640294586144*^9}, {
   3.855642975131096*^9, 3.855642992274358*^9}, {3.855643072996529*^9, 
   3.855643078025722*^9}, 3.8556604032391863`*^9, 3.856071906345834*^9, {
   3.856071973378243*^9, 3.856071976313992*^9}},
 CellLabel->
  "In[120]:=",ExpressionUUID->"f8440ec4-95c3-4b38-b0c1-4403e85ee8f6"],

Cell[BoxData["32"], "Output",
 CellChangeTimes->{
  3.855643080485177*^9, 3.855658717027832*^9, 3.8558275265615673`*^9, {
   3.85607190145897*^9, 3.8560719083144913`*^9}, 3.856071985685199*^9, 
   3.861682854326727*^9},
 CellLabel->
  "Out[121]=",ExpressionUUID->"83410ec0-8f0d-416f-8fc2-5cc47a4cbc56"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody2", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}, {3.861682856816519*^9, 3.861682864205388*^9}},
 CellLabel->
  "In[126]:=",ExpressionUUID->"4a428e7f-11bd-434a-81c1-8cba436c6cbb"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJxtlF1Ik2EUx5d5U63oO5UKVy5mY7llH2jiznVFaxISKcGENSvs7SZIYqOC
1ItSBllE26JdSxGsorB2vLJCiFKHEEF+VNBtLChKGz3/88Tz4gvvzZ/D+fid
/3lcHVZLtMzhcDSV/qWlPx1Iu14cWE69h8+ONdbVcPZNU/vjrIfiR8pvHnz6
O58pPJwb6vdyIBawXDPVVL2/5rpVWcszzV3Orx828W6lc6atxz9/so5bPGsj
r+IruXAxd2d1+xIOR7c+OBH2UqL520ios5zqEQ+dL5k6/Uj2JRs3VrID38K/
z8cuVZc+m3UJdek46k6putQx6E06q7Zzj5qLpM/0ttDsaK7Ur5qLJtHnmWuZ
QXeDm6SucAAf7gOf+0rnhOITTIOP5N88sG/dVa+LYvWJNc7vFSTxr59HGs7f
qqIdz4r93TGP7qdr6O3eR4fW8zH0r6rvopEbvlyobCE4h3lFl3lbVbz0T8Ln
i4rXPH8qnnouybMFfXaqPvVco2afsneOKJ4kHCT/XcWThAP2TrZ42mOLt/Gn
iqlfbfee+KQf+oi9jNPwsrEVbs1t2uaruPKP5r8BecCfJc975HFjrk/Qz006
B3ZeKOb/FI/W3l7lp3HoltKDok+gz9NqXxTGvsSfL9W+8tPYl+i2eBJ9GPG4
I5qHDv9w1PQPwT8sHOQewY1PIR58CPPqeMxLKfPedf4ruPcU9iL5Q7jTbnCW
vdv8SeIrm5+1bpmceWJxzqLr++01/cYp3K/4TfZ12bzH//eO+7XNyzZu4gd6
B242n8h98ax5X/rdk3kL5nui3zGpK/sVf2YX3y/7wfkvWgZieQ==
    "], 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{40, 42, 41, 6, 39}, {34, 44, 43, 26, 27}, {37, 35, 36, 7,
         38}, {31, 32, 23, 22, 30}, {56, 58, 3, 4, 57}, {59, 45, 54, 55, 
        60}, {25, 24, 1, 2, 49}, {21, 46, 47, 17, 18}, {8, 9, 19, 20, 12}, {
        11, 33, 52, 53, 10}, {28, 5, 15, 16, 29}, {50, 13, 14, 48, 51}, {4, 
        54, 45, 6, 41, 57}, {11, 42, 40, 44, 34, 33}, {25, 32, 31, 9, 8, 
        24}, {59, 17, 47, 39, 6, 45}, {44, 40, 39, 47, 46, 43}, {57, 41, 42, 
        11, 10, 56}, {58, 56, 10, 53, 38, 7}, {30, 5, 28, 19, 9, 31}, {13, 36,
         35, 22, 23, 14}, {58, 7, 36, 13, 50, 3}, {17, 59, 60, 2, 1, 18}, {43,
         46, 21, 12, 20, 26}, {1, 24, 8, 12, 21, 18}, {22, 35, 37, 15, 5, 
        30}, {37, 38, 53, 52, 16, 15}, {26, 20, 19, 28, 29, 27}, {34, 27, 29, 
        16, 52, 33}, {54, 4, 3, 50, 51, 55}, {23, 32, 25, 49, 48, 14}, {60, 
        55, 51, 48, 49, 2}}],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJyFlL1LA0EQxY8IKQQhKApRgiQgKn6ACNaDErGTJCjY6HlgpRBMZ6GV2KUS
OxtjFSKopLAQw6QRsbdQ/wcLwcLGD+52BnznkIVjud/Nvtude++yQbm4lfA8
j36vLi8+ZsMxzQanxm3y+Ssxoc+j+yF2nIDT4dLr8trLCI01S8ep9jBLPXAC
zlBPwKWe1p8u75vXKb7o656pXo2rPnACTlBPwFV/8NE/ea9P6Xkre/sH8/Wk
cALOfk9utbDSy0eLN5/5uUnedfXASfjddvvj7HuUzgdo4bSc5cr/nITLe6Re
6oDr+nS4zww/bLztlKr93Io4Ayfh0bkyJPWiA1z1N8Nz5bQPoiNzze3TnRe5
9IGdDoOO9kl0ZD1w3X8Q9Zmg/8j1vZbPrVxYPrdyYfm2g8+tXMRyZPm2g8+t
XMRyZPncyoVv9Nk3vovzEYPPkUsuNB/gc+S6Pg2+bf3NBUEuxOcMPmfgqm/5
VmbwOXL1sZUj6RP4nIDr/gPjPxMY/6UfIZ9+JQ==
     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True},
  ViewPoint->{-2.722467489510636, -2.0056806831881078`, -0.12416024179961284`},
  ViewVertical->{-0.82373805623906, 
   0.15983983011862937`, -0.5439732010045557}]], "Output",
 CellChangeTimes->{
  3.8556430900059223`*^9, 3.855658720820983*^9, 3.855827531201936*^9, 
   3.856071911423555*^9, 3.856071987961668*^9, {3.861682857535678*^9, 
   3.861682864827859*^9}},
 CellLabel->
  "Out[127]=",ExpressionUUID->"8dd0abf1-b8df-4fec-bd7e-9e69b9563660"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Jig axes are vertices of Cube and/or Octahedron", "Subsection",
 CellChangeTimes->{{3.855640015637751*^9, 3.855640019398101*^9}, {
  3.855642919638413*^9, 
  3.855642928790169*^9}},ExpressionUUID->"084d98e7-18db-487f-910d-\
98c2513ad9d7"],

Cell["The jig body for either of these is just the dual.", "Text",
 CellChangeTimes->{{3.855643200073801*^9, 
  3.855643230125321*^9}},ExpressionUUID->"709193f6-44be-4834-9208-\
dea35d91d514"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"PolyhedronData", "[", 
    RowBox[{"\"\<Cube\>\"", ",", "\"\<VertexCoordinates\>\""}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "star", "]"}]}], "Input",
 CellChangeTimes->{{3.85563749515095*^9, 3.855637544262084*^9}, {
   3.8556380920606613`*^9, 3.8556380960848217`*^9}, {3.8556381882302*^9, 
   3.855638189238912*^9}, {3.8556383689887342`*^9, 3.855638374899458*^9}, {
   3.855638412395669*^9, 3.8556384167631207`*^9}, {3.855638808887814*^9, 
   3.8556388460389433`*^9}, {3.855638915064519*^9, 3.855638941914418*^9}, {
   3.85563908215079*^9, 3.855639083895178*^9}, {3.855639126100025*^9, 
   3.855639127944468*^9}, {3.855639747690493*^9, 3.85563975244311*^9}, 
   3.855640226528442*^9, {3.855640266282907*^9, 3.855640294586144*^9}, {
   3.856072007079986*^9, 3.856072009694702*^9}},
 CellLabel->
  "In[593]:=",ExpressionUUID->"b31b4a7e-f2f7-434f-b2e9-169dd2b90cea"],

Cell[BoxData["8"], "Output",
 CellChangeTimes->{{3.8556375284607677`*^9, 3.855637545398603*^9}, 
   3.855638098428989*^9, 3.8556381384299498`*^9, 3.855638190369357*^9, 
   3.855638376270917*^9, 3.8556384175415783`*^9, 3.855638705146554*^9, {
   3.8556388116244307`*^9, 3.855638846772299*^9}, {3.855638920169354*^9, 
   3.855638943523416*^9}, 3.855639084842663*^9, 3.855639131437209*^9, {
   3.85563974002225*^9, 3.855639752999628*^9}, 3.855640227626932*^9, {
   3.855640268597116*^9, 3.855640295840948*^9}, 3.8558275445639973`*^9, 
   3.8560718808440866`*^9, 3.856072010325819*^9},
 CellLabel->
  "Out[594]=",ExpressionUUID->"e62025ba-182f-4032-9758-a284d141ac32"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}},
 CellLabel->
  "In[595]:=",ExpressionUUID->"fd9901f3-0965-4027-b1a4-a94273185bc5"],

Cell[BoxData[
 Graphics3DBox[{
   GraphicsComplex3DBox[{{0., 0., 25.980762113533153`}, {-25.980762113533153`,
     0., 0.}, {0., -25.980762113533153`, 0.}, {25.980762113533153`, 0., 0.}, {
    0., 0., -25.980762113533153`}, {0., 25.980762113533153`, 0.}}, 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{5, 3, 2}, {3, 5, 4}, {3, 1, 2}, {1, 3, 4}, {5, 6, 4}, {6,
        5, 2}, {6, 1, 4}, {1, 6, 2}}],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGAQAGJmIF4s5uA8J1/xAJG0AwE+ujg6Tax5uPThkieWJtZe
Qv4nNhwIygMAn+mNPw==
     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{3.8556402986454353`*^9, 3.8558275492593107`*^9, 
  3.856071882418483*^9, 3.856072012193523*^9},
 CellLabel->
  "Out[596]=",ExpressionUUID->"bf5fa9bc-7909-4673-8e2e-7cfe59d9a137"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"PolyhedronData", "[", 
    RowBox[{"\"\<Octahedron\>\"", ",", "\"\<VertexCoordinates\>\""}], "]"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "star", "]"}]}], "Input",
 CellChangeTimes->{{3.85563749515095*^9, 3.855637544262084*^9}, {
   3.8556380920606613`*^9, 3.8556380960848217`*^9}, {3.8556381882302*^9, 
   3.855638189238912*^9}, {3.8556383689887342`*^9, 3.855638374899458*^9}, {
   3.855638412395669*^9, 3.8556384167631207`*^9}, {3.855638808887814*^9, 
   3.8556388460389433`*^9}, {3.855638915064519*^9, 3.855638941914418*^9}, {
   3.85563908215079*^9, 3.855639083895178*^9}, {3.855639126100025*^9, 
   3.855639127944468*^9}, {3.855639747690493*^9, 3.85563975244311*^9}, 
   3.855640226528442*^9, {3.855640266282907*^9, 3.855640267381486*^9}, {
   3.855640304258225*^9, 3.855640305395232*^9}, {3.8560720168320837`*^9, 
   3.856072018958733*^9}},
 CellLabel->
  "In[597]:=",ExpressionUUID->"2f4da7e9-0807-4ed0-a887-569e85521de4"],

Cell[BoxData["6"], "Output",
 CellChangeTimes->{{3.8556375284607677`*^9, 3.855637545398603*^9}, 
   3.855638098428989*^9, 3.8556381384299498`*^9, 3.855638190369357*^9, 
   3.855638376270917*^9, 3.8556384175415783`*^9, 3.855638705146554*^9, {
   3.8556388116244307`*^9, 3.855638846772299*^9}, {3.855638920169354*^9, 
   3.855638943523416*^9}, 3.855639084842663*^9, 3.855639131437209*^9, {
   3.85563974002225*^9, 3.855639752999628*^9}, 3.855640227626932*^9, 
   3.855640268597116*^9, 3.855640306806253*^9, 3.8558275528040457`*^9, 
   3.8560718754319563`*^9, 3.856072019454754*^9},
 CellLabel->
  "Out[598]=",ExpressionUUID->"f3506a7c-75e7-433f-b030-fe8c4b508754"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}},
 CellLabel->
  "In[599]:=",ExpressionUUID->"e6ac2073-4ca5-47cd-90eb-bc82cb180941"],

Cell[BoxData[
 Graphics3DBox[{
   GraphicsComplex3DBox[{{-15., 15., 15.}, {15., 15., 15.}, {-15., -15., 
    15.}, {15., -15., 15.}, {-15., 15., -15.}, {15., 
    15., -15.}, {-15., -15., -15.}, {15., -15., -15.}}, 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{1, 3, 4, 2}, {1, 2, 6, 5}, {2, 4, 8, 6}, {3, 1, 5, 7}, {
       4, 3, 7, 8}, {5, 6, 8, 7}}],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], 
    Point3DBox[{{-15.1, 0., 0.}, {0., 15.1, 0.}, {0., 0., -15.1}, {0., 0., 
     15.1}, {0., -15.1, 0.}, {15.1, 0., 0.}, {15.1, 0., 0.}, {0., -15.1, 
     0.}, {0., 0., 15.1}, {0., 0., -15.1}, {0., 15.1, 0.}, {-15.1, 0., 0.}}]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{3.855640308968149*^9, 3.855827556609132*^9, 
  3.856071877422546*^9, 3.85607202187796*^9},
 CellLabel->
  "Out[600]=",ExpressionUUID->"d87d96a7-9d6b-4275-89af-93827da53337"]
}, Open  ]],

Cell["\<\
We combine these below, to get a truncated octahedral jig body:\
\>", "Text",
 CellChangeTimes->{{3.8556430209849586`*^9, 
  3.855643039088523*^9}},ExpressionUUID->"96ddf636-b6b2-4603-98ca-\
9edcb7fe93c9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"PolyhedronData", "[", 
      RowBox[{"\"\<Cube\>\"", ",", "\"\<VertexCoordinates\>\""}], "]"}], ",", 
     
     RowBox[{"PolyhedronData", "[", 
      RowBox[{"\"\<Octahedron\>\"", ",", "\"\<VertexCoordinates\>\""}], 
      "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "star", "]"}]}], "Input",
 CellChangeTimes->{{3.85563749515095*^9, 3.855637544262084*^9}, {
   3.8556380920606613`*^9, 3.8556380960848217`*^9}, {3.8556381882302*^9, 
   3.855638189238912*^9}, {3.8556383689887342`*^9, 3.855638374899458*^9}, {
   3.855638412395669*^9, 3.8556384167631207`*^9}, {3.855638808887814*^9, 
   3.8556388460389433`*^9}, {3.855638915064519*^9, 3.855638941914418*^9}, {
   3.85563908215079*^9, 3.855639083895178*^9}, {3.855639126100025*^9, 
   3.855639127944468*^9}, {3.855639747690493*^9, 3.85563975244311*^9}, 
   3.855640226528442*^9, {3.855640266282907*^9, 3.855640294586144*^9}, {
   3.855642975131096*^9, 3.855642992274358*^9}, {3.856072029967328*^9, 
   3.856072034335095*^9}},
 CellLabel->
  "In[601]:=",ExpressionUUID->"8bf06040-3834-4215-87ca-c272ef6a7b83"],

Cell[BoxData["14"], "Output",
 CellChangeTimes->{3.85564299441928*^9, 3.855659368256597*^9, 
  3.855827560579088*^9, 3.855827877900351*^9, 3.856072035918149*^9},
 CellLabel->
  "Out[602]=",ExpressionUUID->"21c41045-8966-4917-a3d0-7fff745aca5c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}},
 CellLabel->
  "In[603]:=",ExpressionUUID->"1219a96f-8130-401b-90c4-bd1718679c03"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAGJmIN7Xv7RY7ZvqAQYUoOcApeHiUHUO6OrQ9aOq0zuA
Kq+Hrv8AdnPR3YVwB3ZzcZuHbj+a+3D5B10/hjp0/TB16P7HYf4BdH3o/sBh
Pg59uP1BajjiCld0/TB1AOd/dac=
    "], 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{19, 1, 10, 13}, {3, 5, 20, 11}, {9, 21, 8, 15}, {16, 18, 
        12, 14}, {4, 17, 7, 23}, {2, 6, 24, 22}, {6, 2, 1, 19, 20, 5}, {17, 4,
         3, 11, 12, 18}, {20, 19, 13, 14, 12, 11}, {10, 9, 15, 16, 14, 13}, {
        18, 16, 15, 8, 7, 17}, {1, 2, 22, 21, 9, 10}, {3, 4, 23, 24, 6, 5}, {
        23, 7, 8, 21, 22, 24}}],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIF4s5uA8J1/xAJG0AwE+ujg6Tax5uPRhyBuDgd4B
BhwAKu9AQB5DP7o+dHW4zCXgD0L+wuVPQvFBbLwQlCc3vAiFC6Hww2UuAIog
o8s=
     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True},
  ViewPoint->{1.2193686194904212`, -2.3486484825337177`, 2.108788864560435},
  ViewVertical->{0.01241397726604419, 0.05150390496315752, 
   0.998595634349552}]], "Output",
 CellChangeTimes->{3.855643008369791*^9, 3.85565937045415*^9, 
  3.855827563178871*^9, 3.8558278796490088`*^9, 3.8560720381170177`*^9},
 CellLabel->
  "Out[604]=",ExpressionUUID->"09f63991-06ae-4a6f-8166-b646739dbf3a"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Finally",
  FontWeight->"Bold"],
 ": Combining cube or octahedron axes with dodecahedron or icosahedron axes \
(in their default positions in space) produces some bizarre bodies. For \
instance:"
}], "Text",
 CellChangeTimes->{{3.855658926016604*^9, 3.855658944632803*^9}, {
  3.8556595865254793`*^9, 3.855659643371422*^9}, {3.855659715553389*^9, 
  3.855659716161305*^9}, {3.855726428352404*^9, 3.855726436992311*^9}, {
  3.855726561394986*^9, 3.85572658896266*^9}, {3.855827919149386*^9, 
  3.8558279195335207`*^9}},ExpressionUUID->"9bead9ef-7512-4630-bf8a-\
ab4972fe0e75"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cube", "=", 
      RowBox[{"PolyhedronData", "[", 
       RowBox[{"\"\<Cube\>\"", ",", "\"\<MeshRegion\>\""}], "]"}]}], ",", 
     RowBox[{"icos", "=", 
      RowBox[{"PolyhedronData", "[", 
       RowBox[{"\"\<Icosahedron\>\"", ",", "\"\<MeshRegion\>\""}], "]"}]}]}], 
    "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"MeshRegion", "[", 
      RowBox[{
       RowBox[{"Normalize", "/@", 
        RowBox[{"MeshCoordinates", "[", "cube", "]"}]}], ",", 
       RowBox[{"MeshCells", "[", 
        RowBox[{"cube", ",", "2"}], "]"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"MeshRegion", "[", 
      RowBox[{
       RowBox[{"Normalize", "/@", 
        RowBox[{"MeshCoordinates", "[", "icos", "]"}]}], ",", 
       RowBox[{"MeshCells", "[", 
        RowBox[{"icos", ",", "2"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.855827601521764*^9, 3.8558277862272778`*^9}},
 CellLabel->
  "In[550]:=",ExpressionUUID->"f5613b32-29d2-4bb1-be31-fe372f6225c4"],

Cell[BoxData[
 Graphics3DBox[{
   GraphicsComplex3DBox[{{-0.5773502691896258, -0.5773502691896258, \
-0.5773502691896258}, {-0.5773502691896258, -0.5773502691896258, 
    0.5773502691896258}, {-0.5773502691896258, 
    0.5773502691896258, -0.5773502691896258}, {-0.5773502691896258, 
    0.5773502691896258, 0.5773502691896258}, {
    0.5773502691896258, -0.5773502691896258, -0.5773502691896258}, {
    0.5773502691896258, -0.5773502691896258, 0.5773502691896258}, {
    0.5773502691896258, 0.5773502691896258, -0.5773502691896258}, {
    0.5773502691896258, 0.5773502691896258, 0.5773502691896258}}, 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{8, 2, 1}, {2, 8, 4}, {8, 1, 4}, {1, 2, 4}, {6, 1, 8}, {1,
        6, 2}, {6, 8, 2}, {6, 1, 5}, {6, 5, 8}, {5, 1, 8}, {1, 7, 5}, {7, 1, 
       8}, {5, 7, 8}, {8, 7, 3}, {7, 1, 3}, {1, 8, 3}, {3, 1, 4}, {8, 3, 4}}],
      
      Annotation[#, "Geometry"]& ]}], 
   GraphicsComplex3DBox[{{0., 0., -1.}, {0., 0., 1.}, {-0.894427190999916, 
    0., -0.44721359549995787`}, {0.894427190999916, 0., 
    0.44721359549995787`}, {
    0.7236067977499789, -0.5257311121191336, -0.44721359549995787`}, {
    0.7236067977499789, 
    0.5257311121191336, -0.44721359549995787`}, {-0.7236067977499789, \
-0.5257311121191336, 0.44721359549995787`}, {-0.7236067977499789, 
    0.5257311121191336, 
    0.44721359549995787`}, {-0.276393202250021, -0.85065080835204, \
-0.44721359549995787`}, {-0.276393202250021, 
    0.85065080835204, -0.44721359549995787`}, {
    0.276393202250021, -0.85065080835204, 0.44721359549995787`}, {
    0.276393202250021, 0.85065080835204, 0.44721359549995787`}}, 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{6, 4, 5}, {4, 6, 12}, {6, 5, 12}, {5, 4, 12}, {5, 12, 
       11}, {12, 5, 7}, {5, 11, 7}, {11, 12, 7}, {11, 9, 5}, {9, 11, 7}, {5, 
       9, 7}, {2, 11, 4}, {11, 2, 12}, {2, 4, 12}, {4, 11, 12}, {6, 10, 5}, {
       10, 6, 1}, {6, 5, 1}, {5, 10, 1}, {1, 10, 9}, {10, 1, 3}, {1, 9, 3}, {
       9, 10, 3}, {3, 8, 10}, {8, 3, 7}, {3, 10, 7}, {10, 8, 7}, {12, 8, 2}, {
       8, 12, 7}, {12, 2, 7}, {2, 8, 7}, {1, 5, 9}, {5, 10, 9}, {3, 9, 7}, {9,
        10, 7}, {4, 11, 5}, {11, 2, 7}, {10, 5, 8}, {5, 6, 8}, {6, 10, 8}, {
       10, 12, 6}, {12, 10, 8}, {6, 12, 8}, {5, 12, 8}, {8, 5, 7}, {5, 10, 
       7}}],
      Annotation[#, "Geometry"]& ]}]},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{{3.855827745560664*^9, 3.8558277881387377`*^9}, 
   3.856071841400124*^9},
 CellLabel->"Out[550]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>", "ImageResolution" -> \
144.],ExpressionUUID->"bd737829-c0a0-41d3-8755-24e8be669adf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"Join", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"PolyhedronData", "[", 
      RowBox[{"\"\<Icosahedron\>\"", ",", "\"\<VertexCoordinates\>\""}], 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PolyhedronData", "[", 
      RowBox[{"\"\<Cube\>\"", ",", "\"\<VertexCoordinates\>\""}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "star", "]"}]}], "Input",
 CellChangeTimes->{{3.85563749515095*^9, 3.855637544262084*^9}, {
   3.8556380920606613`*^9, 3.8556380960848217`*^9}, {3.8556381882302*^9, 
   3.855638189238912*^9}, {3.8556383689887342`*^9, 3.855638374899458*^9}, {
   3.855638412395669*^9, 3.8556384167631207`*^9}, {3.855638808887814*^9, 
   3.8556388460389433`*^9}, {3.855638915064519*^9, 3.855638941914418*^9}, {
   3.85563908215079*^9, 3.855639083895178*^9}, {3.855639126100025*^9, 
   3.855639127944468*^9}, {3.855639747690493*^9, 3.85563975244311*^9}, 
   3.855640226528442*^9, {3.855640266282907*^9, 3.855640294586144*^9}, {
   3.855642975131096*^9, 3.855642992274358*^9}, {3.855643072996529*^9, 
   3.855643078025722*^9}, {3.855658952745623*^9, 3.855658983358841*^9}, {
   3.8556591759337997`*^9, 3.855659178204817*^9}, {3.855659210939951*^9, 
   3.855659231243743*^9}, {3.855659274203356*^9, 3.855659302225531*^9}, {
   3.8556593403451366`*^9, 3.855659355417856*^9}, {3.855659559223915*^9, 
   3.855659567958949*^9}, 3.855827857543336*^9, {3.8560720742293367`*^9, 
   3.856072077220264*^9}},
 CellLabel->
  "In[605]:=",ExpressionUUID->"b3faf77a-a80d-4db8-bdb4-c293fbe1187f"],

Cell[BoxData["20"], "Output",
 CellChangeTimes->{
  3.855658990211815*^9, 3.855659179612466*^9, 3.8556592324276323`*^9, {
   3.855659277968747*^9, 3.8556593040254908`*^9}, 3.855659569310258*^9, 
   3.8557261125674477`*^9, {3.855827860272668*^9, 3.8558278893542852`*^9}, 
   3.8559872071287394`*^9, 3.8560718462254353`*^9, 3.856072078165658*^9},
 CellLabel->
  "Out[606]=",ExpressionUUID->"e93c88c9-7703-408f-a398-dafbf6e1bd41"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}},
 CellLabel->
  "In[607]:=",ExpressionUUID->"72ec1ef8-5b25-4a5e-98e6-42a98aea6f8c"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGBQAmJmIN79ao9zQ5eSg4SGa71h7O/9//6DgK7DFuU3H3Ss
/tq7c3dcfeCndIABDPQcNOXm7dl+4u3+22tvf58lqQIXtzt3YtKyIjmHd9vX
FvC7GDgIPZ6mfPESwwGhNbt1Vy8ScdjBonfFYJGhg9jBdRf3NHIeUFli8FEu
VP3AWoXstu+LtRwer5tz4P+F9/uFMl4ctt2kfyBGSWRD8mQFhxItj7/qLX/3
66Da6wCzVwBi/oFtEPMPiEDMh7nnwFuIew4IQtzjALXXAWrvAai99iIQex2g
9h6A2msPdY9DNKp77JWg5qyBuv8h1Jyd0HBzg4Sbw39oeO6BhrMwJJztYe7f
BRY3gvqHgeFC6HNZphCeA1DxAzDx8xBxB2g42KOFwwG2/NJa7XINuDm7FQy+
/arTPrCvf2mx2jdVuDhMPVp8HYDFlzBqfMHC84Amqr2weIeZfwDNfAcWiHvg
4jsh7oGFwwG0cDgATW/7oekN7i+0+HXAEb8OsPhFSz+weNwPja8D0Pg6AI2v
/Wju2Q+zdxeqew4wQcUBYaJYYg==
    "], 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{2, 11, 12, 1}, {16, 13, 14, 15}, {27, 7, 6, 28}, {32, 31,
         33, 34}, {1, 12, 17, 13, 16}, {7, 27, 33, 31, 18}, {9, 3, 25, 26, 
        10}, {18, 31, 32, 10, 26}, {23, 24, 21, 20, 22}, {12, 11, 22, 20, 
        17}, {13, 17, 20, 4, 14}, {21, 19, 5, 4, 20}, {25, 8, 29, 30, 26}, {7,
         18, 26, 30, 6}, {2, 3, 9, 23, 22, 11}, {23, 9, 10, 32, 34, 24}, {5, 
        29, 8, 15, 14, 4}, {19, 28, 6, 30, 29, 5}, {3, 2, 1, 16, 15, 8, 25}, {
        21, 24, 34, 33, 27, 28, 19}}],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGDQAGJmBkxgDAZ6B3CIO6zezXbzH5M2XB7Clz4AFXdAE3do
8bjtH3lL1UFjc/BkgYPyB2Dq0cQd0MQPoKl3QBOHqXeIu7r+2OaNAgfWCHMZ
9m7QhJuPJu6AJu6Apt4BTRxu/mIxB+c5+YoHiKTR1ePS74CDJtY8XPow5HHF
I654xxWPuOIdV7wQiEdc8Y6RTnDFC4F4xBXvGOmEQLgSCmdc+gmlD2LTCUF5
AKLQZf4=
     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{3.8560718594093237`*^9, 3.856072080399496*^9},
 CellLabel->
  "Out[608]=",ExpressionUUID->"4a26652c-48e2-4b62-a28e-b5ddf14cc719"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Jig for building polar zonohedra", "Subsection",
 CellChangeTimes->{{3.855640039188676*^9, 3.85564005498094*^9}, {
  3.855640393835045*^9, 3.8556404027544947`*^9}, {3.855826405883655*^9, 
  3.855826409907357*^9}, {3.855827185319274*^9, 
  3.855827188435409*^9}},ExpressionUUID->"6d5476fd-948a-42e4-bf30-\
1080646e8da4"],

Cell[TextData[{
 "Take ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],ExpressionUUID->
  "d35c3c74-b6ce-4820-962a-5113dbbb98c4"],
 " CirclePoints (points in the plane evenly spaced around the unit circle), \
and Append a common z-coordinate to each. For example, below we use the \
z-coordinate ",
 Cell[BoxData[
  FormBox[
   RowBox[{"tan", "(", 
    RowBox[{"42", "\[Degree]"}], ")"}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "ac89ec6c-fc25-4a82-89b4-157ad058c8df"],
 " to achieve a rise angle of 42 degrees for the \[OpenCurlyDoubleQuote]ribs\
\[CloseCurlyDoubleQuote] of the zonohedron."
}], "Text",
 CellChangeTimes->{{3.8556422872667913`*^9, 3.855642373798999*^9}, {
  3.855642660356523*^9, 3.855642660708477*^9}, {3.855643811132907*^9, 
  3.8556438351618967`*^9}, {3.8556583212448673`*^9, 3.8556583306766357`*^9}, {
  3.8557267935756683`*^9, 3.855726828702993*^9}, {3.855826766996729*^9, 
  3.855826824035833*^9}, {3.855987347841113*^9, 3.855987387418235*^9}, {
  3.855989245867339*^9, 3.855989326516281*^9}, {3.85599732798104*^9, 
  3.855997330485285*^9}},ExpressionUUID->"27fe1def-337a-4df2-a6a1-\
e2cb491fdfe2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"star", "=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", "=", "7"}], ",", 
      RowBox[{"z0", "=", 
       RowBox[{"Tan", "[", 
        RowBox[{"42", " ", "Degree"}], "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Append", "[", 
       RowBox[{"#", ",", "z0"}], "]"}], "&"}], "/@", 
     RowBox[{"CirclePoints", "[", "n", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8556391920091467`*^9, 3.855639202273176*^9}, 
   3.855639239558659*^9, {3.85563971362216*^9, 3.855639714187256*^9}, {
   3.855640415293953*^9, 3.855640424912155*^9}, {3.855826842311041*^9, 
   3.855826958081443*^9}, 3.855827003425557*^9, {3.855827118585032*^9, 
   3.85582713251301*^9}, {3.855837451375847*^9, 3.855837472599572*^9}, 
   3.855837637765045*^9, {3.855896778585043*^9, 3.855896809685747*^9}, {
   3.855896846462503*^9, 3.855896847036433*^9}, {3.855896929884576*^9, 
   3.85589695454008*^9}, {3.855896984796032*^9, 3.855896985386812*^9}, {
   3.855897070922557*^9, 3.8558970711529827`*^9}, {3.855897124033469*^9, 
   3.855897159791606*^9}, 3.855898106653125*^9, {3.855900546418003*^9, 
   3.855900581552004*^9}, {3.855900627138372*^9, 3.8559006587761517`*^9}, {
   3.855900733053557*^9, 3.8559007334041777`*^9}},
 CellLabel->
  "In[135]:=",ExpressionUUID->"40dad83e-841f-4939-af08-09f209e4f3a7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sin", "[", 
      FractionBox["\[Pi]", "7"], "]"}], ",", 
     RowBox[{"-", 
      RowBox[{"Cos", "[", 
       FractionBox["\[Pi]", "7"], "]"}]}], ",", 
     RowBox[{"Tan", "[", 
      RowBox[{"42", " ", "\[Degree]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", 
      FractionBox["\[Pi]", "14"], "]"}], ",", 
     RowBox[{"-", 
      RowBox[{"Sin", "[", 
       FractionBox["\[Pi]", "14"], "]"}]}], ",", 
     RowBox[{"Tan", "[", 
      RowBox[{"42", " ", "\[Degree]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", 
      FractionBox[
       RowBox[{"3", " ", "\[Pi]"}], "14"], "]"}], ",", 
     RowBox[{"Sin", "[", 
      FractionBox[
       RowBox[{"3", " ", "\[Pi]"}], "14"], "]"}], ",", 
     RowBox[{"Tan", "[", 
      RowBox[{"42", " ", "\[Degree]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", 
     RowBox[{"Tan", "[", 
      RowBox[{"42", " ", "\[Degree]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"3", " ", "\[Pi]"}], "14"], "]"}]}], ",", 
     RowBox[{"Sin", "[", 
      FractionBox[
       RowBox[{"3", " ", "\[Pi]"}], "14"], "]"}], ",", 
     RowBox[{"Tan", "[", 
      RowBox[{"42", " ", "\[Degree]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Cos", "[", 
       FractionBox["\[Pi]", "14"], "]"}]}], ",", 
     RowBox[{"-", 
      RowBox[{"Sin", "[", 
       FractionBox["\[Pi]", "14"], "]"}]}], ",", 
     RowBox[{"Tan", "[", 
      RowBox[{"42", " ", "\[Degree]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sin", "[", 
       FractionBox["\[Pi]", "7"], "]"}]}], ",", 
     RowBox[{"-", 
      RowBox[{"Cos", "[", 
       FractionBox["\[Pi]", "7"], "]"}]}], ",", 
     RowBox[{"Tan", "[", 
      RowBox[{"42", " ", "\[Degree]"}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8558269591422663`*^9, 3.855827004378108*^9, {3.8558271195161963`*^9, 
   3.8558271333979692`*^9}, 3.855837097546624*^9, {3.855837451997367*^9, 
   3.8558374729630823`*^9}, 3.8558376384270973`*^9, {3.85589678760076*^9, 
   3.855896810754484*^9}, 3.855896847870866*^9, {3.855896930355266*^9, 
   3.855896955224524*^9}, 3.855896986075995*^9, 3.85589707236052*^9, {
   3.855897125178627*^9, 3.855897160263031*^9}, 3.855898107983222*^9, {
   3.855900547888178*^9, 3.8559005820343113`*^9}, {3.85590062790714*^9, 
   3.855900659247641*^9}, 3.855900734061028*^9, 3.856071817736699*^9, 
   3.861683064510034*^9},
 CellLabel->
  "Out[135]=",ExpressionUUID->"1fd09c71-9174-490f-a4f7-016318b506d3"]
}, Open  ]],

Cell["A quick preview of the resulting polar zonohedron:", "Text",
 CellChangeTimes->{{3.8558373056433907`*^9, 3.85583731630729*^9}, {
  3.856072122774354*^9, 
  3.8560721252038937`*^9}},ExpressionUUID->"f7d345f8-a358-4dce-9d98-\
5a8c41aa49e3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"n", "=", "7"}], "}"}], ",", 
   RowBox[{"(*", " ", 
    RowBox[{"warning", ":", " ", 
     RowBox[{
     "computation", " ", "time", " ", "increases", " ", "exponentially", " ", 
      "with", " ", "n"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cubeVertices", "=", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Chop", "[", 
          RowBox[{"N", "[", 
           RowBox[{"Transpose", "[", "star", "]"}], "]"}], "]"}], ".", "#"}], 
        "&"}], ",", 
       RowBox[{"Tuples", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}], ",", "n"}], "]"}]}], "]"}]}], ";", 
    "\n", 
    RowBox[{"ConvexHullMesh", "[", "cubeVertices", "]"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.855837124336564*^9, 3.8558371417182837`*^9}, {
   3.8558372169536657`*^9, 3.855837229456891*^9}, 3.855837282012298*^9, {
   3.85583742643093*^9, 3.855837467687697*^9}, {3.855837525439165*^9, 
   3.855837599145073*^9}, {3.855896816222617*^9, 3.855896816316926*^9}, {
   3.85589685113412*^9, 3.855896852245302*^9}, 3.855896925725212*^9, {
   3.855897075969551*^9, 3.85589707614548*^9}, {3.855897130680736*^9, 
   3.855897163448997*^9}, {3.855898112372815*^9, 3.855898114147593*^9}, 
   3.855900543050537*^9, 3.855900632010063*^9},
 CellLabel->
  "In[158]:=",ExpressionUUID->"da3302a2-f98d-4ce2-851b-30db897e14d0"],

Cell[BoxData[
 Graphics3DBox[
  TagBox[
   DynamicModuleBox[{Typeset`mesh = HoldComplete[
     BoundaryMeshRegion[CompressedData["
1:eJxTTMoPSmViYGDQAWJmBtzg4OpC3wNHbu8vjDm9cs+VN/vjHfJUZC68sc98
GcE6x+j9/iZXpscTqs/AxZfe5xCr6/q2/+U318ILPz9Cxf/Ye99jLT3M8nL/
xbfdjxZ8fmwPU38rWX/veuk/+x/umBZcufKmPUx96nPXF/ltjAcgrniw331D
kLToHFYHVNd9gJsDM/8F2N6fcHNg5lusexoSl/XNHmYOzPx//0HgPlQ9jwPU
HHt0d8LE0c2HuQQizugAMx8WPhMuiSaLGzE4wMyHhQ9E/Ud76xdHpgkyCcHU
26OHJ9T99ujhAxNH9xfMHHR7Ye4sAMfjH7i9sPjNh8Qv1BxRmLg9erzDzIGI
/4HHbwbUvxMh9h6AuQct/PfD3AMTfwzx136Ye2Dm1EDCAe4eaLjZo6erLKh/
0e2FuHKCDUQ94wGYvV7QdPIKEo9we2HilyDxvh9mLzSdODCipUNY+Fui+csH
mk7QzYe4Z8UeiDkfMMxHT4cw85+ghQ/MfHR3LoGGD3q6goanPXp47oPGbwFa
vMPcCaEX7AmueDBfwkzSAQAqqtjL
      "], {
       Polygon[{{22, 21, 15, 16}, {21, 22, 44, 43}, {12, 1, 8, 13}, {8, 1, 5, 
        9}, {8, 9, 14, 13}, {12, 13, 19, 18}, {21, 43, 41, 20}, {15, 21, 20, 
        14}, {19, 13, 14, 20}, {22, 16, 28, 44}, {44, 28, 27, 33}, {25, 31, 
        32, 26}, {25, 26, 7, 4}, {33, 27, 26, 32}, {44, 33, 32, 37}, {32, 31, 
        36, 37}, {43, 44, 42, 41}, {44, 37, 36, 40}, {42, 44, 40, 39}, {39, 
        40, 36, 35}, {19, 20, 41, 38}, {18, 19, 38, 34}, {42, 39, 38, 41}, {
        39, 35, 34, 38}, {36, 31, 30, 35}, {34, 35, 30, 29}, {5, 1, 3, 6}, {7,
         6, 3, 4}, {9, 5, 6, 10}, {14, 9, 10, 15}, {1, 12, 18, 17}, {18, 34, 
        29, 17}, {3, 1, 2, 4}, {28, 16, 11, 27}, {7, 26, 27, 11}, {16, 15, 10,
         11}, {6, 7, 11, 10}, {1, 17, 29, 23}, {25, 4, 2, 24}, {31, 25, 24, 
        30}, {2, 1, 23, 24}, {29, 30, 24, 23}}]}, 
      Method -> {
       "EliminateUnusedCoordinates" -> True, "DeleteDuplicateCoordinates" -> 
        Automatic, "DeleteDuplicateCells" -> Automatic, "VertexAlias" -> 
        Identity, "CheckOrientation" -> Automatic, "CoplanarityTolerance" -> 
        Automatic, "CheckIntersections" -> Automatic, 
        "BoundaryNesting" -> {{0, 0}}, "SeparateBoundaries" -> False, 
        "TJunction" -> Automatic, "PropagateMarkers" -> True, "ZeroTest" -> 
        Automatic, "Hash" -> 733819896758870573}]]}, 
    TagBox[GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDQAWJmBtzg4OpC3wNHbu8vjDm9cs+VN/vjHfJUZC68sc98
GcE6x+j9/iZXpscTqs/AxZfe5xCr6/q2/+U318ILPz9Cxf/Ye99jLT3M8nL/
xbfdjxZ8fmwPU38rWX/veuk/+x/umBZcufKmPUx96nPXF/ltjAcgrniw331D
kLToHFYHVNd9gJsDM/8F2N6fcHNg5lusexoSl/XNHmYOzPx//0HgPlQ9jwPU
HHt0d8LE0c2HuQQizugAMx8WPhMuiSaLGzE4wMyHhQ9E/Ud76xdHpgkyCcHU
26OHJ9T99ujhAxNH9xfMHHR7Ye4sAMfjH7i9sPjNh8Qv1BxRmLg9erzDzIGI
/4HHbwbUvxMh9h6AuQct/PfD3AMTfwzx136Ye2Dm1EDCAe4eaLjZo6erLKh/
0e2FuHKCDUQ94wGYvV7QdPIKEo9we2HilyDxvh9mLzSdODCipUNY+Fui+csH
mk7QzYe4Z8UeiDkfMMxHT4cw85+ghQ/MfHR3LoGGD3q6goanPXp47oPGbwFa
vMPcCaEX7AmueDBfwkzSAQAqqtjL
      "], 
      {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
       TagBox[Polygon3DBox[CompressedData["
1:eJxNkVkSgkAMREERVBAXwF0UURSZ03gED6D3/7NT9azy41U6mUyTCdXr83z3
PM97iEAsRSGmYoa2mhOdSIQvhmJCtHwgRuQWU84TYiYW+JlPK3K+U6BT+ibo
nG/bHHtmcOidqMRGHMVJbMktRrynondLj6Nm+kq0+xfyjp4HMzrqdn6n7tA3
uHNeM3/O3YY3Z+gz92/kLbrmrMHH5in/6jX5gT3bvvsi5J0hecDuB9TG7HGE
nnI3Ya458Yz3HB/r6eG3Z/8xe4zY5Y7aDN8x+W+mmJqPr/mv+D8B/mveukGX
1H1619wr0Vb7AqUsEKc=
         "]],
        Annotation[#, "Geometry"]& ]}],
     MouseAppearanceTag["LinkHand"]],
    AllowKernelInitialization->False],
   "MeshGraphics3D",
   AutoDelete->True,
   Editable->False,
   Selectable->False],
  Boxed->False,
  DefaultBaseStyle->{
   "MeshGraphics3D", FrontEnd`GraphicsHighlightColor -> Hue[0.1, 1, 0.7]},
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True},
  ViewPoint->{0.16783445495536922`, 3.2219085325674044`, -1.0203612122670966`},
  ViewVertical->{0.03569111904940513, 
   0.34953243904896963`, -0.9362442085660554}]], "Output",
 CellChangeTimes->{
  3.855837240102097*^9, {3.8558374466861153`*^9, 3.855837475673123*^9}, 
   3.8558376414585657`*^9, 3.855837788951488*^9, {3.855896791446897*^9, 
   3.8558968171630087`*^9}, 3.85589685451383*^9, {3.85589693364417*^9, 
   3.855896957259753*^9}, 3.8558969908673058`*^9, 3.855897076690667*^9, {
   3.8558971311265583`*^9, 3.855897164119471*^9}, 3.8558979305626307`*^9, 
   3.855898115152823*^9, {3.855900556426395*^9, 3.8559005844423122`*^9}, {
   3.855900632315815*^9, 3.855900661283978*^9}, 3.855900736195849*^9},
 CellLabel->"Out[158]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>", "ImageResolution" -> \
144.],ExpressionUUID->"bacb5e75-d661-42f9-9428-c08848b3026d"]
}, Open  ]],

Cell[TextData[{
 "The drill jig needed to make an edge model of this zonohedron (or the \
entire ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "76517196-c3a1-41bb-b6d1-4dbf14b8da60"],
 "-cube projection!):"
}], "Text",
 CellChangeTimes->{{3.855837326571149*^9, 3.855837355507019*^9}, {
  3.855897947026166*^9, 3.855897980688991*^9}, {3.8559893653058968`*^9, 
  3.8559893729697104`*^9}},ExpressionUUID->"b7807275-ecaa-455f-b98c-\
8b334fc58e1e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}},
 CellLabel->
  "In[136]:=",ExpressionUUID->"2de384de-80e9-4da9-a1a5-591b493e4f88"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGAQAGJmBkxQOMfJ6lSW2YHko6fDZbeYHKji4zh295mQw6T3
ZSnp6z/Zo4kfgIrvh4o74FDvgK4eZt/+Bdf2ZNmYOkxFE4eBIoh7HGKbNi2L
mWVwQD5c955ktdaByVDzoeIOUHEHqPh+NPUOE1HFYeoPTIGak/P9367uXKUD
AT/+3+ZSMnaYABVHc+eBqajqHdDVo4kfgIrvRzMfLg4AZo6wyw==
    "], 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{8, 7, 2, 3}, {7, 8, 16, 13}, {8, 3, 1, 16}, {1, 9, 4, 
       5}, {5, 4, 7, 11}, {13, 16, 1, 15}, {7, 13, 15, 11}, {1, 5, 11, 15}, {
       6, 12, 7, 14}, {4, 9, 14, 7}, {9, 1, 6, 14}, {3, 2, 10, 1}, {2, 7, 12, 
       10}, {12, 6, 1, 10}}],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIJbkPq+wplLYYdbCyTW5FioHpiga7dYzVXEI3mqh
GPVQ1eHVXsHkxz+Z4eLe8hbN77sVHTp89n9I/SPtABNngIKFVz/sTCtUc0BT
fwBdPdT8A+jmQ91zAN09aOIwcw6gmQMXR7MXZs4BNHceQFPvgK4eLRzg5qOF
G1wcAJOXh5M=
     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True},
  ViewPoint->{3.1584982410946143`, 0.9123537973486668, 0.8009365826741193},
  ViewVertical->{0.3473965797124924, 0.10635338291156377`, 
   0.9316676308358729}]], "Output",
 CellChangeTimes->{
  3.8557268930288773`*^9, {3.855826977635068*^9, 3.8558270302424307`*^9}, {
   3.855827121497698*^9, 3.855827135800529*^9}, 3.855837646017839*^9, 
   3.8558968289845963`*^9, 3.855896866435461*^9, 3.85589696249366*^9, 
   3.8558969958632097`*^9, 3.855897180783511*^9, 3.8558981413619328`*^9, 
   3.8559005888751574`*^9, 3.855900672227072*^9, 3.855900739977161*^9, 
   3.856071825175316*^9, 3.86168306994499*^9},
 CellLabel->
  "Out[137]=",ExpressionUUID->"b9b7a764-b236-4807-bb20-10e51cf78434"]
}, Open  ]],

Cell[TextData[{
 "One could add a \[OpenCurlyDoubleQuote]vertical\[CloseCurlyDoubleQuote] \
vector to the star list to truncate the top and bottom portions of the jig. \
This may be useful if the vertical rise ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["z", "0"], TraditionalForm]],ExpressionUUID->
  "d9a4baf7-35e8-4dc4-b3ce-8068dbf3e91d"],
 " is small, or if you intend to use a clamp to hold the jig halves \
together."
}], "Text",
 CellChangeTimes->{{3.8558272913544073`*^9, 3.855827325100216*^9}, {
  3.8558273862012367`*^9, 3.855827401848289*^9}, {3.8558377379389267`*^9, 
  3.8558377602910957`*^9}, {3.855896379487565*^9, 
  3.855896413428822*^9}},ExpressionUUID->"4e00401a-5e9a-4562-943b-\
79d33ed26589"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{
     RowBox[{"Append", "[", 
      RowBox[{"star", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], ",", "r"}], 
    "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}, {3.855827252707654*^9, 3.855827260755373*^9}},
 CellLabel->
  "In[161]:=",ExpressionUUID->"45acb777-f267-46b2-b153-58d5f56531a2"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAWJmIM75/m9Xd66SQ8CP/7e5lIwPTHhflpK+/tP+axtP
Z27exemQUxmXu22b1AEGMNA7ENu0aVnMLIMD8uG69ySrtRwmQtUnHz0dLrvF
xKGKj+PY3WdCDpMg4vZo4geg4vunB5+KFH8h43Dq4VdB8ZRf9v/BQNfh7pZJ
kzL1xB3+lZ0x6awROgATv4rqHgeoexzQ3O8Adb89AxQc/ir3K3WZLNwcmPj+
Bdf2ZNmYOkyFugfqLweYvyajuvMA1J37oeYcgLrzANSdDjBxNHMOTEENhwM4
wucAevighQPcfLRwg7sHzb8OONwJDwc0f8HDHxrOB3CE8wH0cEZLDwcmo4U/
NJwPQMPZ/hqq+fB0hWY+PB0CAOcDWrM=
    "], 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{26, 28, 27, 2, 1}, {25, 17, 13, 27, 28}, {11, 24, 23, 8, 
        9}, {12, 18, 20, 11, 9}, {17, 16, 3, 14, 13}, {24, 11, 20, 14, 3}, {1,
         2, 19, 5, 15}, {18, 12, 4, 5, 19}, {21, 25, 28, 26, 10}, {26, 1, 15, 
        7, 10}, {15, 5, 4, 6, 7}, {4, 12, 9, 8, 6}, {16, 17, 25, 21, 22}, {23,
         24, 3, 16, 22}, {20, 18, 19, 2, 27, 13, 14}, {8, 23, 22, 21, 10, 7, 
        6}}],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIJbkPq+wplLYYdbCyTW5FioHpiga7dYzVXEI3mqh
GPVQ1eHVXsHkxz+Z4eLe8hbN77sVHTp89n9I/SPtABNngIKFVz/sTCtUc0BT
fwBdPdT8A+jmQ91zAN09aOIwcw6gmQMXR7MXZs4BNHceQFPvgK4eLRzg5qOF
G1wcAJOXh5M=
     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True},
  ViewPoint->{1.5133785478127149`, -2.642505107698126, 1.4754159165501761`},
  ViewVertical->{0.06834379513279126, -0.08875291572236733, 
   0.9937062169563121}]], "Output",
 CellChangeTimes->{
  3.8558272617767*^9, 3.8558376530164633`*^9, 3.855896837038398*^9, 
   3.855896870943335*^9, {3.855896974683999*^9, 3.8558970001929197`*^9}, 
   3.8559005927762003`*^9, 3.855900675282802*^9, 3.855900743037999*^9},
 CellLabel->
  "Out[162]=",ExpressionUUID->"38f8feaf-4b2b-4578-8241-2d2779585b1d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Jig for building 6-Cross Polytope", "Subsection",
 CellChangeTimes->{{3.855640039188676*^9, 3.85564005498094*^9}, {
  3.855640393835045*^9, 3.8556404027544947`*^9}, {3.855828275443365*^9, 
  3.855828276609009*^9}},ExpressionUUID->"84e45d3a-35a4-4b8f-acc4-\
8e43cb93be1a"],

Cell["\<\
Produce a jig to make this model:
https://en.wikipedia.org/wiki/6-orthoplex#/media/File:Hexacross.png\
\>", "Text",
 CellChangeTimes->{{3.855658275046892*^9, 3.855658289867824*^9}, {
  3.855726726419105*^9, 
  3.8557267324165983`*^9}},ExpressionUUID->"c050039b-8c8e-4deb-bd1f-\
29c7cd73c159"],

Cell["\<\
In PolyhedronData[\[OpenCurlyDoubleQuote]Icosahedron\[CloseCurlyDoubleQuote]],\
 vertices 1 and 2 are opposite each other. The desired axes for this jig are \
the vectors from vertex 1 to each of the other vertices of the icosahedron \
except vertex 2. So there are 10 generators:\
\>", "Text",
 CellChangeTimes->{{3.8556422872667913`*^9, 3.855642373798999*^9}, {
  3.855642660356523*^9, 3.855642660708477*^9}, {3.855643811132907*^9, 
  3.8556438351618967`*^9}, {3.8556583212448673`*^9, 3.8556583306766357`*^9}, {
  3.8557267935756683`*^9, 
  3.855726828702993*^9}},ExpressionUUID->"48317514-2203-4be3-9fc7-\
661dfb3e686f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"With", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"v", "=", 
       RowBox[{"PolyhedronData", "[", 
        RowBox[{"\"\<Icosahedron\>\"", ",", "\"\<Vertices\>\""}], "]"}]}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"Normalize", "[", 
         RowBox[{
          RowBox[{"v", "[", 
           RowBox[{"[", "#", "]"}], "]"}], "-", 
          RowBox[{"v", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "]"}], "&"}], "/@", 
      RowBox[{"Range", "[", 
       RowBox[{"3", ",", "12"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8556391920091467`*^9, 3.855639202273176*^9}, 
   3.855639239558659*^9, {3.85563971362216*^9, 3.855639714187256*^9}, {
   3.855640415293953*^9, 3.855640424912155*^9}},
 CellLabel->
  "In[139]:=",ExpressionUUID->"4b9a56fd-de5c-4b8e-bf39-148df89c7ec9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}},
 CellLabel->
  "In[612]:=",ExpressionUUID->"6e24f4a0-10bd-4fe4-9d0e-a8cbb6d4eb49"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJx1Uj1LA1EQPNTCPiDp4gcICnpRO9MMWGgs/QUiWNsKgWARBC8gxOQX+IH/
QM5gsYWdrY1/IWBl7xnvzTy4hSw8lpvbN7s781bOLk7O55IkWZ6e+ekZfoxa
7909JIzj05/Wd30RL53br/1+GvFx+d1AzpxtXl8WkyU8PwyyorfB+obdBNye
Am6H5BtP3g6uslUIf2QmbnmFP7V+ybMe7/O/ub68l4L1YL34kbMv5/e4CXc8
Rh2Y65xzF0fEg241+y3+YyvyD0p8zaQb90Wbe7yyr3SgbnC64S7wRP217yj4
Zc4v8qTm/GJ9DZpTOnMvaC/57nDjvhhWeaQbnI+Y4aN8UR+TDno/Ts/oi9M/
+tKu8uhdRb0U+cL2Z/N+x2bg+ANbUmZ6
    "], 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{4, 20, 8, 31}, {4, 31, 16, 28}, {31, 8, 14, 5}, {16, 31, 
        18, 11}, {31, 5, 10, 18}, {17, 2, 3, 32}, {17, 32, 27, 24}, {27, 32, 
        15, 6}, {15, 32, 30, 25}, {32, 3, 21, 30}, {19, 20, 4, 28, 29, 7}, {
        20, 19, 26, 13, 14, 8}, {12, 23, 29, 28, 16, 11}, {9, 1, 12, 11, 18, 
        10}, {14, 13, 22, 9, 10, 5}, {23, 12, 1, 2, 17, 24}, {29, 23, 24, 27, 
        6, 7}, {26, 19, 7, 6, 15, 25}, {13, 26, 25, 30, 21, 22}, {1, 9, 22, 
        21, 3, 2}}],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGAQAWJmIF4jzGXYu0HzAAMUaG4OnixwUN5BA0rDxNdC1Dks
/Ba5t+uEioMxGMgdgKlHE3eAiUPMlzzw58K6ryqrhA7AzEETd4CJa4H18R+Q
YCoUWZOnATcfTRxuvkHJgXOcC5jh7oGZgybugGqvpgOafw9A/XsAzb8HoP46
gOYvdHGYOw9A/eWA5i90cZg7D0D95YDmL3RxuPlQfx1A8xe6ONx8AI6krbM=

     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{3.8560721801188793`*^9},
 CellLabel->
  "Out[613]=",ExpressionUUID->"8d3bedcf-827f-42d4-9285-17127c083ce8"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Jig to produce a Zome-like connector", "Subsection",
 CellChangeTimes->{{3.855640039188676*^9, 3.85564005498094*^9}, {
  3.8556426841007557`*^9, 3.8556426888914557`*^9}, {3.8556606615002413`*^9, 
  3.855660664276313*^9}, {3.855986917938431*^9, 3.855986920425727*^9}, {
  3.8559870095436773`*^9, 3.8559870118629847`*^9}, {3.8559889788349113`*^9, 
  3.855989021062419*^9}, {3.855998397871242*^9, 
  3.85599842091079*^9}},ExpressionUUID->"32cc2d0f-b344-4612-aeed-\
e50a05b8740f"],

Cell[TextData[{
 "The connecting balls for the Zome system are in the shape of a ",
 StyleBox["rhombicosidodecahedron",
  FontSlant->"Italic"],
 ". We use the vertices of its dual, the ",
 StyleBox["deltoidal hexecontahedron",
  FontSlant->"Italic"],
 ", to get generators for its face planes."
}], "Text",
 CellChangeTimes->{{3.855642714782909*^9, 3.855642813201779*^9}, {
  3.855643398579176*^9, 3.855643407651444*^9}, {3.855658498782173*^9, 
  3.85565854639397*^9}, {3.855659896407596*^9, 3.855659923972147*^9}, {
  3.855660490378813*^9, 3.855660514658257*^9}, {3.8559890261021757`*^9, 
  3.855989104307753*^9}},ExpressionUUID->"b9010852-8f49-4532-b8d8-\
7765c40186f0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolyhedronData", "[", "\"\<DeltoidalHexecontahedron\>\"", 
  "]"}]], "Input",
 CellChangeTimes->{{3.8556391920091467`*^9, 3.855639202273176*^9}, 
   3.855639239558659*^9, {3.85563971362216*^9, 3.855639714187256*^9}, {
   3.8559008344004917`*^9, 3.855900841509214*^9}, 3.855986930404893*^9, 
   3.8559881517717533`*^9, 3.855988208854529*^9},
 CellLabel->
  "In[382]:=",ExpressionUUID->"e8881cb5-6a9d-495c-a889-8de52a485350"],

Cell[BoxData[
 Graphics3DBox[
  GraphicsComplex3DBox[
   NCache[{{0, 0, (-11) (85 - 31 5^Rational[1, 2])^Rational[-1, 2]}, {
     0, 0, 11 (85 - 31 5^Rational[1, 2])^Rational[-1, 2]}, {
     0, (-11) (85 - 31 5^Rational[1, 2])^Rational[-1, 2], 0}, {
     0, 11 (85 - 31 5^Rational[1, 2])^Rational[-1, 2], 0}, {
     0, Rational[-1, 3] (Rational[53, 2] + 59 5^Rational[-1, 2])^
       Rational[1, 2], 
      Rational[-1, 6] (41 + 89 5^Rational[-1, 2])^Rational[1, 2]}, {
     0, Rational[-1, 3] (Rational[53, 2] + 59 5^Rational[-1, 2])^
       Rational[1, 2], 
      Rational[1, 6] (41 + 89 5^Rational[-1, 2])^Rational[1, 2]}, {
     0, -(Rational[1, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (13 + 29 5^Rational[-1, 2])^Rational[1, 2]}, {
     0, -(Rational[1, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (13 + 29 5^Rational[-1, 2])^Rational[1, 2]}, {
     0, (Rational[1, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (13 + 29 5^Rational[-1, 2])^Rational[1, 2]}, {
     0, (Rational[1, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (13 + 29 5^Rational[-1, 2])^Rational[1, 2]}, {
     0, (Rational[53, 18] + Rational[59, 9] 5^Rational[-1, 2])^Rational[1, 2],
       Rational[-1, 6] (41 + 89 5^Rational[-1, 2])^Rational[1, 2]}, {
     0, (Rational[53, 18] + Rational[59, 9] 5^Rational[-1, 2])^Rational[1, 2],
       Rational[1, 6] (41 + 89 5^Rational[-1, 2])^
       Rational[1, 2]}, {(-11) (85 - 31 5^Rational[1, 2])^Rational[-1, 2], 0, 
      0}, {Rational[-1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2]}, {
     11 (85 - 31 5^Rational[1, 2])^Rational[-1, 2], 0, 0}, {
     Rational[-1, 2] (13 + 29 5^Rational[-1, 2])^Rational[1, 2], 
      0, -(Rational[1, 2] + 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 2] (13 + 29 5^Rational[-1, 2])^Rational[1, 2], 
      0, (Rational[1, 2] + 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 3] (Rational[53, 2] + 59 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 6] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 0}, {
     Rational[-1, 3] (Rational[53, 2] + 59 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 6] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      0}, {-(Rational[1, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (13 + 29 5^Rational[-1, 2])^Rational[1, 2], 
      0}, {-(Rational[1, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (13 + 29 5^Rational[-1, 2])^Rational[1, 2], 0}, {
     Rational[-1, 6] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 0, 
      Rational[-1, 3] (Rational[53, 2] + 59 5^Rational[-1, 2])^
       Rational[1, 2]}, {
     Rational[-1, 6] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      0, (Rational[53, 18] + Rational[59, 9] 5^Rational[-1, 2])^
      Rational[1, 2]}, {
     Rational[-1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[-1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 6] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 0, 
      Rational[-1, 3] (Rational[53, 2] + 59 5^Rational[-1, 2])^
       Rational[1, 2]}, {
     Rational[1, 6] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      0, (Rational[53, 18] + Rational[59, 9] 5^Rational[-1, 2])^
      Rational[1, 2]}, {
     Rational[1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 4] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (Rational[5, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 4] (17 + 31 5^Rational[-1, 2])^Rational[1, 2]}, {(
       Rational[1, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (13 + 29 5^Rational[-1, 2])^Rational[1, 2], 
      0}, {(Rational[1, 2] + 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (13 + 29 5^Rational[-1, 2])^Rational[1, 2], 
      0}, {(Rational[53, 18] + Rational[59, 9] 5^Rational[-1, 2])^
      Rational[1, 2], 
      Rational[-1, 6] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 
      0}, {(Rational[53, 18] + Rational[59, 9] 5^Rational[-1, 2])^
      Rational[1, 2], 
      Rational[1, 6] (41 + 89 5^Rational[-1, 2])^Rational[1, 2], 0}, {
     Rational[1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[-1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2], 
      Rational[1, 2] (5 + 11 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 2] (13 + 29 5^Rational[-1, 2])^Rational[1, 2], 
      0, -(Rational[1, 2] + 5^Rational[-1, 2])^Rational[1, 2]}, {
     Rational[1, 2] (13 + 29 5^Rational[-1, 2])^Rational[1, 2], 
      0, (Rational[1, 2] + 5^Rational[-1, 2])^Rational[1, 2]}}, {{
     0, 0, -2.777751854490368}, {0, 0, 2.777751854490368}, {
     0, -2.777751854490368, 0}, {0, 2.777751854490368, 0}, {
     0, -2.424082922456278, -1.4981656376261552`}, {
     0, -2.424082922456278, 1.4981656376261552`}, {
     0, -0.9732489894677301, -2.547998933943006}, {
     0, -0.9732489894677301, 2.547998933943006}, {
     0, 0.9732489894677301, -2.547998933943006}, {
     0, 0.9732489894677301, 2.547998933943006}, {
     0, 2.424082922456278, -1.4981656376261552`}, {
     0, 2.424082922456278, 1.4981656376261552`}, {-2.777751854490368, 0, 
      0}, {-1.3888759272451836`, -2.247248456439233, 
     0.8583725291940496}, {-1.3888759272451836`, -2.247248456439233, \
-0.8583725291940496}, {-1.3888759272451836`, 2.247248456439233, 
     0.8583725291940496}, {-1.3888759272451836`, 
     2.247248456439233, -0.8583725291940496}, {
     1.3888759272451836`, -2.247248456439233, 0.8583725291940496}, {
     1.3888759272451836`, -2.247248456439233, -0.8583725291940496}, {
     1.3888759272451836`, 2.247248456439233, 0.8583725291940496}, {
     1.3888759272451836`, 2.247248456439233, -0.8583725291940496}, {
     2.777751854490368, 0, 0}, {-2.547998933943006, 
      0, -0.9732489894677301}, {-2.547998933943006, 0, 
      0.9732489894677301}, {-1.5747499444752757`, -1.5747499444752757`, \
-1.5747499444752757`}, {-1.5747499444752757`, -1.5747499444752757`, 
     1.5747499444752757`}, {-1.5747499444752757`, 
     1.5747499444752757`, -1.5747499444752757`}, {-1.5747499444752757`, 
     1.5747499444752757`, 
     1.5747499444752757`}, {-2.424082922456278, -1.4981656376261552`, 
      0}, {-2.424082922456278, 1.4981656376261552`, 
      0}, {-0.9732489894677301, -2.547998933943006, 0}, {-0.9732489894677301, 
      2.547998933943006, 0}, {-1.4981656376261552`, 
      0, -2.424082922456278}, {-1.4981656376261552`, 0, 
      2.424082922456278}, {-2.247248456439233, 
     0.8583725291940496, -1.3888759272451836`}, {-2.247248456439233, 
     0.8583725291940496, 
     1.3888759272451836`}, {-2.247248456439233, -0.8583725291940496, \
-1.3888759272451836`}, {-2.247248456439233, -0.8583725291940496, 
     1.3888759272451836`}, {
     0.8583725291940496, -1.3888759272451836`, -2.247248456439233}, {
     0.8583725291940496, -1.3888759272451836`, 2.247248456439233}, {
     0.8583725291940496, 1.3888759272451836`, -2.247248456439233}, {
     0.8583725291940496, 1.3888759272451836`, 
     2.247248456439233}, {-0.8583725291940496, -1.3888759272451836`, \
-2.247248456439233}, {-0.8583725291940496, -1.3888759272451836`, 
     2.247248456439233}, {-0.8583725291940496, 
     1.3888759272451836`, -2.247248456439233}, {-0.8583725291940496, 
     1.3888759272451836`, 2.247248456439233}, {
     1.4981656376261552`, 0, -2.424082922456278}, {
     1.4981656376261552`, 0, 2.424082922456278}, {2.247248456439233, 
     0.8583725291940496, -1.3888759272451836`}, {2.247248456439233, 
     0.8583725291940496, 1.3888759272451836`}, {
     2.247248456439233, -0.8583725291940496, -1.3888759272451836`}, {
     2.247248456439233, -0.8583725291940496, 1.3888759272451836`}, {
     0.9732489894677301, -2.547998933943006, 0}, {
     0.9732489894677301, 2.547998933943006, 0}, {
     2.424082922456278, -1.4981656376261552`, 0}, {
     2.424082922456278, 1.4981656376261552`, 0}, {
     1.5747499444752757`, -1.5747499444752757`, -1.5747499444752757`}, {
     1.5747499444752757`, -1.5747499444752757`, 1.5747499444752757`}, {
     1.5747499444752757`, 1.5747499444752757`, -1.5747499444752757`}, {
     1.5747499444752757`, 1.5747499444752757`, 1.5747499444752757`}, {
     2.547998933943006, 0, -0.9732489894677301}, {
     2.547998933943006, 0, 0.9732489894677301}}], 
   Polygon3DBox[{{43, 33, 1, 7}, {8, 2, 34, 44}, {33, 45, 9, 1}, {2, 10, 46, 
    34}, {31, 15, 5, 3}, {3, 6, 14, 31}, {17, 32, 4, 11}, {12, 4, 32, 16}, {
    39, 5, 43, 7}, {40, 8, 44, 6}, {9, 45, 11, 41}, {12, 46, 10, 42}, {39, 7, 
    1, 47}, {48, 2, 8, 40}, {1, 9, 41, 47}, {48, 42, 10, 2}, {53, 3, 5, 19}, {
    18, 6, 3, 53}, {11, 4, 54, 21}, {20, 54, 4, 12}, {33, 37, 23, 35}, {24, 
    38, 34, 36}, {15, 25, 43, 5}, {6, 44, 26, 14}, {45, 27, 17, 11}, {12, 16, 
    28, 46}, {29, 37, 25, 15}, {14, 26, 38, 29}, {27, 35, 30, 17}, {16, 30, 
    36, 28}, {29, 13, 23, 37}, {38, 24, 13, 29}, {23, 13, 30, 35}, {36, 30, 
    13, 24}, {15, 31, 14, 29}, {25, 37, 33, 43}, {44, 34, 38, 26}, {33, 35, 
    27, 45}, {46, 28, 36, 34}, {17, 30, 16, 32}, {19, 5, 39, 57}, {58, 40, 6, 
    18}, {41, 11, 21, 59}, {60, 20, 12, 42}, {19, 57, 51, 55}, {55, 52, 58, 
    18}, {49, 59, 21, 56}, {56, 20, 60, 50}, {55, 51, 61, 22}, {22, 62, 52, 
    55}, {61, 49, 56, 22}, {22, 56, 50, 62}, {55, 18, 53, 19}, {57, 39, 47, 
    51}, {52, 48, 40, 58}, {47, 41, 59, 49}, {50, 60, 42, 48}, {54, 20, 56, 
    21}, {49, 61, 51, 47}, {50, 48, 52, 62}}]]]], "Output",
 CellChangeTimes->{3.855640101597933*^9, 3.855900842395883*^9, 
  3.855986930979618*^9, 3.855988152344041*^9, 3.855988209431098*^9},
 CellLabel->
  "Out[382]=",ExpressionUUID->"6813a4c2-ec2e-4e1a-8816-16d02adec554"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"PolyhedronData", "[", 
    RowBox[{
    "\"\<DeltoidalHexecontahedron\>\"", ",", "\"\<VertexCoordinates\>\""}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "star", "]"}]}], "Input",
 CellChangeTimes->{{3.8556391920091467`*^9, 3.855639202273176*^9}, 
   3.855639239558659*^9, {3.85563971362216*^9, 3.855639714187256*^9}, {
   3.8559008344004917`*^9, 3.8559008672669*^9}, {3.85590091174608*^9, 
   3.855900929897543*^9}, 3.855900970920197*^9, 3.855901009997745*^9, {
   3.855901059785708*^9, 3.8559010706727867`*^9}, {3.855901144237237*^9, 
   3.8559011492831793`*^9}, 3.8559810313173532`*^9, 3.8559810696673203`*^9, 
   3.85598116925595*^9, 3.855981237085253*^9, 3.8559812898742657`*^9, 
   3.8559813324865513`*^9, 3.855981421383493*^9, 3.855981500491672*^9, 
   3.85598154655431*^9, 3.855981593375434*^9, 3.855981860583682*^9, 
   3.855988164418048*^9, 3.855988215869092*^9},
 CellLabel->
  "In[141]:=",ExpressionUUID->"e2f2e1fe-03a1-4377-994a-07496ae1c512"],

Cell[BoxData["62"], "Output",
 CellChangeTimes->{
  3.855900868109358*^9, {3.855900913408659*^9, 3.855900931046731*^9}, 
   3.855900971655966*^9, 3.855901010623291*^9, {3.8559010656567793`*^9, 
   3.8559010718767347`*^9}, 3.8559011499756804`*^9, 3.85598103281905*^9, 
   3.855981070879265*^9, 3.85598117081329*^9, 3.855981238212474*^9, 
   3.8559812911762943`*^9, 3.855981333388802*^9, {3.8559814012212553`*^9, 
   3.8559814223036013`*^9}, 3.855981501368843*^9, 3.855981547476557*^9, 
   3.855981594308405*^9, 3.855981861506569*^9, 3.855982002946826*^9, 
   3.85598206008274*^9, 3.855982096465007*^9, 3.855982131668891*^9, 
   3.855982162085664*^9, 3.855982398738597*^9, 3.855985183669924*^9, 
   3.8559852441074657`*^9, 3.855988165171026*^9, 3.855988216476014*^9, 
   3.856068179025477*^9, 3.8560682927655783`*^9, 3.861683242370281*^9},
 CellLabel->
  "Out[142]=",ExpressionUUID->"1e9c310b-701b-43e6-97d1-751a27104080"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}},
 CellLabel->
  "In[459]:=",ExpressionUUID->"ff8b7ab4-cb0d-4c91-ae8a-b7ff4e612aa4"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJyNlj9IlWEUxm8WQuq9oLk1pf25BhZNoYsHgiJoyTbHoCwcWhoK2ssMp4Jo
a3CpiAQhmr5DQw15g4amIFqDIBoajKBEz/MOv9cDXvi4cL73PX+ec57nfIcu
35i90tdqtW5tPns3n40zxwdmx/vt39Zv0s5ef2c3B4ct7E77ufj/E+9bW78T
tJvs7T3XOq/3fZq5d2FhffrkYTv65vfy7fmuzX1/sdocHLEPU686dx7ut0dv
L57+8nzSBrfPN3fj/JE4//LZ+aW5vjH7eXVi/v7TA/b41Pu1/vGuTXQXhla+
jtnoj/XPtjFiD35d+vvtybHqnO7znO73kIfy0//H7feu96jTE1yKfShwQF2e
5O9JvfTrSTzZWadHHAcuHnGYj+s+8in30V+P/jrrkV/WI7+YQ495c8xhsbN/
isd+K170zaOfrn4n8+DJ/PhSnOsCpyRuicc5x1yV/IC7Ix8Hbg5/Ln8JH9M5
BR/llziUuEl/Wa8Td/Io4R1xMMxPhTf8lHjgnUtPkvMGnXLNN/ruybwVvBK+
ZPwiLiUf6uBA5MM5Uj2JHqc6LR3qhO4uRryouwGvSx5xfmYR+Q1Dv7E/yGfa
6V/5OPNoJ3oa+DScp8DHkWeZC+6n9s5+yh5QPPix3eqy7MC5zB3nQLyGDnJP
0858OB/Ms9pz4FEDHu3ar+zUKdWJ/WTYO5Uec3+IZ9w34lkv0aPEjwXfHTpv
vZ3xMeIinnLvYr9Xup7oW6aH9GPQmUqnqeO6Rx3XvWTvVPolvJO6qu8P1QEe
lfmiXoPXDt1z6Jh0Kd0//F4RD9F3fi9VffsPLnHL4A==
    "], 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{108, 100, 60, 109}, {11, 5, 6, 8}, {23, 57, 41, 68}, {10,
         30, 61, 12}, {36, 77, 75, 17}, {120, 117, 113, 101}, {40, 96, 118, 
        119}, {51, 99, 72, 98}, {2, 1, 89, 90}, {53, 26, 24, 13}, {3, 4, 85, 
        86}, {52, 45, 21, 73}, {22, 59, 71, 74}, {15, 29, 28, 14}, {56, 27, 
        54, 55}, {106, 116, 115, 94}, {34, 49, 76, 35}, {110, 66, 48, 111}, {
        114, 87, 103, 95}, {33, 18, 38, 16}, {81, 91, 105, 104}, {7, 50, 93, 
        37}, {46, 25, 44, 58}, {64, 70, 69, 63}, {107, 112, 65, 32}, {20, 84, 
        83, 19}, {9, 67, 62, 31}, {42, 43, 79, 80}, {92, 97, 82, 78}, {88, 39,
         102, 47}, {60, 100, 118, 96, 29, 15}, {87, 114, 72, 99, 2, 90}, {1, 
        12, 61, 76, 49, 89}, {57, 23, 24, 26, 27, 56}, {66, 53, 13, 3, 86, 
        48}, {4, 6, 5, 7, 37, 85}, {52, 73, 55, 54, 14, 28}, {10, 11, 8, 9, 
        31, 30}, {33, 34, 35, 36, 17, 18}, {109, 110, 111, 112, 107, 108}, {
        94, 95, 103, 104, 105, 106}, {97, 92, 93, 50, 51, 98}, {45, 46, 58, 
        59, 22, 21}, {77, 63, 69, 74, 71, 75}, {117, 19, 83, 115, 116, 113}, {
        70, 64, 62, 67, 68, 41}, {38, 42, 80, 91, 81, 16}, {119, 120, 101, 
        102, 39, 40}, {20, 32, 65, 78, 82, 84}, {25, 88, 47, 79, 43, 44}, {10,
         12, 1, 2, 99, 51, 50, 7, 5, 11}, {67, 9, 8, 6, 4, 3, 13, 24, 23, 
        68}, {26, 53, 66, 110, 109, 60, 15, 14, 54, 27}, {96, 40, 39, 88, 25, 
        46, 45, 52, 28, 29}, {118, 100, 108, 107, 32, 20, 19, 117, 120, 
        119}, {34, 33, 16, 81, 104, 103, 87, 90, 89, 49}, {44, 43, 42, 38, 18,
         17, 75, 71, 59, 58}, {57, 56, 55, 73, 21, 22, 74, 69, 70, 41}, {97, 
        98, 72, 114, 95, 94, 115, 83, 84, 82}, {63, 77, 36, 35, 76, 61, 30, 
        31, 62, 64}, {48, 86, 85, 37, 93, 92, 78, 65, 112, 111}, {106, 105, 
        91, 80, 79, 47, 102, 101, 113, 116}}],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJy1lr1KA1EQhZfYWYl/WCkBiwREEMF6QPQBzAMIgl0w2FvbpbK1s5NVBAvb
sbP0SewsLARF2RTn8u1Mir0QAmfnzt4758yZ7Z9NTs57VVVd/f4WqnLt/61d
B9zmjWvWw8ri3vRp6MPn0c3S65YDPtv3dvoxHk3X/Pr45evoYMcB13iDeNP4
+v+9NpDzCG7t99z0jd7lan0x8O/3x8/t+2UD3AU3iDeJN8ivuMZrfsWdeArq
XdT1bt0Obyd9T/5rPO1vcOtaN5SXdJHkO+KJ9EG6oPcRz3QO1VdWp6THQnfK
h9Sz6L9kP2TvUZy3K19o8KSOC11nn4PPof9pP1Ofq69l44RX4tu0r6jeAT90
z6K/63adzfq5/Z6or8hXqR+ivs3Ohcg/cE4F9S7qGug00i3tn/VF17qhvKSL
JN8RT+hjybzRnIh8OzpHVo+F7mA+kj/iXJtPx3zernyhwZM6jr578HkwhxT3
H7ofnJA=
     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{3.8560683802323313`*^9},
 CellLabel->
  "Out[460]=",ExpressionUUID->"c337ef07-8cf2-4df4-87cf-b775fd08e823"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Jig axes are vertices of SnubCube (with iteration)", "Subsection",
 CellChangeTimes->{{3.855640039188676*^9, 3.85564005498094*^9}, {
  3.8556426841007557`*^9, 3.8556426888914557`*^9}, {3.8556606615002413`*^9, 
  3.855660664276313*^9}, {3.855989181017108*^9, 3.855989184400791*^9}, {
  3.855990364113687*^9, 
  3.855990364392537*^9}},ExpressionUUID->"0ecbbea7-c5bd-4afa-b153-\
55280eb87520"],

Cell["\<\
The snub cube is chiral, and none of its 24 vertices are the negatives of any \
others. So taking its vertices as the 24 axis generators will produce 48 star \
vectors for the resulting jig.\
\>", "Text",
 CellChangeTimes->{{3.855642714782909*^9, 3.855642813201779*^9}, {
   3.855643398579176*^9, 3.855643407651444*^9}, {3.855658498782173*^9, 
   3.85565854639397*^9}, {3.855659896407596*^9, 3.855659923972147*^9}, {
   3.855660490378813*^9, 3.855660514658257*^9}, 
   3.856068597142199*^9},ExpressionUUID->"9372f7ac-331c-4cb0-943f-\
f236d4547d6b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PolyhedronData", "[", "\"\<SnubCube\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.8556391920091467`*^9, 3.855639202273176*^9}, 
   3.855639239558659*^9, {3.85563971362216*^9, 3.855639714187256*^9}},
 CellLabel->
  "(Debug) In[842]:=",ExpressionUUID->"9238f037-4f55-45f8-97b4-b50f7acdd771"],

Cell[BoxData[
 Graphics3DBox[
  GraphicsComplex3DBox[
   NCache[{{Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 1, 0]}, {
     Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 2, 0]}, {
     Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 2, 0]}, {
     Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 1, 0]}, {
     Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 2, 0]}, {
     Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 1, 0]}, {
     Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 1, 0]}, {
     Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 2, 0]}, {
     Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 2, 0]}, {
     Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 1, 0]}, {
     Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 1, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 1, 0]}, {
     Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 2, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 2, 0]}, {
     Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 1, 0]}, {
     Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 2, 0]}, {
     Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 1, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 2, 0]}, {
     Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 2, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 1, 0]}, {
     Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 1, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 1, 0]}, {
     Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 1, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 2, 0]}, {
     Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 2, 0]}, {
     Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 1, 0]}, {
     Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 2, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 2, 0]}, {
     Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 2, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 1, 0]}, {
     Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 1, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 1, 0]}, {
     Root[-1 + 4 #^2 - 16 #^4 + 32 #^6& , 2, 0], 
      Root[-1 + 12 #^2 - 32 #^4 + 32 #^6& , 2, 0], 
      Root[-1 - 12 #^2 - 32 #^4 + 32 #^6& , 2, 0]}}, CompressedData["
1:eJxTTMoPSmViYGCQAGJmIG564COl6vFpf+zH59cPzb26P1NghqnYw8f70cTt
oeL2MHGYOpg8mrg9zDyouD2a+fZo4vZo9tqjmY8uDteHJo/TfnTzcPgTp/sI
+BvDXej+IRSOBOIBw1wC/sOIDwLxiRE/BMIVrg8AYF86Ng==
    "]], 
   Polygon3DBox[{{3, 1, 17}, {3, 17, 9}, {3, 19, 2}, {3, 9, 19}, {1, 4, 20}, {
     1, 20, 11}, {1, 11, 17}, {2, 19, 12}, {2, 18, 4}, {2, 12, 18}, {4, 18, 
     10}, {4, 10, 20}, {17, 11, 13}, {19, 9, 15}, {18, 12, 14}, {20, 10, 
     16}, {9, 21, 15}, {11, 23, 13}, {12, 24, 14}, {10, 22, 16}, {13, 23, 
     7}, {13, 7, 21}, {15, 21, 5}, {15, 5, 24}, {16, 22, 6}, {16, 6, 23}, {14,
      24, 8}, {14, 8, 22}, {21, 7, 5}, {23, 6, 7}, {24, 5, 8}, {22, 8, 6}, {1,
      3, 2, 4}, {21, 9, 17, 13}, {24, 12, 19, 15}, {10, 18, 14, 22}, {11, 20, 
     16, 23}, {8, 5, 7, 6}}]],
  ImageSize->{351.06778804044086`, 363.3937949039864},
  ImageSizeRaw->Automatic,
  ViewPoint->{1.366992829689105, -2.7153946416003567`, 1.4859214460888044`},
  ViewVertical->{0.10324621195784318`, -0.14617791784430673`, 
   0.9838558004357444}]], "Output",
 CellChangeTimes->{3.855640101597933*^9},
 CellLabel->
  "(Debug) Out[842]=",ExpressionUUID->"5b46702b-8b0c-4834-82f5-3616c26d6ed1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"PolyhedronData", "[", 
     RowBox[{"\"\<SnubCube\>\"", ",", "\"\<VertexCoordinates\>\""}], "]"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "star", "]"}]}], "Input",
 CellChangeTimes->{{3.85563749515095*^9, 3.855637544262084*^9}, {
   3.8556380920606613`*^9, 3.8556380960848217`*^9}, {3.8556381882302*^9, 
   3.855638189238912*^9}, {3.8556383689887342`*^9, 3.855638374899458*^9}, {
   3.855638412395669*^9, 3.8556384167631207`*^9}, {3.855638808887814*^9, 
   3.8556388460389433`*^9}, {3.855638915064519*^9, 3.855638941914418*^9}, {
   3.85563908215079*^9, 3.855639083895178*^9}, {3.855639126100025*^9, 
   3.855639127944468*^9}, {3.855639747690493*^9, 3.85563975244311*^9}, 
   3.856068613317122*^9},
 CellLabel->
  "In[144]:=",ExpressionUUID->"cde00149-9ef2-456b-b89f-8995fad854f1"],

Cell[BoxData["24"], "Output",
 CellChangeTimes->{3.855640108347926*^9, 3.855642847881222*^9, 
  3.855827452326743*^9, 3.855986313658227*^9, 3.8560686172414494`*^9, 
  3.856068795190208*^9, 3.856071781616042*^9, 3.8616832908517237`*^9},
 CellLabel->
  "Out[145]=",ExpressionUUID->"43594329-613a-4c25-b923-24ac359a6564"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}},
 CellLabel->
  "In[533]:=",ExpressionUUID->"c6027f2c-0ab6-4fb7-8020-9bd292696e81"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAmJmIOa/ulhn2y01BwYogPHfvN69N0dPGUYfgNEweSh9
gAEHWCmU8fHaYkO4vtdQ815B+TB5dH2v0eyDuQPdfTD6NZo7oebD3YfuTnRz
36CqR7fnwCqIOx0Y0AC6O9DMRw8/uDyR5mG4Dz0ecMTLATTzMPgExNHDDcOd
aPHrgMYnZL8DAG3P5jA=
    "], 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[Polygon3DBox[CompressedData["
1:eJxNkEkOwyAMRROSNAOZCIVAdr1Bz9Ij9ADp/Xc10kNi8eXnb2Mjv76/z62q
qnqLGlEneooexJS3oll0iBbijJ/qBjbUMqfajmfgS6SZr8mD6KQ/+yfcwTtR
w5uo5j81eWDXir/iZz6Ktys8MDPgD7CGc88GW+7SEi3/TPdQ+Ip8oT7RM5FH
bq3oUeSRuoMdtcy2mO/gdL+eP/fsiPBV7O3hkXsFdo701/BCbGDP24jvi/me
OZ5a4j/PJQlw
       "]],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJxTTMoPSmViYGAwAGJmID723KlEbZ3mgaaaDY7msXwHfNydlae9kT6AJu4A
FXeAicPUweTRxB1g5kHFHdDMd0ATd0Cz1wHNfHRxuD40eZz2o5uHw5843UfA
3xjuQvcPoXAkEA8Y5hLwH0Z8EIhPjPghEK5wfQT8h24urngk6A8c4Yor3nC5
Fz3+cMUjoXSNy5843UfA3xjuwhFvOMORUDrDEb8E8y2OdEionCAUrnB9AB+f
4z4=
     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{3.8560688005907507`*^9, 3.856071784065104*^9},
 CellLabel->
  "Out[534]=",ExpressionUUID->"66c5260e-c8b9-4ef3-8b36-a3229f79031b"]
}, Open  ]],

Cell[TextData[{
 "It is interesting to ",
 StyleBox["iterate",
  FontSlant->"Italic"],
 " the jigBody process (using the vertices of a jigBody polyhedron as the \
star vectors to produce the next iterate). It will quickly settle into a \
2-cycle if there is sufficient symmetry in the original star configuration. \
When this happens, we get a pair of dual polyhedra."
}], "Text",
 CellChangeTimes->{{3.8559870401584177`*^9, 3.855987087847599*^9}, {
  3.855987460451206*^9, 3.855987486697344*^9}, {3.8616833478966093`*^9, 
  3.86168339094387*^9}, {3.861775171516776*^9, 
  3.861775235563545*^9}},ExpressionUUID->"91adfd7a-b0ad-4c2e-9593-\
d3ed60d7d77b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"MeshCoordinates", "[", "jb", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "star", "]"}]}], "Input",
 CellChangeTimes->{{3.8556391920091467`*^9, 3.855639202273176*^9}, 
   3.855639239558659*^9, {3.85563971362216*^9, 3.855639714187256*^9}, {
   3.8559008344004917`*^9, 3.8559008672669*^9}, {3.85590091174608*^9, 
   3.855900929897543*^9}, 3.855900970920197*^9, 3.855901009997745*^9, {
   3.855901059785708*^9, 3.8559010706727867`*^9}, {3.855901144237237*^9, 
   3.8559011492831793`*^9}, 3.8559810313173532`*^9, 3.8559810696673203`*^9, 
   3.85598116925595*^9, 3.855981237085253*^9, 3.8559812898742657`*^9, 
   3.8559813324865513`*^9, 3.855981421383493*^9, 3.855981500491672*^9, 
   3.85598154655431*^9, 3.855981593375434*^9, {3.855981660163269*^9, 
   3.8559816728295*^9}},
 CellLabel->
  "In[535]:=",ExpressionUUID->"5ab6fd36-6eee-4d99-9d50-2e1301fa87fd"],

Cell[BoxData["26"], "Output",
 CellChangeTimes->{
  3.855640108347926*^9, 3.855642847881222*^9, 3.855827452326743*^9, {
   3.855986313658227*^9, 3.855986341039822*^9}, 3.8560688048361197`*^9, 
   3.856071789172228*^9},
 CellLabel->
  "Out[536]=",ExpressionUUID->"c2c0d7e5-38e8-44c4-a9ff-88e826ce985d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}},
 CellLabel->
  "In[537]:=",ExpressionUUID->"6df14cb0-76e3-4d0f-a134-f1a864783ad2"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJyFU8ENwjAMjMoEiA9PGADEAlAHtR2gfz5IvFnRczAAPxbg01bFF6mXWFSK
qt6dz47t7u/P/lGFEE7TWU3nsruF/rXVMD9HleHz/q43MszPQc/GAzedAL8S
Dr/6hyNeKvOPpjcd4pJelrwSn/SUJ8vfmB/jneFO/qwu+pa67JvwWO5f4hmX
ZZ/AS2s+jDvzUqqX+6lOP7M41BcpP8dBD76le3Md3E+um/uLeNKLoxfSJ17K
9xDbW8VeYh7RqRd5/s2f98XZn4wnf5dnP7wbJz/HsR/n6cr34z1Lc4iUl/Rc
Z/afjStVpTU=
    "], 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{11, 10, 9, 12}, {29, 30, 28, 27}, {4, 3, 5, 6}, {32, 33, 
        34, 31}, {46, 45, 47, 48}, {23, 25, 26, 24}, {15, 18, 17, 16}, {7, 8, 
        22, 21}, {1, 2, 20, 19}, {43, 44, 41, 42}, {36, 40, 39, 35}, {14, 13, 
        37, 38}, {7, 27, 28, 4, 6, 8}, {25, 23, 33, 32, 10, 11}, {29, 12, 9, 
        13, 14, 30}, {46, 2, 1, 16, 17, 45}, {26, 21, 22, 19, 20, 24}, {18, 
        15, 5, 3, 41, 44}, {31, 34, 48, 47, 36, 35}, {42, 38, 37, 39, 40, 
        43}, {27, 7, 21, 26, 25, 11, 12, 29}, {8, 6, 5, 15, 16, 1, 19, 22}, {
        33, 23, 24, 20, 2, 46, 48, 34}, {14, 38, 42, 41, 3, 4, 28, 30}, {18, 
        44, 43, 40, 36, 47, 45, 17}, {9, 10, 32, 31, 35, 39, 37, 13}}],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJyNlLENAjEMRS3Ygf4KWhoYIBISA1BSIl19K2QQGnIL0NOkZALm4YTiSLzo
K1iKLCfn7x/754brdB5XZnZY1npZ79Pz8bpsgxXzeN6E420a3Gf3fl58NmH7
r+1qXip49xL7OfMS6jkP8nOfwLPgV37kSdz593vWcZ7BYOQBfPavnv+J1/Dj
HMRcMvCauLPPvjU81T04T1GHuom4r5oL+UR65+N5CXoA35qXRJ/Jzz30WfUs
9BA774h1AvoYFQ/gN3pAX3p4Sl+NjsV7iSru7Kv/iZov79Wrnz9SZX6E
     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{3.8560688108341007`*^9, 3.8560717914317427`*^9},
 CellLabel->
  "Out[538]=",ExpressionUUID->"ded9ca47-6477-4112-aac4-28deca0b776c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"MeshCoordinates", "[", "jb", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "star", "]"}]}], "Input",
 CellChangeTimes->{{3.8556391920091467`*^9, 3.855639202273176*^9}, 
   3.855639239558659*^9, {3.85563971362216*^9, 3.855639714187256*^9}, {
   3.8559008344004917`*^9, 3.8559008672669*^9}, {3.85590091174608*^9, 
   3.855900929897543*^9}, 3.855900970920197*^9, 3.855901009997745*^9, {
   3.855901059785708*^9, 3.8559010706727867`*^9}, {3.855901144237237*^9, 
   3.8559011492831793`*^9}, 3.8559810313173532`*^9, 3.8559810696673203`*^9, 
   3.85598116925595*^9, 3.855981237085253*^9, 3.8559812898742657`*^9, 
   3.8559813324865513`*^9, 3.855981421383493*^9, 3.855981500491672*^9, 
   3.85598154655431*^9, 3.855981593375434*^9, {3.855981660163269*^9, 
   3.8559816728295*^9}},
 CellLabel->
  "In[539]:=",ExpressionUUID->"665a55d3-3b90-47c4-9428-297b1ddf8f3d"],

Cell[BoxData["48"], "Output",
 CellChangeTimes->{
  3.855640108347926*^9, 3.855642847881222*^9, 3.855827452326743*^9, {
   3.855986313658227*^9, 3.855986341039822*^9}, 3.855986486088827*^9, 
   3.85606882540597*^9, 3.856071794292938*^9},
 CellLabel->
  "Out[540]=",ExpressionUUID->"d1569a51-5fcb-431f-83f2-709b404e5b93"]
}, Open  ]],

Cell["\<\
The jig body below is similar, but not identical, to the first one (see how \
the red axes markers are slightly different, for instance).\
\>", "Text",
 CellChangeTimes->{{3.8560687348869143`*^9, 3.856068752431658*^9}, {
  3.86177527921771*^9, 
  3.8617753162098637`*^9}},ExpressionUUID->"5b4bf6be-e6f5-4cf9-8b53-\
998727c23f01"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}},
 CellLabel->
  "In[541]:=",ExpressionUUID->"9316d609-01aa-4788-be59-7b695d8af143"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGCQAmJmIN70/bMca5eywxY0WurxmWNG79Qd9jFMfH795v89
ML4MhD5wACz+3gYqfkAaKg+lD1wP5XZ9av3UBs3cA5uhfIFf/tEPXhs4MECB
0zmp59e4vtuguwfKh5kPtwdq/h4GNAAzdyNU33oofQBqnp/vVHX5QxK2whB1
B2D6YP6ShNLo5sL8CaP7Dipkt7D/2wOlbaD2HtiG6s8DMPdvQaUxwhtN/oAg
1Lwt3GI3tix8uedvRtvM1/927YGZtwGq7xCUnwj2l4atKNT/JhMjAha3XrOU
QvMPLB7R/S2DI77R/O2AHh7o5uKiYeoAX3YZBg==
    "], 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[Polygon3DBox[CompressedData["
1:eJxNkEkOwyAQBL1hTIKN8W7f8oO8JU/IA5z/3zIjFRKHVlcPw7C8vr/PXRVF
8RbVok40iyZc8yKyokvU4pa69uyiAbcZz9neHQ4iz3xPftJbU6+pJ56ZGcjK
jShyn0jWOQfnpfoBW3jAYzazZ29PPXGgJ5KVR9EqcqKT7PinkTeOrCXueMtK
Vi75x4XeEr7gFq8yPjmrIjtmPmD1DfbkCV8z9rxxIysb5jrqBjb8bcu6gRs4
7d3gP3fUCVA=
       "]],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJydlTFOAzEQRVdASUOTnhaJC1D5DBTUOFFqOkSTg9AYjuIGsU7ic3CNRIpn
JJ73awPFFjt/PPNn5nt8u3x5XF8Mw/B8/C6P36q+vm3uF/lzcf3w9HWXx/ef
3ebqJny0/2XDzd78gtm3sFu875M9x9N/YPwV7OYPPAN3f+Tp8jdeOTV745H3
4JUQn7zwH4wn8rm9TPfPcdpbvd7nhofa4tAu5pVFXxwX/ezOGb+C/Dxn/oZX
1E0e7Cd5s792Hv5B+Af4Oz5O1xG2yB8FL8x3dv7Ui9BPhyO+xBkvoZ4o8tk5
xjM/O2f3I0Fv6IvPoaBu+Af6Kz6Yl+ud98TimJ1zZH1xWg+dTsx/FHOcmzvz
215M0NcevJLQPffZuXuwTPfPcdpxP/z+1t97ifea85J6Ffte6tz4FeRXeja8
om6l83/qU+qf957vxzhdR/duRsGLe3Ru/tTLuXsf8SXOeAn1RJGP+5l58D77
vZnb/wV1//V9OQD17Nt+
     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{3.856068831489594*^9, 3.856071796699071*^9},
 CellLabel->
  "Out[542]=",ExpressionUUID->"85fb46a6-7e83-4407-ac4e-1c3b895a7ef3"]
}, Open  ]],

Cell["\<\
And from here on out, we are in a 2-cycle, (iterating twice is the identity).\
\
\>", "Text",
 CellChangeTimes->{{3.856068859237817*^9, 3.856068976085191*^9}, {
  3.8560722423931723`*^9, 3.856072249361546*^9}, {3.8616834364010763`*^9, 
  3.861683452488537*^9}},ExpressionUUID->"9aa9b228-c702-4a8f-b1c5-\
19d21418300c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"MeshCoordinates", "[", "jb", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "star", "]"}]}], "Input",
 CellChangeTimes->{{3.8556391920091467`*^9, 3.855639202273176*^9}, 
   3.855639239558659*^9, {3.85563971362216*^9, 3.855639714187256*^9}, {
   3.8559008344004917`*^9, 3.8559008672669*^9}, {3.85590091174608*^9, 
   3.855900929897543*^9}, 3.855900970920197*^9, 3.855901009997745*^9, {
   3.855901059785708*^9, 3.8559010706727867`*^9}, {3.855901144237237*^9, 
   3.8559011492831793`*^9}, 3.8559810313173532`*^9, 3.8559810696673203`*^9, 
   3.85598116925595*^9, 3.855981237085253*^9, 3.8559812898742657`*^9, 
   3.8559813324865513`*^9, 3.855981421383493*^9, 3.855981500491672*^9, 
   3.85598154655431*^9, 3.855981593375434*^9, {3.855981660163269*^9, 
   3.8559816728295*^9}},
 CellLabel->
  "In[543]:=",ExpressionUUID->"3b94d8f7-54bf-47fb-9cd7-3fc3e88bb79d"],

Cell[BoxData["26"], "Output",
 CellChangeTimes->{
  3.855640108347926*^9, 3.855642847881222*^9, 3.855827452326743*^9, {
   3.855986313658227*^9, 3.855986341039822*^9}, 3.855986525378132*^9, 
   3.856068990919379*^9, 3.856071799677476*^9},
 CellLabel->
  "Out[544]=",ExpressionUUID->"cee9b8db-4812-41e8-af38-82600ae8446e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"r", "=", "15"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "r", " ", "is", " ", "the", " ", "radius", " ", "of", " ", "the", " ", 
     "drill", " ", "jig"}], ",", " ", 
    RowBox[{
    "from", " ", "center", " ", "of", " ", "ball", " ", "cavity", " ", "to", 
     " ", "drill", " ", "entry", " ", "point"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jb", "=", 
   RowBox[{"jigBody", "[", 
    RowBox[{"star", ",", "r"}], "]"}]}], ";", 
  RowBox[{"Show", "[", 
   RowBox[{"jb", ",", 
    RowBox[{"Graphics3D", "[", 
     RowBox[{"{", 
      RowBox[{"Red", ",", 
       RowBox[{"PointSize", "[", ".01", "]"}], ",", 
       RowBox[{"Point", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"r", "+", ".1"}], ")"}], "*", 
         RowBox[{"Normalize", "/@", 
          RowBox[{"Join", "[", 
           RowBox[{"star", ",", 
            RowBox[{
             RowBox[{"-", "1"}], "*", "star"}]}], "]"}]}]}], "]"}]}], "}"}], 
     "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.855639304377112*^9, 3.855639306041306*^9}, {
  3.855639355971319*^9, 3.855639394486916*^9}, {3.855639432454893*^9, 
  3.855639433061316*^9}, {3.855639531198367*^9, 3.8556396223517647`*^9}, {
  3.855640128115387*^9, 3.8556401284646683`*^9}, {3.855826550996633*^9, 
  3.855826669745974*^9}},
 CellLabel->
  "In[545]:=",ExpressionUUID->"d0206a15-04a8-496a-891d-c919da5afc2e"],

Cell[BoxData[
 Graphics3DBox[{GraphicsComplex3DBox[CompressedData["
1:eJxtU8tKA0EQHKKIHsWLR/UWReMpGtxseicbo4so5O5F8Owvznf4Ad68Kj7X
hK0a6MKFpZnq7uqanu79h6fFYy+EcLr815b/YO8+LJ5301ZYfSfWtK8vn9s7
6Rp2A/gR4kJ3ThHneRdnxKfIm3R+I/8meErEX8J+tKvv2G4QP5W6A8HHOLfI
m4FH8R70UMfkf51WwI/8jJMnCE8NHcQrz5P6cv+fjifN4D9APHHWKRHfeJ12
AdzAy/5Ff990h/O79IX4G/AxeEbS/1voGyGe7099rBelP7/en/tBP+ejlve5
kvdsYL9wnyh9MPDjHXM/K68z2yjx0JkKnOk/g+W8sM+cx2/kEacuzePelLIn
nCfy1H5v0jrihsDPfZ8zP2yev8LXz++CeaEOq2TuwZ/rcg/nUm/o51315/3l
3sgcp0O/J9YX3Yz/A0HrEPw=
    "], 
    {Hue[0.6, 0.3, 0.85], EdgeForm[Hue[0.6, 0.3, 0.75]], 
     TagBox[
      Polygon3DBox[{{3, 31, 33, 43}, {4, 47, 12, 11}, {13, 10, 5, 1}, {37, 38,
         36, 35}, {6, 7, 8, 9}, {30, 32, 14, 16}, {21, 20, 17, 18}, {15, 2, 
        22, 19}, {44, 45, 46, 48}, {26, 24, 23, 27}, {40, 39, 42, 41}, {34, 
        29, 25, 28}, {47, 4, 3, 43, 44, 48}, {7, 5, 10, 11, 12, 8}, {40, 29, 
        34, 37, 35, 39}, {38, 33, 31, 32, 30, 36}, {1, 2, 15, 16, 14, 13}, {
        20, 6, 9, 24, 26, 17}, {19, 22, 21, 18, 41, 42}, {45, 28, 25, 27, 23, 
        46}, {3, 4, 11, 10, 13, 14, 32, 31}, {43, 33, 38, 37, 34, 28, 45, 
        44}, {7, 6, 20, 21, 22, 2, 1, 5}, {15, 19, 42, 39, 35, 36, 30, 16}, {
        47, 48, 46, 23, 24, 9, 8, 12}, {29, 40, 41, 18, 17, 26, 27, 25}}],
      Annotation[#, "Geometry"]& ]}], 
   {RGBColor[1, 0, 0], PointSize[0.01], Point3DBox[CompressedData["
1:eJx1Uz1LA0EQPbQRbawSLAN+FGIaYxFYZUEQaxvBUhBUlIA/QO4f+AdEL+Fa
RawiWWHAwiiWl7SCEAtJk2AhIYUhvhe4ibuwPOZm5t29mXe5/dLOwUQQBIXB
nRzcKGM3L0s5W1HY3Krd1fcW7NPRxvLKSd8xBsrf87ZJEDeQB0q+c/5c734Y
xStlxKvDk7cBztrX7mvr4ntUH6u+hnoP+F2gDnmv0XcFvAFf8ezwtJXNrKNO
2Edd1KN5mSd2ol4489ZzQEO+OK1TMF+ppHFs3iov5Jt9MfPH75+u0L1fms5W
ndJlbxFvD3UtUpet/tSiqbmk2FR6uEePLu++fX2a14es88xD0r7qm/+/q+0S
5TPtBz3nsponPiOE30b1serz+Zn9RPJiL5Z7gd8EfntUfg+pK0nPJ9R5In1G
35EvTuu0nv95bN7af+SD3wz8ZpQugd8s/EZdAr89qH2Hyidal3ffvj7N60PW
/QKgqucY
     "]]}},
  Boxed->False,
  Lighting->{{"Ambient", 
     GrayLevel[0.45]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{2, 0, 2}]}, {"Directional", 
     GrayLevel[0.33], 
     ImageScaled[{2, 2, 2}]}, {"Directional", 
     GrayLevel[0.3], 
     ImageScaled[{0, 2, 2}]}},
  Method->{"ShrinkWrap" -> True}]], "Output",
 CellChangeTimes->{3.856068992701783*^9, 3.856071801719468*^9},
 CellLabel->
  "Out[546]=",ExpressionUUID->"e886fec8-86df-470c-8c37-a0c38b7cd05d"]
}, Open  ]],

Cell["\<\
Not every collection of generators will produce an iteration sequence that \
falls into a 2-cycle. Indeed, only very special ones do! Here is an example \
showing the first four iterates in a sequence that does not stabilize:\
\>", "Text",
 CellChangeTimes->{{3.861775482801071*^9, 3.8617756290906353`*^9}, {
  3.861775685295994*^9, 
  3.8617756958558283`*^9}},ExpressionUUID->"881ea734-3049-4248-9c8a-\
f1382121742d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"seed", "=", "\"\<PentagonalIcositetrahedron\>\""}], ",", "star",
      ",", "jb1", ",", "star1", ",", "jb2", ",", "star2", ",", "jb3", ",", 
     "star3"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"star", "=", 
     RowBox[{"PolyhedronData", "[", 
      RowBox[{"seed", ",", "\"\<VertexCoordinates\>\""}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"jb1", "=", 
     RowBox[{"jigBody", "[", "star", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"star1", "=", 
     RowBox[{"MeshCoordinates", "[", "jb1", "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"jb2", "=", 
     RowBox[{"jigBody", "[", "star1", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"star2", "=", 
     RowBox[{"MeshCoordinates", "[", "jb2", "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"jb3", "=", 
     RowBox[{"jigBody", "[", "star2", "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"star3", "=", 
     RowBox[{"MeshCoordinates", "[", "jb3", "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Row", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PolyhedronData", "[", "seed", "]"}], ",", "jb1", ",", "jb2", 
        ",", "jb3", ",", 
        RowBox[{"jigBody", "[", "star3", "]"}]}], "}"}], ",", 
      RowBox[{"Spacer", "[", "2", "]"}]}], "]"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.85563749515095*^9, 3.855637544262084*^9}, {
   3.8556380920606613`*^9, 3.8556380960848217`*^9}, {3.8556381882302*^9, 
   3.855638189238912*^9}, {3.8556383689887342`*^9, 3.855638374899458*^9}, {
   3.855638412395669*^9, 3.8556384167631207`*^9}, {3.855638808887814*^9, 
   3.8556388460389433`*^9}, {3.855638915064519*^9, 3.855638941914418*^9}, {
   3.85563908215079*^9, 3.855639083895178*^9}, {3.855639126100025*^9, 
   3.855639127944468*^9}, {3.855639747690493*^9, 3.85563975244311*^9}, 
   3.856068613317122*^9, 3.856253658634039*^9, 3.856253865285411*^9, {
   3.856253955861155*^9, 3.856253966092351*^9}, 3.8562541152892714`*^9, {
   3.8562546396424026`*^9, 3.856254666435419*^9}, {3.856593417929503*^9, 
   3.856593418814076*^9}, {3.856593626818502*^9, 3.856593675935418*^9}, {
   3.8565937070743*^9, 3.856593837674252*^9}, {3.856593892580241*^9, 
   3.85659398268681*^9}, {3.856594012812913*^9, 3.856594035891562*^9}, {
   3.856594073449469*^9, 3.85659408805595*^9}, {3.8565941868550997`*^9, 
   3.856594279390637*^9}, {3.856594497519195*^9, 3.8565945083903522`*^9}, {
   3.856594740765923*^9, 3.856594750398335*^9}, {3.8565947837831697`*^9, 
   3.856594802510179*^9}, {3.856594853261077*^9, 3.856594960992682*^9}, {
   3.856595405142956*^9, 3.856595405791*^9}, {3.856595470910123*^9, 
   3.856595477970962*^9}, {3.85659554536543*^9, 3.856595575910902*^9}, {
   3.856595621515608*^9, 3.856595645646627*^9}, {3.856595692250691*^9, 
   3.856595711647995*^9}, 3.85678922573559*^9, 3.85678937542704*^9, 
   3.856789454982317*^9, 3.856789611043922*^9, 3.856792201695326*^9},
 CellLabel->"In[18]:=",ExpressionUUID->"f867a64b-dbb9-4589-81bd-2cc36c96fd0a"],

Cell[BoxData[
 TemplateBox[{
   TemplateBox[{2}, "Spacer1"], 
   Graphics3DBox[
    GraphicsComplex3DBox[
     NCache[{{0, 0, 
        Root[-1 - 4 #^2 - 336 #^4 + 64 #^6& , 1, 0]}, {0, 0, 
        Root[-1 - 4 #^2 - 336 #^4 + 64 #^6& , 2, 0]}, {0, 
        Root[-1 - 4 #^2 - 336 #^4 + 64 #^6& , 1, 0], 0}, {0, 
        Root[-1 - 4 #^2 - 336 #^4 + 64 #^6& , 2, 0], 0}, {
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 1, 0]}, {
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 2, 0]}, {
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0]}, {
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0]}, {
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 2, 0]}, {
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 1, 0]}, {
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0]}, {
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0]}, {
        Root[-1 - 4 #^2 - 336 #^4 + 64 #^6& , 1, 0], 0, 0}, {
        Root[-1 - 4 #^2 - 336 #^4 + 64 #^6& , 2, 0], 0, 0}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 2, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 1, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 1, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 1, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 2, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 2, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 1, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 2, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 1, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 2, 0]}, {
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 2, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 1, 0]}, {
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 1, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0]}, {
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 1, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0]}, {
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 2, 0]}, {
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 1, 0]}, {
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 2, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 1, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0]}, {
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 2, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0]}, {
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 1, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 1, 0]}, {
        Root[-1 + 4 #^2 + 16 #^4 + 64 #^6& , 2, 0], 
        Root[-1 + 20 #^2 - 112 #^4 + 64 #^6& , 2, 0], 
        Root[-49 + 164 #^2 - 240 #^4 + 64 #^6& , 2, 0]}}, {{
       0, 0, -2.2940010536869546`}, {0, 0, 2.2940010536869546`}, {
       0, -2.2940010536869546`, 0}, {
       0, 2.2940010536869546`, 
        0}, {-1.7248794185064589`, -1.2472231679936432`, \
-0.3686763528801638}, {-1.7248794185064589`, 1.2472231679936432`, 
       0.36867635288016387`}, {-1.7248794185064589`, -0.3686763528801638, 
       1.2472231679936432`}, {-1.7248794185064589`, 
       0.36867635288016387`, -1.2472231679936432`}, {
       1.724879418506459, -1.2472231679936432`, 0.36867635288016387`}, {
       1.724879418506459, 1.2472231679936432`, -0.3686763528801638}, {
       1.724879418506459, -0.3686763528801638, -1.2472231679936432`}, {
       1.724879418506459, 0.36867635288016387`, 
       1.2472231679936432`}, {-2.2940010536869546`, 0, 0}, {
       2.2940010536869546`, 0, 
        0}, {-1.2472231679936432`, -1.7248794185064589`, 
       0.36867635288016387`}, {-1.2472231679936432`, 
       1.724879418506459, -0.3686763528801638}, {-1.2472231679936432`, \
-1.2472231679936432`, -1.2472231679936432`}, {-1.2472231679936432`, \
-1.2472231679936432`, 1.2472231679936432`}, {-1.2472231679936432`, 
       1.2472231679936432`, -1.2472231679936432`}, {-1.2472231679936432`, 
       1.2472231679936432`, 
       1.2472231679936432`}, {-1.2472231679936432`, -0.3686763528801638, \
-1.7248794185064589`}, {-1.2472231679936432`, 0.36867635288016387`, 
       1.724879418506459}, {
       1.2472231679936432`, -1.7248794185064589`, -0.3686763528801638}, {
       1.2472231679936432`, 1.724879418506459, 0.36867635288016387`}, {
       1.2472231679936432`, -1.2472231679936432`, -1.2472231679936432`}, {
       1.2472231679936432`, -1.2472231679936432`, 1.2472231679936432`}, {
       1.2472231679936432`, 1.2472231679936432`, -1.2472231679936432`}, {
       1.2472231679936432`, 1.2472231679936432`, 1.2472231679936432`}, {
       1.2472231679936432`, -0.3686763528801638, 1.724879418506459}, {
       1.2472231679936432`, 
       0.36867635288016387`, -1.7248794185064589`}, {-0.3686763528801638, \
-1.7248794185064589`, -1.2472231679936432`}, {-0.3686763528801638, 
       1.724879418506459, 
       1.2472231679936432`}, {-0.3686763528801638, -1.2472231679936432`, 
       1.724879418506459}, {-0.3686763528801638, 
       1.2472231679936432`, -1.7248794185064589`}, {
       0.36867635288016387`, -1.7248794185064589`, 1.2472231679936432`}, {
       0.36867635288016387`, 1.724879418506459, -1.2472231679936432`}, {
       0.36867635288016387`, -1.2472231679936432`, -1.7248794185064589`}, {
       0.36867635288016387`, 1.2472231679936432`, 1.724879418506459}}], 
     Polygon3DBox[{{5, 13, 8, 21, 17}, {22, 20, 6, 13, 7}, {15, 18, 7, 13, 
      5}, {8, 13, 6, 16, 19}, {14, 12, 29, 26, 9}, {11, 30, 27, 10, 14}, {9, 
      23, 25, 11, 14}, {14, 10, 24, 28, 12}, {35, 33, 18, 15, 3}, {34, 19, 16,
       4, 36}, {31, 17, 21, 1, 37}, {38, 32, 20, 22, 2}, {3, 31, 37, 25, 
      23}, {28, 24, 4, 32, 38}, {26, 29, 2, 33, 35}, {1, 34, 36, 27, 30}, {15,
       5, 17, 31, 3}, {4, 16, 6, 20, 32}, {2, 22, 7, 18, 33}, {21, 8, 19, 34, 
      1}, {9, 26, 35, 3, 23}, {27, 36, 4, 24, 10}, {25, 37, 1, 30, 11}, {12, 
      28, 38, 2, 29}}]]], 
   Graphics3DBox[
    TagBox[
     DynamicModuleBox[{Typeset`mesh = HoldComplete[
         BoundaryMeshRegion[CompressedData["
1:eJyVVr9rVEEYfGqhwSqIIAELwUJT2BlTPLIoWNqIYCEkELARQSEKNkLyB+QP
CMeFFEZ8Z5WA5JF74SMQDFEblUuagJUINlGvFPOLN/PBTm5RD47l7e3bnZlv
vtm7MP7o9v3jWZY9PPieOPg2rqx+evJl26oHO38mp7+HWTxjDJznuu7nc2fO
P17Kj2WHnx82vP2hM3J3M7QmBq6Pjny0DPPz9XPAc7hWr7Nf9fsV57HO8H64
1Or/fbFvIW9Nd5q3bnwzjDzf8QGXtfuePR1499Xenp56P7WwFUo8N7F+BuMy
eBCX4A1D4EF+nC+w/gXG3b3Dz04gD/BynmWMx/G9Ao/XGC/XPCv8HrhuDe/N
CU/yb8R18TrxfOIHH+dHvvO96+T6c57vj725N3lzdslxAp/jXcH8MsZ1/P6v
9eY864S6Geul/Fl/4qHO0J362qmJO2efdxZz6M79qJfNiO/pb+geXsZ1oh8d
b6r+5EWfcf85qV8Z46eegedoH8g+1MPK3jr81dfaB6KDn1PG/jyit/jddaPu
4FFpH7I/NSeo31Xg3kO//Yz1dv+iDrn6mrxUX+IeiuvGXKsEj2k9NeeGRV/m
YiORo4XkCHLFRtFnmpf/2c/eH5rrqovqhfNzPVd9pLlJXdR/ZSLX2rH+vk+3
dx39PO6red+O58MGzingv0L6qcL6DfEFcsyQY4Yc8/oxP5gb8GMOnxp8mtRX
c5PnNiWPeE7Kf5xnLrMuzCn2HXNQ76FSeDK3iU9xNONcPJITKXzMR+lj0/xQ
P3Tj+yJ5P+n9RzzkTR0G4/zx/wWqc6q/me/sD97bep8rPuKmDuRPvxSSj/Sp
8iFPuQedt/ZV4v+Q5/TJ+l6seM+0Yp8E7bN9q5AQtQ==
          "], {
           
           Polygon[{{69, 63, 62, 26, 102}, {46, 19, 55, 54, 47}, {47, 54, 100,
             77, 17}, {108, 77, 100, 101, 84}, {22, 23, 95, 72, 104}, {69, 
            102, 83, 22, 104}, {72, 95, 51, 4, 18}, {3, 55, 19, 80, 7}, {28, 
            11, 61, 7, 80}, {3, 7, 68, 18, 4}, {62, 63, 68, 7, 61}, {42, 16, 
            25, 37, 36}, {20, 39, 24, 44, 43}, {44, 45, 16, 42, 43}, {39, 57, 
            89, 103, 24}, {97, 98, 74, 73, 29}, {65, 97, 29, 9, 31}, {83, 102,
             75, 94, 82}, {98, 82, 94, 86, 74}, {59, 50, 16, 45, 2}, {36, 37, 
            38, 34, 35}, {50, 49, 48, 25, 16}, {12, 11, 28, 30, 34}, {33, 46, 
            47, 5, 6}, {35, 34, 30, 33, 6}, {56, 8, 108, 84, 78}, {84, 101, 
            52, 87, 85}, {56, 57, 39, 41, 8}, {47, 17, 40, 21, 5}, {39, 20, 
            21, 40, 41}, {51, 95, 76, 87, 52}, {95, 23, 64, 32, 76}, {65, 31, 
            15, 32, 64}, {31, 9, 96, 93, 92}, {74, 86, 88, 67, 70}, {73, 74, 
            70, 71, 1}, {75, 102, 26, 27, 58}, {12, 34, 38, 10, 13}, {66, 67, 
            88, 91, 99}, {91, 58, 27, 14, 99}, {79, 78, 84, 85, 81}, {92, 79, 
            81, 15, 31}, {90, 93, 96, 105, 107}, {103, 89, 90, 107, 106}, {49,
             66, 99, 53, 48}, {14, 13, 10, 53, 99}, {1, 71, 60, 107, 105}, {
            59, 2, 106, 107, 60}}], 
           
           Polygon[{{72, 18, 68, 63, 69, 104}, {75, 58, 91, 88, 86, 94}, {19, 
            46, 33, 30, 28, 80}, {77, 108, 8, 41, 40, 17}, {44, 24, 103, 106, 
            2, 45}, {29, 73, 1, 105, 96, 9}, {85, 87, 76, 32, 15, 81}, {37, 
            25, 48, 53, 10, 38}}], 
           
           Polygon[{{101, 100, 54, 55, 3, 4, 51, 52}, {57, 56, 78, 79, 92, 93,
             90, 89}, {6, 5, 21, 20, 43, 42, 36, 35}, {23, 22, 83, 82, 98, 97,
             65, 64}, {11, 12, 13, 14, 27, 26, 62, 61}, {66, 49, 50, 59, 60, 
            71, 70, 67}}]}, 
          Method -> {
           "EliminateUnusedCoordinates" -> True, "DeleteDuplicateCoordinates" -> 
            Automatic, "DeleteDuplicateCells" -> Automatic, "VertexAlias" -> 
            Identity, "CheckOrientation" -> Automatic, "CoplanarityTolerance" -> 
            Automatic, "CheckIntersections" -> Automatic, 
            "BoundaryNesting" -> {{0, 0}}, "SeparateBoundaries" -> False, 
            "TJunction" -> Automatic, "PropagateMarkers" -> True, "ZeroTest" -> 
            Automatic, "Hash" -> 1155972850687605872}]]}, 
      TagBox[
       GraphicsComplex3DBox[CompressedData["
1:eJyVVr9rVEEYfGqhwSqIIAELwUJT2BlTPLIoWNqIYCEkELARQSEKNkLyB+QP
CMeFFEZ8Z5WA5JF74SMQDFEblUuagJUINlGvFPOLN/PBTm5RD47l7e3bnZlv
vtm7MP7o9v3jWZY9PPieOPg2rqx+evJl26oHO38mp7+HWTxjDJznuu7nc2fO
P17Kj2WHnx82vP2hM3J3M7QmBq6Pjny0DPPz9XPAc7hWr7Nf9fsV57HO8H64
1Or/fbFvIW9Nd5q3bnwzjDzf8QGXtfuePR1499Xenp56P7WwFUo8N7F+BuMy
eBCX4A1D4EF+nC+w/gXG3b3Dz04gD/BynmWMx/G9Ao/XGC/XPCv8HrhuDe/N
CU/yb8R18TrxfOIHH+dHvvO96+T6c57vj725N3lzdslxAp/jXcH8MsZ1/P6v
9eY864S6Geul/Fl/4qHO0J362qmJO2efdxZz6M79qJfNiO/pb+geXsZ1oh8d
b6r+5EWfcf85qV8Z46eegedoH8g+1MPK3jr81dfaB6KDn1PG/jyit/jddaPu
4FFpH7I/NSeo31Xg3kO//Yz1dv+iDrn6mrxUX+IeiuvGXKsEj2k9NeeGRV/m
YiORo4XkCHLFRtFnmpf/2c/eH5rrqovqhfNzPVd9pLlJXdR/ZSLX2rH+vk+3
dx39PO6red+O58MGzingv0L6qcL6DfEFcsyQY4Yc8/oxP5gb8GMOnxp8mtRX
c5PnNiWPeE7Kf5xnLrMuzCn2HXNQ76FSeDK3iU9xNONcPJITKXzMR+lj0/xQ
P3Tj+yJ5P+n9RzzkTR0G4/zx/wWqc6q/me/sD97bep8rPuKmDuRPvxSSj/Sp
8iFPuQedt/ZV4v+Q5/TJ+l6seM+0Yp8E7bN9q5AQtQ==
        "], {
         Directive[{
           Hue[0.6, 0.3, 0.85], 
           EdgeForm[{
             Hue[0.6, 0.3, 0.75]}]}], {
          TagBox[
           
           Polygon3DBox[{{69, 63, 62, 26, 102}, {46, 19, 55, 54, 47}, {47, 54,
              100, 77, 17}, {108, 77, 100, 101, 84}, {22, 23, 95, 72, 104}, {
             69, 102, 83, 22, 104}, {72, 95, 51, 4, 18}, {3, 55, 19, 80, 7}, {
             28, 11, 61, 7, 80}, {3, 7, 68, 18, 4}, {62, 63, 68, 7, 61}, {42, 
             16, 25, 37, 36}, {20, 39, 24, 44, 43}, {44, 45, 16, 42, 43}, {39,
              57, 89, 103, 24}, {97, 98, 74, 73, 29}, {65, 97, 29, 9, 31}, {
             83, 102, 75, 94, 82}, {98, 82, 94, 86, 74}, {59, 50, 16, 45, 
             2}, {36, 37, 38, 34, 35}, {50, 49, 48, 25, 16}, {12, 11, 28, 30, 
             34}, {33, 46, 47, 5, 6}, {35, 34, 30, 33, 6}, {56, 8, 108, 84, 
             78}, {84, 101, 52, 87, 85}, {56, 57, 39, 41, 8}, {47, 17, 40, 21,
              5}, {39, 20, 21, 40, 41}, {51, 95, 76, 87, 52}, {95, 23, 64, 32,
              76}, {65, 31, 15, 32, 64}, {31, 9, 96, 93, 92}, {74, 86, 88, 67,
              70}, {73, 74, 70, 71, 1}, {75, 102, 26, 27, 58}, {12, 34, 38, 
             10, 13}, {66, 67, 88, 91, 99}, {91, 58, 27, 14, 99}, {79, 78, 84,
              85, 81}, {92, 79, 81, 15, 31}, {90, 93, 96, 105, 107}, {103, 89,
              90, 107, 106}, {49, 66, 99, 53, 48}, {14, 13, 10, 53, 99}, {1, 
             71, 60, 107, 105}, {59, 2, 106, 107, 60}, {72, 18, 68, 63, 69, 
             104}, {75, 58, 91, 88, 86, 94}, {19, 46, 33, 30, 28, 80}, {77, 
             108, 8, 41, 40, 17}, {44, 24, 103, 106, 2, 45}, {29, 73, 1, 105, 
             96, 9}, {85, 87, 76, 32, 15, 81}, {37, 25, 48, 53, 10, 38}, {101,
              100, 54, 55, 3, 4, 51, 52}, {57, 56, 78, 79, 92, 93, 90, 89}, {
             6, 5, 21, 20, 43, 42, 36, 35}, {23, 22, 83, 82, 98, 97, 65, 
             64}, {11, 12, 13, 14, 27, 26, 62, 61}, {66, 49, 50, 59, 60, 71, 
             70, 67}}], Annotation[#, "Geometry"]& ]}}], 
       MouseAppearanceTag["LinkHand"]], AllowKernelInitialization -> False], 
     "MeshGraphics3D", {
     AutoDelete -> True, Editable -> False, Selectable -> False}], {
    Boxed -> False, Lighting -> {{"Ambient", 
        GrayLevel[0.45]}, {"Directional", 
        GrayLevel[0.3], 
        ImageScaled[{2, 0, 2}]}, {"Directional", 
        GrayLevel[0.33], 
        ImageScaled[{2, 2, 2}]}, {"Directional", 
        GrayLevel[0.3], 
        ImageScaled[{0, 2, 2}]}}, Method -> {"ShrinkWrap" -> True}, 
     DefaultBaseStyle -> {
      "MeshGraphics3D", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.1, 1, 0.7]}}], 
   Graphics3DBox[
    TagBox[
     DynamicModuleBox[{Typeset`mesh = HoldComplete[
         BoundaryMeshRegion[CompressedData["
1:eJx1mN9L32UUx7/qTNeECDaI1oX7E7rYxUh67tpaRVBdRNDNoutguc1htswr
x364ili/cAVhXQQxCMzU449+00/WnL/dHEabLlzo5la6xM/7deA5c4I8PM/n
+XXOeZ/3eT/fbXteeurF8lKp9Mvqf8Xq/6kn608vH/8snXxr68KZ9vk0oH79
1TcfrHloLh18+Nlf6174Pu38/aPu6h3nU9knVQPX279NfSef31z186yNTp7q
3F5/IXU/t+Va648X0ldFa2MfbH/7vsoZm619puWH/u/S1AOXhk7vnzXmMc78
88X31K/vWp+61G/WPV7WvR7XfY7pvk1Fa+/Jjtc0/7Finu3Vuie07tXiux3Q
+G6N71P/iNbfqv3m88Z7LqaybWutlYrW7xXsTXfLPyOFXww/Hc39aDrHNA9/
phqtD/cx4oC97xZ22ivqt+g781nfr/PHdM5/HWv725j83av7X1Y8LhWtf8e+
OY2rnxQvPyf40xTv1KP1f4X14OFvjb+h9dHuCe3DvXpyv6/GpRhnHude1Xzh
yc+dUJy4F3Zif0+Yr3PTpO47ovWmeeB50/p5YcKDmcYnNK6+x4M8GlK7Ueu+
1ryzGgcfiqvjRvE19lNc01weTxuVvTdze92fK3m+pmgv7YDOHQ64qvlz509D
X3zaveWRqaf3/DOf7i/6dfDJLsX3gOLNeJPwq+/2jvK4VfhuUH5zz2HxC/7H
XuHA5mVHPJdz4Bn8UVPgKC1qnfY14n5N4+PqkxfihSReMPGF3wseZD64fjS/
D/baEdnbKHuZT34rPwy+Pqj5+Al+xL+7cr5x/4pPfR/8e1gtccevtr69qVx2
b1a8S+EPfoOHhJPb5rFeuLH4fYPOo12pXZeH05TufVeej+RHqtb4cH6vtEH5
Nhz4WPXCxG8JfgNP++XX4/In9vZqPfkPnuRXz8+2PA/AhbFvcx7HFOPYqHuR
L8KPCT/OW0vige6c32xG4xc1Dz9V5DxDHUs3O/L6dk7+HpQ98Am8yvgN5Q+8
B98tdeRxUp84eD0A//ipN5w3il+1D/e7of2lA1wXoAdi/pAPh3L94HlVLr+M
5Tix1py/HCfYtaJ7DIV1t2QvuLkiP02E+iwev43nFA/XGdxrNK+/8Jrzp3gs
LVAf5C/F3ciLs8LTCfkHniK/qHPMHwDnut9G1WfiobphVTqnKegG4o2eQ+eg
ewKfwWOuWxU/a9f6srz+Oi6uhLqIX9nnw7BftPNfxfPetfr2Zd3Y9G8fn5h7
f4d4zFSnPR49snsp170eZ+Vhmla/K88jWwx6mXYxx4uPU3+kd4z7Rj9QtwdD
PQdPlYrzOc0fDPEjT/+Qv9rkd/wGvsAj91q4Ax77wv3R1VHf3wEPyXlauCJv
qbfoO3hxJtR1vl/X+JlgD/aBB+IKz0T+hZdb1te3Xs9DffF7xjpckesM+s4T
k7ledv7Hn9LhxNnzmLwc13hlzgM2rXih2zt1nnSRCa+GH9FnfQGvXaGvem3Y
RbssHRXfL9Ql8r9BfiO+e4O+gh/iewn84Df8rTrC+zLyjNdn+tSRhvCd+Oo8
+As+i3XF9zsc6hz74QfiJh3jPMs7p1p8Oxp0F/EcDPuU5E+9Tw27G3R+eE+6
v8kH1U2TfvS4qM4adsKH8V08kutjdKa/25vzPDbqCzzqOkP3aA/5il/Q4eAv
4DhNCMed+Xcf3x3iSryb1+cZ19FRX1PnlzvydyHvNPCIXVv1fkIXb1K/LegV
eEq6OPKDTcp+7MUP2Dse3sXL+bvU616IH3qQvHF9ie4Iv5uY3guuG1aC/iMu
s6E+wBf8DgDPgaOgS71uLqA7tQ/4PJTj0/U3/df1Hd6g/hxVyztyX4j7/zVX
xwE=
          "], {
           
           Polygon[{{113, 115, 114}, {19, 18, 20}, {173, 175, 174}, {62, 53, 
            2}, {144, 145, 143}, {158, 159, 160}, {8, 12, 1}, {84, 82, 83}, {
            141, 162, 81}, {116, 167, 166}, {164, 165, 163}, {28, 109, 77}, {
            96, 98, 97}, {178, 180, 172}, {64, 63, 65}, {137, 138, 136}, {49, 
            48, 50}, {186, 185, 184}, {10, 11, 9}, {25, 16, 132}, {203, 204, 
            205}, {119, 100, 93}, {59, 61, 60}, {206, 190, 78}}], 
           
           Polygon[{{197, 161, 200, 199, 196}, {80, 118, 188, 161, 197}, {80, 
            197, 196, 140, 139}, {147, 146, 148, 149, 177}, {147, 177, 202, 
            179, 135}, {90, 54, 7, 72, 89}, {51, 13, 14, 6, 5}, {72, 7, 124, 
            123, 73}, {146, 147, 135, 134, 133}, {13, 35, 29, 30, 14}, {45, 
            57, 4, 42, 31}, {26, 27, 58, 57, 45}, {51, 52, 22, 35, 13}, {89, 
            72, 73, 44, 43}, {66, 67, 32, 107, 106}, {67, 66, 33, 34, 94}, {
            156, 181, 111, 169, 154}, {156, 155, 153, 152, 181}, {55, 4, 57, 
            58, 56}, {155, 156, 154, 85, 86}, {193, 23, 24, 127, 191}, {126, 
            125, 192, 191, 127}, {183, 193, 191, 192, 182}, {32, 67, 94, 104, 
            103}}], 
           Polygon[CompressedData["
1:eJwBYQGe/iFib1JiAgAAADAAAAAHAAAAaXFyvRMUA3FpdlCLjnOuR83MqKut
EkU0MwUDFK2rjMTHZq9Gj5HGbKOlrq9myZ6gR7GVnZ+eycpEPgJlJlJUj0Zh
YktMkL1yc45woo3IobzCpKNsCEp8BzYRDIgvurjDeImQTIaHs8aRvi8BDBFP
TntLYmAoLElhRgkLJyhgebSyl5ZNbSYdIxZfU1ITvXSmqkUSGi0fXD9AKUFE
VFNfKUBaWStlAjVbgUoIAS+IiniUkoWBiolbNT5EMjAuwm4KCUalpA4eJwsK
bgYlUaJwb7WYtHmEEA+wrAQ3DxAZuyqEeXddV7sZm1aXsqywmajMy4NVmqnN
Rzw9goPLMkRBP1xYMUJqLjAxWCFeIlddZGNoeW0cemNkd6d0vY1RJSQ6G6qm
pyQ4ln5/GHocTUegn50VOzx9gj07FbbAw7i5dRfBty++zoB1ubqAzk5PayBn
VxaJ3w==
            "]], 
           
           Polygon[{{102, 199, 200, 108, 198, 179, 202, 201}, {3, 5, 6, 110, 
            194, 188, 118, 105}, {76, 75, 123, 124, 74, 129, 133, 134}, {52, 
            69, 170, 27, 26, 41, 95, 22}, {38, 101, 43, 44, 40, 39, 30, 29}, {
            54, 90, 91, 46, 106, 107, 79, 17}, {171, 168, 169, 111, 112, 142, 
            139, 140}, {151, 86, 85, 131, 130, 125, 126, 150}, {120, 195, 183,
             182, 21, 157, 149, 148}, {34, 33, 88, 92, 31, 42, 187, 87}, {15, 
            55, 56, 36, 37, 152, 153, 176}, {99, 122, 24, 23, 117, 128, 103, 
            104}}]}, 
          Method -> {
           "EliminateUnusedCoordinates" -> True, "DeleteDuplicateCoordinates" -> 
            Automatic, "DeleteDuplicateCells" -> Automatic, "VertexAlias" -> 
            Identity, "CheckOrientation" -> Automatic, "CoplanarityTolerance" -> 
            Automatic, "CheckIntersections" -> Automatic, 
            "BoundaryNesting" -> {{0, 0}}, "SeparateBoundaries" -> False, 
            "TJunction" -> Automatic, "PropagateMarkers" -> True, "ZeroTest" -> 
            Automatic, "Hash" -> 6936675050470510676}]]}, 
      TagBox[
       GraphicsComplex3DBox[CompressedData["
1:eJx1mN9L32UUx7/qTNeECDaI1oX7E7rYxUh67tpaRVBdRNDNoutguc1htswr
x364ili/cAVhXQQxCMzU449+00/WnL/dHEabLlzo5la6xM/7deA5c4I8PM/n
+XXOeZ/3eT/fbXteeurF8lKp9Mvqf8Xq/6kn608vH/8snXxr68KZ9vk0oH79
1TcfrHloLh18+Nlf6174Pu38/aPu6h3nU9knVQPX279NfSef31z186yNTp7q
3F5/IXU/t+Va648X0ldFa2MfbH/7vsoZm619puWH/u/S1AOXhk7vnzXmMc78
88X31K/vWp+61G/WPV7WvR7XfY7pvk1Fa+/Jjtc0/7Finu3Vuie07tXiux3Q
+G6N71P/iNbfqv3m88Z7LqaybWutlYrW7xXsTXfLPyOFXww/Hc39aDrHNA9/
phqtD/cx4oC97xZ22ivqt+g781nfr/PHdM5/HWv725j83av7X1Y8LhWtf8e+
OY2rnxQvPyf40xTv1KP1f4X14OFvjb+h9dHuCe3DvXpyv6/GpRhnHude1Xzh
yc+dUJy4F3Zif0+Yr3PTpO47ovWmeeB50/p5YcKDmcYnNK6+x4M8GlK7Ueu+
1ryzGgcfiqvjRvE19lNc01weTxuVvTdze92fK3m+pmgv7YDOHQ64qvlz509D
X3zaveWRqaf3/DOf7i/6dfDJLsX3gOLNeJPwq+/2jvK4VfhuUH5zz2HxC/7H
XuHA5mVHPJdz4Bn8UVPgKC1qnfY14n5N4+PqkxfihSReMPGF3wseZD64fjS/
D/baEdnbKHuZT34rPwy+Pqj5+Al+xL+7cr5x/4pPfR/8e1gtccevtr69qVx2
b1a8S+EPfoOHhJPb5rFeuLH4fYPOo12pXZeH05TufVeej+RHqtb4cH6vtEH5
Nhz4WPXCxG8JfgNP++XX4/In9vZqPfkPnuRXz8+2PA/AhbFvcx7HFOPYqHuR
L8KPCT/OW0vige6c32xG4xc1Dz9V5DxDHUs3O/L6dk7+HpQ98Am8yvgN5Q+8
B98tdeRxUp84eD0A//ipN5w3il+1D/e7of2lA1wXoAdi/pAPh3L94HlVLr+M
5Tix1py/HCfYtaJ7DIV1t2QvuLkiP02E+iwev43nFA/XGdxrNK+/8Jrzp3gs
LVAf5C/F3ciLs8LTCfkHniK/qHPMHwDnut9G1WfiobphVTqnKegG4o2eQ+eg
ewKfwWOuWxU/a9f6srz+Oi6uhLqIX9nnw7BftPNfxfPetfr2Zd3Y9G8fn5h7
f4d4zFSnPR49snsp170eZ+Vhmla/K88jWwx6mXYxx4uPU3+kd4z7Rj9QtwdD
PQdPlYrzOc0fDPEjT/+Qv9rkd/wGvsAj91q4Ax77wv3R1VHf3wEPyXlauCJv
qbfoO3hxJtR1vl/X+JlgD/aBB+IKz0T+hZdb1te3Xs9DffF7xjpckesM+s4T
k7ledv7Hn9LhxNnzmLwc13hlzgM2rXih2zt1nnSRCa+GH9FnfQGvXaGvem3Y
RbssHRXfL9Ql8r9BfiO+e4O+gh/iewn84Df8rTrC+zLyjNdn+tSRhvCd+Oo8
+As+i3XF9zsc6hz74QfiJh3jPMs7p1p8Oxp0F/EcDPuU5E+9Tw27G3R+eE+6
v8kH1U2TfvS4qM4adsKH8V08kutjdKa/25vzPDbqCzzqOkP3aA/5il/Q4eAv
4DhNCMed+Xcf3x3iSryb1+cZ19FRX1PnlzvydyHvNPCIXVv1fkIXb1K/LegV
eEq6OPKDTcp+7MUP2Dse3sXL+bvU616IH3qQvHF9ie4Iv5uY3guuG1aC/iMu
s6E+wBf8DgDPgaOgS71uLqA7tQ/4PJTj0/U3/df1Hd6g/hxVyztyX4j7/zVX
xwE=
        "], {
         Directive[{
           Hue[0.6, 0.3, 0.85], 
           EdgeForm[{
             Hue[0.6, 0.3, 0.75]}]}], {
          TagBox[
           
           Polygon3DBox[{{113, 115, 114}, {19, 18, 20}, {173, 175, 174}, {62, 
             53, 2}, {144, 145, 143}, {158, 159, 160}, {8, 12, 1}, {84, 82, 
             83}, {141, 162, 81}, {116, 167, 166}, {164, 165, 163}, {28, 109, 
             77}, {96, 98, 97}, {178, 180, 172}, {64, 63, 65}, {137, 138, 
             136}, {49, 48, 50}, {186, 185, 184}, {10, 11, 9}, {25, 16, 
             132}, {203, 204, 205}, {119, 100, 93}, {59, 61, 60}, {206, 190, 
             78}, {197, 161, 200, 199, 196}, {80, 118, 188, 161, 197}, {80, 
             197, 196, 140, 139}, {147, 146, 148, 149, 177}, {147, 177, 202, 
             179, 135}, {90, 54, 7, 72, 89}, {51, 13, 14, 6, 5}, {72, 7, 124, 
             123, 73}, {146, 147, 135, 134, 133}, {13, 35, 29, 30, 14}, {45, 
             57, 4, 42, 31}, {26, 27, 58, 57, 45}, {51, 52, 22, 35, 13}, {89, 
             72, 73, 44, 43}, {66, 67, 32, 107, 106}, {67, 66, 33, 34, 94}, {
             156, 181, 111, 169, 154}, {156, 155, 153, 152, 181}, {55, 4, 57, 
             58, 56}, {155, 156, 154, 85, 86}, {193, 23, 24, 127, 191}, {126, 
             125, 192, 191, 127}, {183, 193, 191, 192, 182}, {32, 67, 94, 104,
              103}, {105, 113, 114, 189, 19, 20, 3}, {113, 105, 118, 80, 139, 
             142, 115}, {174, 71, 205, 204, 168, 171, 173}, {18, 69, 52, 51, 
             5, 3, 20}, {173, 171, 140, 196, 199, 102, 175}, {70, 143, 145, 
             198, 108, 163, 165}, {174, 175, 102, 201, 158, 160, 71}, {177, 
             149, 157, 159, 158, 201, 202}, {68, 62, 2, 101, 38, 82, 84}, {
             143, 70, 97, 98, 75, 76, 144}, {189, 114, 115, 142, 112, 162, 
             141}, {200, 161, 188, 194, 164, 163, 108}, {8, 74, 124, 7, 54, 
             17, 12}, {136, 47, 186, 184, 195, 120, 137}, {144, 76, 134, 135, 
             179, 198, 145}, {190, 47, 1, 12, 17, 79, 78}, {123, 75, 98, 96, 
             40, 44, 73}, {97, 70, 9, 11, 39, 40, 96}, {121, 180, 178, 151, 
             150, 77, 109}, {38, 29, 35, 22, 95, 83, 82}, {19, 189, 116, 166, 
             170, 69, 18}, {26, 45, 31, 92, 63, 64, 41}, {65, 68, 84, 83, 95, 
             41, 64}, {90, 89, 43, 101, 2, 53, 91}, {129, 74, 8, 1, 47, 136, 
             138}, {120, 148, 146, 133, 129, 138, 137}, {91, 53, 62, 68, 50, 
             48, 46}, {194, 110, 10, 9, 70, 165, 164}, {14, 30, 39, 11, 10, 
             110, 6}, {37, 81, 162, 112, 111, 181, 152}, {180, 121, 132, 16, 
             15, 176, 172}, {4, 55, 15, 16, 25, 187, 42}, {132, 121, 119, 93, 
             87, 187, 25}, {155, 86, 151, 178, 172, 176, 153}, {168, 204, 203,
              131, 85, 154, 169}, {205, 71, 60, 61, 130, 131, 203}, {50, 68, 
             65, 63, 92, 88, 49}, {66, 106, 46, 48, 49, 88, 33}, {94, 34, 87, 
             93, 100, 99, 104}, {121, 109, 28, 122, 99, 100, 119}, {167, 116, 
             189, 141, 81, 37, 36}, {58, 27, 170, 166, 167, 36, 56}, {150, 
             126, 127, 24, 122, 28, 77}, {71, 160, 159, 157, 21, 59, 60}, {
             125, 130, 61, 59, 21, 182, 192}, {195, 184, 185, 117, 23, 193, 
             183}, {47, 190, 206, 128, 117, 185, 186}, {128, 206, 78, 79, 107,
              32, 103}, {102, 199, 200, 108, 198, 179, 202, 201}, {3, 5, 6, 
             110, 194, 188, 118, 105}, {76, 75, 123, 124, 74, 129, 133, 
             134}, {52, 69, 170, 27, 26, 41, 95, 22}, {38, 101, 43, 44, 40, 
             39, 30, 29}, {54, 90, 91, 46, 106, 107, 79, 17}, {171, 168, 169, 
             111, 112, 142, 139, 140}, {151, 86, 85, 131, 130, 125, 126, 
             150}, {120, 195, 183, 182, 21, 157, 149, 148}, {34, 33, 88, 92, 
             31, 42, 187, 87}, {15, 55, 56, 36, 37, 152, 153, 176}, {99, 122, 
             24, 23, 117, 128, 103, 104}}], Annotation[#, "Geometry"]& ]}}], 
       MouseAppearanceTag["LinkHand"]], AllowKernelInitialization -> False], 
     "MeshGraphics3D", {
     AutoDelete -> True, Editable -> False, Selectable -> False}], {
    Boxed -> False, Lighting -> {{"Ambient", 
        GrayLevel[0.45]}, {"Directional", 
        GrayLevel[0.3], 
        ImageScaled[{2, 0, 2}]}, {"Directional", 
        GrayLevel[0.33], 
        ImageScaled[{2, 2, 2}]}, {"Directional", 
        GrayLevel[0.3], 
        ImageScaled[{0, 2, 2}]}}, Method -> {"ShrinkWrap" -> True}, 
     DefaultBaseStyle -> {
      "MeshGraphics3D", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.1, 1, 0.7]}}], 
   Graphics3DBox[
    TagBox[
     DynamicModuleBox[{Typeset`mesh = HoldComplete[
         BoundaryMeshRegion[CompressedData["
1:eJxtmXlUV8cVxyHgBigqLnUF4hItdY0alydjNVqPWyIJbk3qEheiVeOWajTV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          "], {
           Polygon[CompressedData["
1:eJwt0DsohlEcx/HzvOROeVEuCSmDULIYlBCLkl4mBiWjXoN3YTHIQGIxKEW5
jS4JEwZRmNgUJTLIpVxKRHz/nd/w6ff7P0/nPOc5Jb0DkWjIOVeLOGQHzr2R
eWQ5ShEgGa88/3I+bf4gQ2Qutp1nPUV7vGufQ/LWOjoQQSd45WrQiDDDIJkQ
+G6ZiH6e5ZCzznfLMBoQjwxlhbrt16U9v5HE2qLA/1s3igOfWYHvC/R2HGMN
69jACdrwpG75jF3UIYpF59fb2nv9o/3rHyqxqrQ5n2+12HmQhkK7W/LX+exT
H8IOPjGGecSwiUxUK22ewgQmkS7WCzCCA1wop9UvcYc9POAKN8oj9R+UIZUz
Vmm2PkzWo1lp8xZ6dGY7e6vOHdNdNem+lrCCZYxiHDNKm+dwjRec4xH7OMOp
ntv7f9J4Um4=
            "]], 
           
           Polygon[{{77, 76, 135, 136}, {259, 260, 185, 184}, {145, 144, 43, 
            42}, {34, 271, 270, 33}, {151, 150, 171, 170}, {29, 30, 187, 
            186}}], 
           Polygon[CompressedData["
1:eJw11GdsTXEYx/FzS9MYaauqVokWLbXFiqSNGWpHYu8aMVsiQYiVlJpt7djj
he2FTUmIESEixAyJkSA0QW3CC99fzs+LT57/85x7zv0/z//cm5KTNzA3KgiC
nohGXCQIUolNiOmozrquIv6w3owtaECehtOsKxLHE2OQynoesRzxHPELEllX
IrYPwnvi/NwTiEcseTy2sv6F3/iMnUFY1/obZvl5eoa+PxpfyddhHB6jLYqd
q56BQxiJvbiKmqiBCshES/fO44Iufr722hhR7lE9tUEeykfC/tSvejyPHDSN
hGtd1+cWua6ZaXZJGIIjmIzZSHDv6rWRZ6Bc9RhcIe+DvriNG16vwAu8cr3Y
vTfEJJ0fKkfC3jOcq64mk1AN00mrEJN93jr3FJ3t/zMhjnKueqJnpZnFql9H
5cPQCZ0x1Hmm5zncPaiXR3rHUOAeCpx3cz8TvSftLQFVdQbet+oj9G75c8t1
3TVdyyYuQD/cxAOft879OV7jjdeqnUUuZmhu3D+V+B3NUIs8i9gOE1Afq5FM
fYrXqtWJhPfo3h/4iTNYj4PojwHYjUEoxXG0Qusg/G3p93QYz9DD74fek7Wu
6doH3MUT96X+7uOyn7kGq7Rv1HZe6u9cEoSz0X2XsNjXdO87FHpP+1APF71/
7Xkmjmmf6hVzgrD/dKThr2eR5ai8OVqgO0Z7DnrefEc9/xROurYQY5GPZeiN
pdjlXPWjPhvNdgw6Yq4dwH6fmz7TC3vwHi9Rhk146rVq1z0PzfMTijwbvRf6
X+iArkH4jgx23+q/BNs8D83lLR7iAq75Wolz1TdgI1a6D/W5w/3ku77de5uG
e/jofd5xL2Wu3cI/TwGmHw==
            "]], 
           Polygon[CompressedData["
1:eJwt099rz1Ecx/HzGb6LWX6M/Z5tMiZrDBOmkIla+XWBZLQRatn8XJPflAuF
C5SQ5IJc7Ab/APmxNAyZCySaocgFDcl4vjqvi0fn/Tnn7Jzzfr/3LW1sWdGc
FkKYghRGJSHkYRIK+R6CDIzhezB+E//y3hy+2xjHMk5EOdKRwk7mt2Azpoe4
L+UzdNYivndgO374LJ25QXcS5+JPiO/Qe74TD2IsxYQk3pnO3DmMJs72G3JC
XNc+5TUAJcTHGAsYb4S4R3NZ6Ca+g0ytIx/LkYs8vMdb1GIWdmMtruMfruIa
yjgrP4lzWhtKnJnE+qmO4zAQ8zHP3/V6u2qOCq93+/7VWINpGOa7ax1rLlE9
nL/qUMFEP2MWRjrXQhThL9/DQ8y93rHmNmKG39DvMxoZ9+An+pAdYh/UjzTV
mLjcvVMPX+ELlmCva/kAHXiO467tERzCQTxDO7bhsNcUt2IXLqELX3227jiB
J+jBR7xzX9SfD673JsYMxvH6Hwix/g3ul/q2DgsxF9V4idvYimbM8VyD99zE
Le/Zh5U4j/tYhqVY5RqpJlNRhRGe13gSn/x25XDFf69z7qIYJa5ZJ17jMy67
hsr1LO55rdO5K9cyLMZkVDp39e8AajAb691PvX8/6lzjVufT7n6cwjc8Qq/P
rnZNFmCm79LZLTiKMzjtuzSn37l+7xdxwXuKnecLvMFTNPkO3fUYD72mPf8B
jbN53A==
            "]], 
           Polygon[CompressedData["
1:eJwt0MsrhGEUx/HnVcO4rVwSigkxsyEL41KyEjYyRrGRSG4NUbJAYeEfkIWi
FBMLGQtLJnZKLmWDhQ1FWdhJs5DvyW/x6TzvOec9532fwPBMZDrNOVeEDIwg
HT/YQoXnXAiV3v/ZcjXEIArh4MGnnpCeLW9zA8RiYh+iiGAA/ehBGXU/JjlX
EXNRzXkCdciBH5n6xib4NMNm9SKMbGShDSXMWCeOIqUdNq9Ue2xfSvU8/OIb
a1jFEU6QQCdWMI4dHKtmPdsYw6L6Eqpb3yzm9A/5KEADWtGu/wrr+6O6n3q7
WwRxijOc4xUviOES73hTzmpPeMam7smvHbarFh1oxDwOsIB9xHGIQe2xfeV2
X5jSTJvdjBZsYAh7et/mdGtGXHmrL2MJ97jDBy5wjSQesYsufCpv9Qdc4Us9
SdWt7xY3+AOtBUsF
            "]]}, 
          Method -> {
           "EliminateUnusedCoordinates" -> True, "DeleteDuplicateCoordinates" -> 
            Automatic, "DeleteDuplicateCells" -> Automatic, "VertexAlias" -> 
            Identity, "CheckOrientation" -> Automatic, "CoplanarityTolerance" -> 
            Automatic, "CheckIntersections" -> Automatic, 
            "BoundaryNesting" -> {{0, 0}}, "SeparateBoundaries" -> False, 
            "TJunction" -> Automatic, "PropagateMarkers" -> True, "ZeroTest" -> 
            Automatic, "Hash" -> 6605653492519111942}]]}, 
      TagBox[
       GraphicsComplex3DBox[CompressedData["
1:eJxtmXlUV8cVxyHgBigqLnUF4hItdY0alydjNVqPWyIJbk3qEheiVeOWajTV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        "], {
         Directive[{
           Hue[0.6, 0.3, 0.85], 
           EdgeForm[{
             Hue[0.6, 0.3, 0.75]}]}], {
          TagBox[
           
           Polygon3DBox[{{276, 242, 281}, {298, 291, 257}, {265, 241, 249}, {
             241, 265, 244}, {258, 280, 181}, {181, 280, 266}, {242, 243, 
             281}, {195, 226, 25}, {83, 82, 84}, {1, 51, 66}, {274, 115, 
             262}, {274, 262, 263}, {108, 277, 152}, {108, 152, 18}, {65, 4, 
             14}, {4, 44, 14}, {51, 90, 66}, {250, 264, 287}, {3, 91, 288}, {
             91, 275, 288}, {159, 80, 198}, {174, 175, 176}, {201, 78, 236}, {
             201, 236, 237}, {183, 60, 110}, {162, 159, 198}, {229, 226, 
             195}, {255, 45, 166}, {45, 255, 282}, {70, 8, 12}, {285, 35, 
             253}, {35, 100, 253}, {121, 182, 247}, {133, 158, 116}, {177, 17,
              49}, {17, 177, 142}, {138, 140, 13}, {13, 140, 27}, {127, 191, 
             210}, {191, 143, 210}, {217, 227, 189}, {233, 220, 224}, {220, 
             197, 224}, {252, 38, 267}, {46, 252, 267}, {122, 63, 69}, {63, 
             122, 179}, {95, 182, 121}, {75, 133, 116}, {183, 67, 60}, {163, 
             165, 164}, {131, 137, 148}, {137, 131, 155}, {221, 238, 209}, {
             235, 190, 203}, {202, 238, 221}, {77, 76, 135, 136}, {259, 260, 
             185, 184}, {145, 144, 43, 42}, {34, 271, 270, 33}, {151, 150, 
             171, 170}, {29, 30, 187, 186}, {271, 34, 299, 295, 23}, {286, 
             279, 251, 150, 151}, {292, 294, 181, 266, 99}, {7, 290, 120, 259,
              184}, {242, 276, 11, 55, 294}, {271, 23, 178, 16, 270}, {272, 
             153, 248, 249, 241}, {157, 272, 241, 244, 113}, {242, 294, 292, 
             261, 243}, {145, 97, 215, 53, 144}, {97, 145, 42, 169, 92}, {161,
              195, 25, 24, 9}, {61, 48, 5, 1, 66}, {294, 55, 41, 258, 181}, {
             120, 52, 111, 260, 259}, {7, 184, 185, 98, 300}, {185, 260, 111, 
             126, 98}, {150, 251, 22, 87, 171}, {104, 115, 274, 272, 157}, {
             296, 153, 272, 274, 263}, {194, 76, 77, 204, 199}, {77, 136, 223,
              225, 204}, {144, 53, 37, 102, 43}, {268, 169, 42, 43, 102}, {
             256, 278, 277, 108, 273}, {28, 299, 34, 33, 36}, {270, 16, 93, 
             36, 33}, {20, 48, 61, 14, 44}, {14, 61, 89, 64, 65}, {88, 89, 61,
              66, 90}, {76, 194, 214, 15, 135}, {136, 135, 15, 68, 223}, {101,
              273, 108, 18, 19}, {2, 256, 273, 91, 3}, {101, 134, 275, 91, 
             273}, {73, 123, 78, 201, 212}, {195, 161, 222, 228, 229}, {222, 
             161, 183, 110, 109}, {293, 106, 245, 45, 282}, {62, 54, 100, 35, 
             139}, {284, 105, 139, 35, 285}, {245, 106, 246, 247, 182}, {146, 
             168, 79, 80, 159}, {85, 234, 177, 49, 50}, {286, 151, 170, 219, 
             71}, {171, 87, 141, 219, 170}, {237, 208, 216, 212, 201}, {211, 
             192, 234, 140, 138}, {26, 27, 140, 234, 85}, {128, 73, 212, 191, 
             127}, {234, 192, 232, 142, 177}, {162, 32, 188, 146, 159}, {112, 
             173, 30, 29, 118}, {105, 39, 38, 252, 139}, {62, 139, 252, 46, 
             47}, {69, 94, 168, 146, 122}, {146, 188, 180, 179, 122}, {125, 
             96, 132, 133, 75}, {129, 158, 133, 132, 172}, {245, 182, 95, 58, 
             119}, {119, 167, 166, 45, 245}, {74, 160, 233, 224, 240}, {149, 
             218, 240, 224, 197}, {212, 216, 239, 143, 191}, {161, 9, 56, 67, 
             183}, {86, 118, 29, 186, 154}, {30, 173, 230, 213, 187}, {196, 
             154, 186, 187, 213}, {147, 148, 137, 132, 96}, {156, 172, 132, 
             137, 155}, {218, 107, 209, 238, 240}, {206, 74, 240, 238, 202}, {
             276, 281, 299, 28, 10, 11}, {286, 265, 249, 248, 6, 279}, {120, 
             290, 297, 296, 263, 262}, {115, 104, 103, 52, 120, 262}, {265, 
             286, 71, 114, 113, 244}, {279, 6, 99, 266, 280, 251}, {299, 281, 
             243, 261, 289, 295}, {290, 7, 152, 277, 278, 297}, {23, 295, 289,
              2, 3, 288}, {134, 283, 178, 23, 288, 275}, {214, 194, 13, 27, 
             26, 81}, {24, 25, 226, 223, 68, 57}, {117, 92, 169, 255, 166, 
             167}, {293, 282, 255, 169, 268, 269}, {10, 28, 36, 4, 65, 64}, {
             36, 93, 21, 20, 44, 4}, {214, 81, 88, 90, 51, 15}, {57, 68, 15, 
             51, 1, 5}, {152, 7, 300, 254, 19, 18}, {283, 284, 285, 253, 16, 
             178}, {93, 16, 253, 100, 54, 21}, {254, 300, 98, 121, 247, 
             246}, {22, 251, 280, 258, 41, 40}, {114, 71, 219, 236, 78, 
             123}, {194, 199, 200, 211, 138, 13}, {130, 128, 127, 210, 173, 
             112}, {129, 130, 112, 118, 116, 158}, {208, 237, 236, 219, 141, 
             207}, {228, 231, 225, 223, 226, 229}, {268, 102, 267, 38, 39, 
             269}, {97, 92, 117, 94, 69, 63}, {53, 215, 193, 109, 110, 60}, {
             215, 97, 63, 179, 180, 193}, {124, 86, 154, 198, 80, 79}, {87, 
             22, 40, 50, 49, 17}, {87, 17, 142, 232, 207, 141}, {162, 198, 
             154, 196, 31, 32}, {199, 204, 220, 233, 160, 200}, {231, 149, 
             197, 220, 204, 225}, {102, 37, 72, 47, 46, 267}, {98, 126, 59, 
             58, 95, 121}, {124, 125, 75, 116, 118, 86}, {173, 210, 143, 239, 
             205, 230}, {37, 53, 60, 67, 56, 72}, {126, 111, 131, 148, 147, 
             59}, {111, 52, 103, 156, 155, 131}, {31, 196, 213, 221, 209, 
             107}, {230, 205, 206, 202, 221, 213}, {99, 6, 248, 153, 291, 298,
              292}, {291, 153, 296, 297, 278, 256, 257}, {261, 292, 298, 257, 
             256, 2, 289}, {26, 85, 84, 82, 89, 88, 81}, {287, 264, 106, 293, 
             269, 39, 105}, {48, 12, 8, 9, 24, 57, 5}, {89, 82, 83, 55, 11, 
             10, 64}, {283, 134, 101, 250, 287, 105, 284}, {106, 264, 250, 
             101, 19, 254, 246}, {130, 129, 172, 176, 175, 73, 128}, {104, 
             157, 174, 176, 172, 156, 103}, {123, 73, 175, 174, 157, 113, 
             114}, {48, 20, 21, 54, 62, 70, 12}, {55, 83, 84, 85, 50, 40, 
             41}, {180, 188, 189, 227, 222, 109, 193}, {231, 228, 222, 227, 
             217, 218, 149}, {9, 8, 70, 62, 47, 72, 56}, {117, 167, 119, 164, 
             165, 168, 94}, {189, 188, 32, 31, 107, 218, 217}, {58, 59, 147, 
             96, 163, 164, 119}, {79, 168, 165, 163, 96, 125, 124}, {208, 207,
              232, 192, 203, 190, 216}, {160, 74, 235, 203, 192, 211, 200}, {
             239, 216, 190, 235, 74, 206, 205}}], 
           Annotation[#, "Geometry"]& ]}}], 
       MouseAppearanceTag["LinkHand"]], AllowKernelInitialization -> False], 
     "MeshGraphics3D", {
     AutoDelete -> True, Editable -> False, Selectable -> False}], {
    Boxed -> False, Lighting -> {{"Ambient", 
        GrayLevel[0.45]}, {"Directional", 
        GrayLevel[0.3], 
        ImageScaled[{2, 0, 2}]}, {"Directional", 
        GrayLevel[0.33], 
        ImageScaled[{2, 2, 2}]}, {"Directional", 
        GrayLevel[0.3], 
        ImageScaled[{0, 2, 2}]}}, Method -> {"ShrinkWrap" -> True}, 
     DefaultBaseStyle -> {
      "MeshGraphics3D", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.1, 1, 0.7]}}], 
   Graphics3DBox[
    TagBox[
     DynamicModuleBox[{Typeset`mesh = HoldComplete[
         BoundaryMeshRegion[CompressedData["
1:eJxdm3mcT+UXxwcZsxi7wdhNKUUSqV4tT9nak6W0/VQqIUpSUYpIxDCWkiJR
ljE0xgyGaThhLGObInsNM2PGOpbkZSt+vdz35/t63esP93Xv997nOc85n/M5
y/NMwx5vd369dFhYWOv//ivz3zVy/JVRH50tcFnbw3asv7rPZZ/v17FJt2I3
a+vAnd0Tj7h6cUXlN+0vcAcGbOt5p9tup5KbxCS1O+j6dByWlpNe7M5497Y8
ZUrcxd5FdmDjG2ltdx92lf53tNPhV9a5yN4LxxWVznNXln09cVT8EVfBu7ci
3svwvnPVvPftKM+TeF6XcUYUNGl3V+R2d3Zz9J9dd+xxk5dnrHp4zAnXDPnm
I+8byLmllzdvNtf6Gd78SxLODI+/cMztOtiuY9TofDe3S5vmtjPdrd927v5T
YUdc04TCyDati1xJ8surJi5Z59LRS2P0NN/Tjy3m9+d5f6b3vXV+qXDX4+Gn
XV5kUmR0te1Zx7hW4/uvGc8Y51TPxfnl3trjqq37JC0/qcTdenKe/dZ/rU2O
nb3rTP4eF5e9ZNakr0pcwqKu9aN7rLFtntxWufM1uW0p65mEPj5CT397erKv
XmvzQp/2x13LZbcv6dl9h/un7PLY7f3/sGm8l8B3R9HrdPQeluPZIQ67PME6
f0JPX3vrtxzmn93J02MK8q3kvSHoyXnf2zrs9LhnJ+HLDoOr0gu8a3cPX3YY
+4WDmyqeHe118Hee705yXcq494OLUd58toz1twq/tn7Xx9OLvY9+znl6cSne
ezYRvaSjlyxPXxbJ9/sZ73W+X8h769BrIt8/h95+QB+T0ce36PkKeG8Cztu/
etfn85edcrlJNz5a1H65G9C0aZseLTdavGcPi8Ie7/H9hgBuT2OXZdhlJzjv
6OHc1ka2KD4/usDlBK6HeK9FV8+OC/i+DnLtQ86f8fMqPF+FHHu93+0r1j0U
PZSgl7Ho6UX0Vgo91gf3f5Vcw71L8fzBrgf3sR7uXT/PH0x+tFI85fmTxeLf
f4CXPK41Gf8CflYO/2rG+C3wswGpnn+daZm1ulP/1W5f7NhZC7edcke4/zfA
O4PBQ0PWMZT1dQc/n3l2cw9iz3XYcxjP2/L8ivfcJqNH7OvKYO86+GEMz4eh
/+n4URw4vwruTyLnVD8O7S94+hh+0hv/yoaPynt6tVXodTRyzkVucGl/wR9z
WO+lpd56a6P/9eh9v3e195DrJuRcgNzPgIPD+J3wIXnSkaMW9t7E/XXcb+O9
LHj0d+5j+H0B95l8F8f6ziDPZ8jRGv4ZxPN5PG+OvJ8ip+xbHnu/Bv9cRp8l
6HcaeP0CXDUEZw083DnxfS1w2Yp5ZM8xyHEFvYxm3leQ4wTzvML8l5i/6hue
31Rl3HDmexK/aYocb3k41/j2NngdwTwZ8MHvfn4Ixfd8/LwMPCRczAEnCfBV
qscfoXjliFffcd3K80W814v1nGN9igcrsGNl5SnYsxL2HIX/b+T5GeLeh/gn
cdFae3az91nvQPj/N/BTjvG+YbwD8GESPDgFuQ8Gnt9G/rCCOKN49il5SCgO
44/j4I8icHAR3oOnbCi4eQcc1ffsFvLbs1xfRV/7wEUX7Hcn60xhPsWx9cix
D/+sjr/u4P5vxhWuleflBvwuCf3ILxfx+1rs9Cv36NGVRa9dWdcy8HczeKzt
4dbdB14rgN8GPK/E/Q38Lr9CL6464+X58wQXRZ7QFP/qjV/9hJ3O41890d/n
4OFR4ugXxOk08jrw6qp4OHDkXUYe53JZbzh6qcm6l4Ov+fzeAnwMAB9zkScT
P9vCdTvX8eC3J3ius8Wz48fI2w0834vdN4PLHl4cN+VjtcHXPuLrnx7uTPHh
MvgYyzx7iH85xL9yra5dTXFrIvFhBfGLekA4NXBqDZh3PXg/wLw3guv+2LM5
+W0kvLKCeLgfvonmOfcuEz4iTpvi9J/e1c7zncabwfvDuYbzvBJx9ib4E/xZ
bfKEC+hlAnoag35q+OOlzcAvilj3m/gRfmU1sc9g7DYE3AkPP4IDeMPlYn/x
70r4WPWW4o14sxB8zgeXI+Cruay3LPnD3+ivDfn4XHC+lDzyZGC9o+CRXoH4
l4v8yvdmknds5f1PwMdR4oJwMxs73d/Kn2dVxQ5jsXsp7LMI/3scv+xJfhsb
yOti4IdgXvch/HAn319ivZmsdxnz3YR+/kQ/6MMeQU8jmDccOcnXrDRypjDe
V4wveRcT1ydg1wbK15inNvN+KTn4Pexd7/0JfD8O3BWjZ/ltH9bXjTh/A371
Lfnsizxvgl4OUgecgxd+hC9eYp3TWPcE1nsr+JwEPrPhrbJ+P7VDrOc6nh/D
/9JY1zrw8ib4r40/7EAv4xlf/rCK+VU3pqNf+dk6/K4qfBvP+vaneOv+VPkX
ODkH7/wEXrbAN88F9IZfu0zmWco8Geh/I/4BL7t68IT4I4b5juKfxGkL8+pa
Qx5bAw//Qvwfiz3j4PcB+NHPzD8MeRog3+f41QTyrXb4V1vsPpD1U0fZddi9
ar7HEwnwRCH2vAW9C285xJU47NQb/6eusenwvuqbRPx9Kc/xd4uibi+hHggn
Lh8P3JfivYvE11T4LBt8qk9BXmO52KEfci1A3hrIK36lvrd4eKsB+hiE3Qs9
vLiRvPcq48Ty/vfgUn2lO/DPZOxxA/ZIVl8IvebiXxH0RUayrm/4/QrrW8m4
3zLPzYxPf0m4t/bwyQbyjYXMX5E4FOHZ1SYzflXs/T7rvIl1dwYf38BTcxm/
C+OPwB+nIc/dyAPv2yD0NBo9jXrKl2e4DdgrCzneIw5l8Xt5/KUGfvA3fjAH
f2yEnMOQe7g/b7Zz8N95fz5sL+Nng8CH+DESf1L9Nxm9qW4cgp88hF6Ubzcm
/2yEvMoLVCc2wl/E77+gz3vgqxXwVRi4jiAvLQXe9xP39pGvFLX051djAn7W
DZykMR+8rDzV6D+67qH+paeX41z7oR/1lxYw7hDmob9nvRhPcfcQflqBekF+
+gv6U70UK/36470Nhxfi4MXqxOmD8LDy+EnUO+KtOayzofTM+pewzoeQFxzb
zan+egn+t4bMVxH7NYSnN7L+6axfdexm8qxs8q5VXPsF+t3Sa2nwUQiOqetD
9Rf5kWXDV+Db3Qbe3kXOKuinFuPVRE7ZoSPrHQTOygbykDDyCOV5pQK/C1eT
sMda7LQXHGaTl9UgL5uCXYmvthbeqQh+qRutOniYDC8U0ldoDz/MQ37lT0+z
jgnkBfS1LBp5G9PvqsDz95GfOtAi0U9l/LMu9l4Bf0wAP0XwrvKcmfDSJXDm
0Ptt2ON5eONWjy9CdXpf3svy1+PuIvY+5a/f3R70OhA9Ky5vw1/Yb7FE6sHL
fv+y09Sxbf19YHuT8crw/Xb/PoIL418X9h90fxC77sbOEdRxyqcexh5TwdUP
+N2N+N1s+K4AOYu5xsEH85DvS/xIcjdlnnnwmvL8x+An8mVLZt5F4OEUeWN5
cDwDXKnvWJO4Xhl80D83+unGPpANDuQ1/wTiBP7rCohLL3f04tRP4GSav09r
a1hnBHIdZ94U5JbfsZ9lR8iH1WdVHVjMvA/ASxHgpj3+XnuxhzPqY/cU+FPe
Mlq8Bt7V32vM+x14Lj5OC/RnKnh1hY3AzvRHbC/+mQEuWoIL4UzjpYLjJHBx
G98rXzgGz32LP8mPOnX27yvkofcf8BfxsEPfp8HtYfBDP8I+YL3k+xYN70eS
/0zy5z8h+41j/L7MR/y1Pxj/N/lJL98+kzuJP7JvZdRv1oH1304cVh6dwHsx
5I9b4UHq59D+1V7mkb+34r1E8tkovv8O3H0EHjvgXzHghX1DI09xA9DPR+BA
+yh58NVZ6iD1n9lftVnglrrUUsHDA/76yzagV/Vv1eeVH5zg+1sZ95nA/uhy
xqWv4r4kPipv0/6c+rPq18ZGXdtHvTfGu2axz6p9QFM+qP54D/RwN3FW9d1v
yD2E/DgN+ZORj/zHPYvcmfye5+W5TnksvO0isGc58rtFxM3F+ElD/EZ9uk9Z
Vz3y6XvATTK40X7EcXB5lesu8FqDOKm+wQj0Po5+32z86zLrzOP738G38s5w
8HML8VQ4+pK8JT/QB/oe3m2G3NRdpn3FaejpKvpJ8/cF7J8XPXk7gCfx/xz0
/QF6YN/F2CcKyfNXoO/RBLw/QR4Aj9o09F8Fva/BDpt4HhnYPxSOR5AvpLOO
18BPEnFf9ZP2M5LhM+2zNqDOgd9sP++NBO9J/jpLvGhDwH018o7XwEk59PwZ
ev6M9w5hF+1rlAcPieCgJriYzTj9+b4SfjWPcdjHVB3t9uLX6g9M1P4N/Non
0E+gXnHiT+WR7a75Z0HWPd71XuUjqjuK4N/34DP1IRcTd7aAhyPoLwX9DkC+
5bz3InpVf+5j5FP9+AJyx5LPIp/tFt8jRxviwwziQ1l4X3lZIX6+EF4+wn7n
WfYP1hMfF4Czuuofga81/jrd5RJ3z7zj4f0G4kcWdsgM7FvBZ+4FeO4q94e4
XoTvdB6HvrirAf+yX+fQk8tGb/BdaN/xV/wvHv8rgx507oI4Fep77QGHwlNf
9NMC3Ap/yq/mgqc52FHnM6bi5x8zv+LyHvB1iOvKln47XuJ+uH+f3WZg1wji
heJEQYUh4yvVO37vLuzFvlWoL3ABPc307w+4ePiR+szgTXeR+Mr+rn0C/maD
I8mjff8McKf1tQCXOvdzlfhchvl2UleU8Jz9m9B+3pPo/RZ4wwL7oitZZ3Pk
jQ7kCfRp3Xes9yI8PQn/E0+r/lReXIp+z27sSj/cVQRvU8HfAHgnjbjRCFzg
X3YWvzoBrnSO4h2+m8h3VZCXfUKrzDrU539M+S/+Ds6U19u/8LT2r4Qf6iKb
g73EA/PJt3ZyVV9A+xnRyCM8qA4txfziH/JUtxq7RKmOhg9yGJ/60L4J1E/0
U208+FH9VIzc8K72j9wU/Ig+iVuNfuW32u/dgt0+JF8gftmT8MNQ+EH7ntjD
1cF+Y7CLcHjQn+9rXOX5tg87DFWd59/PsdX0W7jaDu7Fo6o3OJ+o8wLuceyq
c3wx/nOGof4y/OhU951UP4x1aF0638E+S+gcgeqX6vjfP/ijzitR7zjt07J/
Gjq3Qv0V8sdm+Gtnf59S515McaMC398HjgbCN83B/Ur6Z7+Sz8cjn84lcJ7L
WpOfqT58Fn+pRV48FXvUx+59wcEe7KV9rXbYawp8oX1V7WNF4gfsy9kF5GJ/
Rfv91pB56U85+MJi/ft97nPk0X78buJtCfE3HXs1Bv+1iB85xDPFW+FG55qi
vPpa/XDXCX084O/zugfgmzrEw0T8KpXxT9CP0PkBnV867D/X4vLoK6QE5FBf
zcC9+o66qm6div8rzv1LXH2M+ZSP/+rPG3QeMbQPM5LvpzEe+wyqP9zP8EdX
4mVY4B/nQUznjXqQb6g+6AXuK4DvZH8cdBPhu2J/PeMucn8SuxZgZ+Vb12FX
nUPeiv4n8vwenmt/kjrF7iCeaL8xfouvnnHPoK8q8JX2QS9gP/UX6M+6ZtQB
jcD3ZvyvCB4o28nfPyL/d/nwxRXeU394K/r4IdBnqkmcyvX37bQvZO+y7kXo
ob36qX7eDvXB09nf+sS/H2obkGcR64DP7Tx89gH6+QL9cX7BdUC/s3geDv53
YDfDDreAK+1nGfEgHb0MRl9rA/upa8DRYPhHdYH20/sil+zIfqnrwvq78R71
Vuj8Mn1k1wjeud7fPxQPuarkRW9x39Tfj3ZR3Cfw+yPISV/bpTJvGX+d7Nai
J9W3idhvM3oqhC8zsAfnZtw29rNHYr968NaBQF9V518S/fmMm4K/5xAPN5EX
1CUfUB04A73/jj04z2lF6n9xpd9t2s8pRl7FJ+3Ds++oc6SWD96VZ0nOTORT
HvQFzwcHzo2I/+b4x3EvEdfFS/R5Q3lwBnzLeVFrgv7FI5epw5aDW353bfEz
4rExnsthnDHgPxq/6OzPi0x/pzAavXJ+zeKIk9pPnI5frKB/cAr+Ub/qCnpV
31Pvj4K3TvO+8s6Wqb7zp6G6pZT2XYlrs+Az9Qffwl774QWdIz2DfdnnVH/G
PQ1uH/THF9ktVOfs8OerIfsP4r0Ef95rE3j+MfZehv6ro//N5FFVAnWO7FQx
UOfoXAZ5pa0hvmZxn+LfX3P0a9wa9JwBX62iP/S1/3yDzru6D8Gr4p14vfwW
X34Y+vuMmbyfxHvqe1OnuM34s/p+DYhfxC39vYfVgmfqgr9J4DIdPnyKdc1n
nZnEoxC/KE/z7/+GzgUorm7C3uKvdPI2/b3Ov15/z7T//bPOVyGHzkEuwV7K
f+BLG+c/N2UZAT1z3jBUTwfrpNL0wcTfylM5T2Y6Px/Be8It++yOPMv+D63w
SZg=
          "], {
           Polygon[CompressedData["
1:eJwl0E8on3EcB/Dnp19kchgiJYVf/iyTNnOyljiRVv6UPye/Ka1m0+zg9jtt
hHYyUSKRQnEgN1ktHBw4bAfaZWsnJ8q/kvF6cnj1fj+f7/fb8zzfgviH5vdJ
QRDEiFLNE9KY5U0kCDLlK5lOJdkORPmnF8pT+cWev7KMAz7SZvaaPY64NfvB
N71FlspreckFVyRTY/6SFH1Qrsg/spc6vUtuskQnB+xTaq2JE1I5NpsjoU+x
qJ+xrk+yEb6DZHIoDv+XOBkM0GrfPiXhN1Bu1s+WXkBCz+UZN/zkF8+tVTGt
v4083G2Fu6rXdxkjj+/m72Qf2+EehhjmKVnOZPKYDKp4wai1Ebqdi9NAI/nU
MsGd9e3wHcwwyw7j5p/lJ3pY49zsNx36VxY4DO+eR3oay/oqaxR5jtHJf8/z
tHMPIv5E6g==
            "]], 
           Polygon[CompressedData["
1:eJxFlWlsVlUQhs+5tUorWKqgbC1lE5VUEJACdUFRFpcqNYomqGhckGrrD9lK
SwISFY2ymbj+UBNETTBW6laXxI2AESJu4IKQGJGgQNREiSbq82bepEmfzMw7
597vnJk5t0NubmlsLlJKi6EUduWU7oevYAKJVSli6RNgENrn9qUNIO4PZ+Pv
hp1QRjyT507SeuxsaIAW6A0nor8AFfgZezf0hT5QhzYZ6lPE0sfxvrHwHf65
cDW0wFOsqXB8HPkPiQc4x19aAtUwCubBdLjevrQ7YQOMgfFeq2eegMetKTca
zuKFf2IbsTNgLPwM++FUfntkEfo21myFe/FXwgrXSXW8DgYWUTOdTef5Fv6D
f1UP9G+wh6HAPwH62SpWXauKyB/JUeMy51Rj1boXXAIlcA/UwGDrgxxLXwjn
qx7ukfqywLrymokhcJF7d5f7qPeOcyy9zHGJ52eSfe3hUrjDumZhO+zI8XLN
ylzPjOLvsXugZw5fmtbeijtfc4XdrP3jV+bo48UwDcrd040p+j7P2jD3dLz7
eR7MgCc1H7z/V+whzRGMIa4tIqd4pnM90XoVEUuvLmKt4hrslBQz28c9HIY2
HCa6FqWuwXwY7j2Ve989YL2OynPvYz+Afvij4Rr70t5MER8gvsHPKLcG+xg0
5ahRpe+E5r8Zeug8xJd59jXvTXA5nGyruBFGsHZgijva4L73tdUcDNUZrWXf
3RWa8xRFX+7Z17wfxX6R4o5Vu+bN/v1Z/r0mx9L38sxPKWq5A37Q9wF7Gns6
vYic1igvX9rX7sWxRdxD3T3dzdIi7qZi3ckLWf8RPEP8oGoGq+HZ3D2D78BV
Kb5dn2Jvk4atwtbnmLnN7pNqvy5FH95V3XLE0tWPSq9vxV+bok761m3U9wJ/
v+tWYf8XGAkLyS/wHrXX53PUULX8SzWBN2wVv0b+Iaj1N0bfmt/RN+TuZ446
fjXH+ht1N7C3w8f4c2E2fhtMhiria7Fn5rBV/r1a5yfl7j1U+eyqwfYUdVOt
9D3a6XqekeN7tQzbAXPQWrGf5LhT5bA6xT3SffosR/+nWFNulHX5hzRXOZ47
HqZaU24f+pc58tKmun8ToXeOvda7VyOsqUc1rrlqPxRWwQPer/Z9AWuWYNth
GvxN/Ap04k/P4Xek6IVq3Ol63+d8p3XN2AHWnYOtc33k/wG/6b3WZf/JUTut
qXPdHsWeAptgkWu4DbbCS96r/LfVI3jduuyPKc6xzJq+D/o/2R/eS/GtWOM6
6OxH0J7D7sG+hX0aGvSbKfbS4Xp05diX8i86bvdaWdVtV4rnpC3HtmsfUEJ8
DDyCfxOshDbocnxLirzWKbcPlnpmNbsHU8zxHM11jli6/CtyvKfN6x6G3bAF
riS3F7spxW93WVdez83KsWaLc62uv2q+GJbCy7De8SL3pM1nOOy9HvQZddbB
OXTl/wepPQrv
            "]], 
           Polygon[CompressedData["
1:eJwt1FdsTlEcAPAPpbX3FtKham8P9nwxQihBE4lakdgEbyRirxA72lqpoEGs
ELGLBxIiSIwXO0aiNjF//8TDL/9xzr3n3O/e86Xmzhw+o3QikWhHOSaUSiS2
iJu5In9NTXmySVXklelFb67o3xEbGUsRy/OGt3TRuyc+4ynLzF1Kmn4qU/V2
qvMokZejiEMs1FtAdypRkRY0/7/HZHqYV5Vh8qH8lv/iI+14HnvX/yp+57r8
h/iNL3zmQdyHBtRnEXP1k/kR19JenscB+SnO0lld3zMslmfJb4hN1LWoQW0a
MkY/SaxDXTJIpwzHXbfPeCHbY39s46S6hjiLEvkHTsR7oSmZ1KUeuXSjK3Ni
73Et1elgjY5kuk+z2CM3mW1sBynGzqvPxVrqLhSQT0JvSTwnL+LdmFuWUfKB
5DLZ2BSe8JRi+jLJWGP+yo+KR5jIPfUadsvX05OODGYID41dErPEEeIt2lqz
DUl6s9Vz+CS/IBZQhzVcI9O8l2I18YI50+XjeMJlWuutoJU8O75R+S9+xm8V
75lm1HR9ezqxSl3W3OqxD3kVpqkvxveot1zMoZ/e1jg39KEvu2ItUuWLWcRu
9Sv2y0+TH/diA80ZaSybv/F70NIaxeJV5rGZlaTFN2zefLGQR/LHfI41XTNe
bxDv1KvjPeoNUPePs0pDlrLJ2DpxLXt4r94b32WcQ/kxDpMR50msIHYih7GM
1ivibpxR9UbOx1kSz4gH4/+BMerb4n3S45uI88otxrIn1uUP/wA8zYmv
            "]], 
           Polygon[CompressedData["
1:eJw11HnQVlMYAPD3fkqllFYpJn3RJuqLolBGEwaNahTZRUWREmmmEKk0I8rW
QouKoiJrNZYSppJEKrRIi0LRykwbfs/c44/fPM8557n3nvcsb93u93XuW1Qo
FK6gDGuzQmEkq9nFj1RSsC3l0fc7HbiaPfzJyWpq0Ey+P8a8qwM1aMJUZlKP
M+hPP8pTgTaMZwKTmcIM3vWufeJemtKMV1PNhNQXY/3UZRTYy6R4r/n8Id/N
cO0RnK2vhKpUow4ZE9W0LMrroj5LY920R1FXXszWLF+LWJOK1GSQ8V70pC0D
eZCHON74L+obirO0TxJ3aO/kYo5SgR7GKopljHcRV/KivjvEE7N8LGq+FquK
v4m/0jXWQLyEtpTy/HEckF8UNVHL9vSd+N6x2Et9B8VNbOQJhjGWxSzigJr9
fMgKVnGMC4ydxkfyU32rpbxFltdFX095Wf7hX67Vty/L5xRzq0c5fa3iXVSm
Ct2pyc1Zvo6xnpfSQH19btFfnQvTM/Fsb+rrO9f43fKrWKK9hQZZPtY7nbc4
d2XpSCX9L4kTac8h7aXiNWk86i5jNd/Gd4z3YTRP0+3/M2/sTPF+sTXnx3e0
O0V/7B8DCvl41HUWG9OSFhTH2SLuYCNqUZvqVKOE5pzCUZaxnMd8fwCPyo/E
eZMP5C/54Zi7/HOKmc0cWtGaIWxVs4UvUl3UX84I2vN87Id4O01Mbp3YqCg/
x3GeDxm/S7xV7CqWjt8m/q09SbyO6zmHcbTj9TRWQvP4biGfx5BUP04+hrHc
qH1e7CttmJbWvk+qi75nGEMd7dPTuYkzci/3xJ1J6xXrtosd7CzkZzzOekla
4+K0F8N4PM4bU42/wlPy0WxmA69l+e+O3/9BzDPOqPZN9Mry+x33fLP8Jxpr
L9ZeRLl0L+J+fKW9kk/l68UucUbk/TnC4Sy/M3F3PhY/ifvFMpYzlLrMZBZV
eF/tc+KbLIhnY+84i+9YE99lRax/UZ5H389Ro71e3EBT+arY79Qf4+28u7z8
BPl2+bb4/fL5PEt55vG2/nnpDMZZPMhb+mt5tjbVeTjOL0PjXBfl5yfO0W0M
ZnfcY31XZvnaxx6sZQ1zmMsP9DB+JxvT3sQeddTuRA2mMDmtRazJ3LizsQe+
2TfWtJDPfX5a21jjzwr5f2n8py6QL4w5xvxZyAs8wHBqx5nm5TS2Se10cY/4
pDgq1U9PY1/yPev4hhn6bxAbZvlaxJqUit8kTmO8fCmDGZTlext7/B5L4uzw
DrN5I8015hxrXIXKlI77wSOFfN3/A4gA9d4=
            "]], 
           Polygon[CompressedData["
1:eJwt0ktIUEEUBuBbmKZpCEGKliFlqKUWKRSUoCRaCWFtoqw0auFCJSIiXZQb
i4xAsCIoSEsjsDRbCGKLCowEpQfoKgl0YRAFVmpEj2+gxcf5z8x9zJ25mSca
DzQsjaIoleWs0CSQRCJ3jN0mXy7grJxMI+mksYudnOPrkiiq5CDX9TcYk1ex
Rx5Wa/jAd34wzydzs/yUy9SjlFPJnLFFFnigv0snPdynm/OYjnII31PPNuL/
f1sKseSZ3EIGE27YrBZRyFaKXZNIHBvJoooGKthLEutYGfYlPJMXnrUvvFt9
qr7lHX08ZoDnnDHfwnt5kB1yL7HEMcLusAe0MkA3c679xjhv9JvC2rmsv0Su
tU/pb5JPHm08Mdev/g1noc6GveYl2WFN6pj6jGPEUGcs0/NSWUuu/hen2c5v
1/zhsHyEdrkp/BdyCRmcoor9HKeaUm5xgYu8ZpQmmnnFalLoYIiHpLOGq0x7
zwwb5PVMyJPh/MO71Vqu8YheDnGPLk7SzEe+hDN0zzKuyG185h9G4loD
            "]]}, 
          Method -> {
           "EliminateUnusedCoordinates" -> True, "DeleteDuplicateCoordinates" -> 
            Automatic, "DeleteDuplicateCells" -> Automatic, "VertexAlias" -> 
            Identity, "CheckOrientation" -> Automatic, "CoplanarityTolerance" -> 
            Automatic, "CheckIntersections" -> Automatic, 
            "BoundaryNesting" -> {{0, 0}}, "SeparateBoundaries" -> False, 
            "TJunction" -> Automatic, "PropagateMarkers" -> True, "ZeroTest" -> 
            Automatic, "Hash" -> 6399374178024339959}]]}, 
      TagBox[
       GraphicsComplex3DBox[CompressedData["
1:eJxdm3mcT+UXxwcZsxi7wdhNKUUSqV4tT9nak6W0/VQqIUpSUYpIxDCWkiJR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        "], {
         Directive[{
           Hue[0.6, 0.3, 0.85], 
           EdgeForm[{
             Hue[0.6, 0.3, 0.75]}]}], {
          TagBox[
           
           Polygon3DBox[{{54, 42, 11, 159}, {355, 19, 319, 269}, {304, 534, 
             516, 484}, {546, 496, 134, 482}, {297, 463, 370, 85}, {79, 199, 
             217, 509}, {451, 149, 339, 40}, {504, 502, 501, 503}, {262, 60, 
             61, 263}, {120, 427, 225, 103}, {323, 91, 182, 169}, {90, 207, 
             203, 296}, {333, 490, 265, 218}, {161, 383, 409, 166}, {241, 435,
              408, 180}, {7, 6, 23, 38}, {99, 98, 18, 115}, {340, 459, 295, 
             481}, {44, 112, 445, 289}, {127, 25, 50, 251}, {212, 213, 307, 
             308}, {156, 361, 4, 558}, {324, 454, 396, 284}, {192, 364, 365, 
             191}, {46, 135, 136, 45}, {532, 531, 529, 530}, {564, 565, 139, 
             138}, {353, 354, 330, 331}, {286, 321, 406, 255}, {447, 448, 414,
              415}, {453, 148, 389, 372}, {356, 431, 244, 220}, {345, 398, 
             420, 208}, {171, 266, 267, 170}, {174, 175, 291, 292}, {346, 254,
              163, 88}, {471, 391, 469, 566, 137}, {391, 471, 310, 540, 
             466}, {310, 471, 538, 537, 309}, {472, 465, 521, 73, 275}, {28, 
             87, 78, 111, 16}, {274, 424, 15, 257, 368}, {277, 276, 55, 58, 
             59}, {276, 277, 563, 562, 475}, {317, 341, 367, 155, 271}, {341, 
             519, 195, 282, 367}, {1, 121, 30, 43, 104}, {71, 93, 104, 43, 
             108}, {165, 48, 52, 30, 121}, {153, 152, 52, 48, 47}, {305, 246, 
             338, 328, 306}, {487, 486, 550, 551, 328}, {201, 200, 387, 388, 
             386}, {471, 137, 89, 539, 538}, {276, 475, 474, 511, 510}, {527, 
             473, 494, 514, 526}, {536, 526, 514, 521, 541}, {494, 495, 73, 
             521, 514}, {87, 28, 13, 74, 3}, {116, 32, 31, 13, 28}, {32, 116, 
             118, 63, 349}, {28, 16, 117, 118, 116}, {2, 33, 68, 78, 109}, {
             87, 3, 51, 109, 78}, {9, 51, 3, 5, 57}, {3, 74, 75, 105, 5}, {
             275, 461, 462, 512, 472}, {352, 472, 512, 476, 477}, {268, 476, 
             512, 462, 101}, {362, 209, 179, 288, 273}, {93, 69, 70, 10, 
             104}, {167, 1, 104, 10, 35}, {30, 52, 152, 62, 72}, {410, 513, 
             492, 493, 411}, {560, 557, 410, 411, 329}, {493, 524, 525, 329, 
             411}, {542, 560, 329, 544, 64}, {55, 276, 510, 547, 548}, {56, 
             57, 5, 105, 106}, {36, 35, 10, 70, 8}, {147, 258, 193, 194, 
             280}, {303, 86, 280, 194, 184}, {86, 488, 94, 147, 280}, {144, 
             151, 363, 362, 273}, {155, 367, 366, 520, 154}, {76, 71, 108, 
             107, 77}, {22, 77, 107, 82, 549}, {27, 111, 78, 68, 21}, {68, 33,
              34, 20, 21}, {257, 15, 130, 131, 256}, {385, 201, 386, 248, 
             211}, {43, 30, 72, 110, 108}, {81, 82, 107, 108, 110}, {479, 229,
              64, 206, 478}, {168, 552, 553, 229, 479}, {64, 229, 553, 470, 
             542}, {518, 487, 328, 338, 517}, {306, 328, 551, 66, 196}, {416, 
             394, 400, 399, 417}, {472, 352, 444, 83, 465}, {204, 358, 188, 
             285, 315}, {288, 179, 258, 147, 146}, {94, 189, 293, 146, 147}, {
             144, 273, 288, 122, 145}, {15, 424, 423, 231, 230}, {130, 15, 
             230, 235, 39}, {374, 373, 394, 416, 422}, {211, 248, 247, 222, 
             183}, {222, 247, 437, 395, 301}, {386, 388, 242, 421, 248}, {247,
              248, 421, 434, 437}, {95, 360, 359, 197, 96}, {343, 380, 314, 
             29, 344}, {302, 344, 29, 222, 301}, {314, 313, 183, 222, 29}, {
             293, 189, 205, 204, 315}, {521, 465, 83, 298, 541}, {382, 433, 
             92, 378, 458}, {525, 522, 143, 544, 329}, {464, 206, 64, 544, 
             143}, {299, 464, 143, 237, 467}, {522, 523, 67, 237, 143}, {480, 
             468, 467, 237, 67}, {285, 312, 272, 293, 315}, {146, 293, 272, 
             122, 288}, {394, 373, 290, 393, 392}, {433, 382, 65, 377, 381}, {
             326, 250, 176, 436, 327}, {176, 177, 395, 437, 436}, {434, 390, 
             327, 436, 437}, {444, 232, 316, 311, 83}, {316, 499, 497, 506, 
             311}, {506, 507, 298, 83, 311}, {92, 404, 279, 429, 375}, {458, 
             457, 456, 426, 382}, {456, 443, 439, 438, 426}, {438, 227, 65, 
             382, 426}, {367, 282, 281, 190, 366}, {400, 394, 392, 239, 
             418}, {221, 441, 412, 334, 202}, {92, 433, 381, 442, 404}, {412, 
             425, 442, 381, 334}, {381, 377, 215, 202, 334}, {129, 125, 126, 
             259, 260}, {142, 97, 132, 124, 186}, {97, 100, 260, 259, 132}, {
             224, 123, 96, 197, 234}, {359, 348, 351, 234, 197}, {351, 335, 
             186, 124, 234}, {141, 216, 198, 336, 223}, {173, 142, 186, 198, 
             216}, {335, 337, 336, 198, 186}, {378, 92, 375, 376, 379}, {430, 
             403, 376, 375, 429}, {124, 132, 238, 224, 234}, {259, 126, 287, 
             238, 132}, {355, 150, 149, 451, 489, 19}, {519, 270, 269, 319, 
             320, 195}, {466, 540, 264, 265, 490, 491}, {566, 469, 483, 482, 
             134, 133}, {546, 545, 361, 156, 157, 496}, {262, 428, 427, 120, 
             119, 60}, {12, 11, 42, 41, 6, 7}, {317, 271, 80, 79, 509, 508}, {
             498, 304, 484, 233, 502, 504}, {199, 505, 503, 501, 500, 217}, {
             61, 26, 25, 127, 371, 263}, {249, 246, 305, 413, 169, 182}, {187,
              309, 537, 128, 296, 203}, {543, 532, 530, 533, 539, 89}, {516, 
             534, 535, 548, 547, 515}, {435, 164, 166, 409, 455, 408}, {181, 
             274, 368, 240, 241, 180}, {99, 37, 38, 23, 24, 98}, {59, 58, 114,
              115, 18, 17}, {562, 563, 294, 295, 459, 460}, {113, 154, 520, 
             446, 445, 112}, {54, 159, 158, 256, 131, 53}, {485, 518, 517, 
             342, 330, 354}, {102, 103, 225, 226, 196, 66}, {357, 286, 255, 
             432, 431, 356}, {213, 140, 417, 399, 318, 307}, {332, 333, 218, 
             449, 40, 339}, {463, 559, 558, 4, 369, 370}, {243, 447, 415, 278,
              396, 454}, {550, 486, 528, 191, 365, 350}, {481, 450, 45, 136, 
             300, 340}, {235, 252, 251, 50, 49, 39}, {531, 561, 564, 138, 261,
              529}, {46, 14, 364, 192, 554, 135}, {91, 323, 407, 406, 321, 
             322}, {160, 44, 289, 384, 383, 161}, {231, 423, 440, 414, 448, 
             401}, {297, 85, 84, 511, 474, 555}, {452, 453, 372, 405, 393, 
             290}, {245, 374, 422, 219, 220, 244}, {556, 353, 331, 236, 139, 
             565}, {325, 324, 284, 283, 389, 148}, {398, 397, 418, 239, 419, 
             420}, {171, 178, 174, 292, 228, 266}, {308, 347, 346, 88, 172, 
             212}, {267, 402, 190, 281, 185, 170}, {210, 345, 208, 214, 291, 
             175}, {253, 207, 90, 162, 163, 254}, {469, 391, 466, 491, 473, 
             527, 483}, {473, 491, 490, 333, 332, 495, 494}, {535, 534, 304, 
             498, 76, 77, 22}, {44, 160, 167, 35, 36, 113, 112}, {11, 12, 62, 
             152, 153, 158, 159}, {164, 435, 241, 240, 47, 48, 165}, {158, 
             153, 47, 240, 368, 257, 256}, {496, 157, 524, 493, 492, 133, 
             134}, {557, 561, 531, 532, 543, 513, 410}, {566, 133, 492, 513, 
             543, 89, 137}, {545, 546, 482, 483, 527, 526, 536}, {120, 103, 
             102, 63, 118, 117, 119}, {518, 485, 552, 168, 528, 486, 487}, {
             317, 508, 268, 101, 270, 519, 341}, {461, 150, 355, 269, 270, 
             101, 462}, {19, 489, 488, 86, 303, 320, 319}, {516, 515, 499, 
             316, 232, 233, 484}, {268, 508, 509, 217, 500, 477, 476}, {388, 
             387, 401, 448, 447, 243, 242}, {187, 203, 207, 253, 312, 285, 
             188}, {540, 310, 309, 187, 188, 358, 264}, {510, 511, 84, 497, 
             499, 515, 547}, {9, 57, 56, 17, 18, 98, 24}, {349, 63, 102, 66, 
             551, 550, 350}, {277, 59, 17, 56, 106, 294, 563}, {105, 75, 450, 
             481, 295, 294, 106}, {113, 36, 8, 80, 271, 155, 154}, {69, 505, 
             199, 79, 80, 8, 70}, {210, 209, 362, 363, 397, 398, 345}, {535, 
             22, 549, 114, 58, 55, 548}, {81, 37, 99, 115, 114, 549, 82}, {42,
              54, 53, 34, 33, 2, 41}, {26, 27, 21, 20, 49, 50, 25}, {252, 200,
              201, 385, 371, 127, 251}, {373, 374, 245, 250, 326, 452, 290}, {
             427, 428, 313, 314, 380, 226, 225}, {453, 452, 326, 327, 390, 
             325, 148}, {354, 353, 556, 470, 553, 552, 485}, {249, 360, 95, 
             342, 517, 338, 246}, {413, 343, 344, 302, 407, 323, 169}, {413, 
             305, 306, 196, 226, 380, 343}, {151, 144, 145, 347, 308, 307, 
             318}, {418, 397, 363, 151, 318, 399, 400}, {31, 32, 349, 350, 
             365, 364, 14}, {200, 252, 235, 230, 231, 401, 387}, {49, 20, 34, 
             53, 131, 130, 39}, {416, 417, 140, 141, 223, 219, 422}, {360, 
             249, 182, 91, 322, 348, 359}, {528, 168, 479, 478, 554, 192, 
             191}, {265, 264, 358, 204, 205, 449, 218}, {85, 370, 369, 507, 
             506, 497, 84}, {445, 446, 443, 456, 457, 384, 289}, {423, 424, 
             274, 181, 403, 430, 440}, {340, 300, 299, 467, 468, 460, 459}, {
             562, 460, 468, 480, 555, 474, 475}, {559, 463, 297, 555, 480, 67,
              523}, {266, 228, 227, 438, 439, 402, 267}, {432, 177, 176, 250, 
             245, 244, 431}, {538, 539, 533, 125, 129, 128, 537}, {342, 95, 
             96, 123, 236, 331, 330}, {141, 140, 213, 212, 172, 173, 216}, {
             357, 356, 220, 219, 223, 336, 337}, {278, 415, 414, 440, 430, 
             429, 279}, {520, 366, 190, 402, 439, 443, 446}, {195, 320, 303, 
             184, 185, 281, 282}, {441, 405, 372, 389, 283, 425, 412}, {441, 
             221, 419, 239, 392, 393, 405}, {419, 221, 202, 215, 214, 208, 
             420}, {90, 296, 128, 129, 260, 100, 162}, {408, 455, 379, 376, 
             403, 181, 180}, {194, 193, 178, 171, 170, 185, 184}, {533, 530, 
             529, 261, 287, 126, 125}, {523, 522, 525, 524, 157, 156, 558, 
             559}, {117, 16, 111, 27, 26, 61, 60, 119}, {495, 332, 339, 149, 
             150, 461, 275, 73}, {444, 352, 477, 500, 501, 502, 233, 232}, {
             505, 69, 93, 71, 76, 498, 504, 503}, {167, 160, 161, 166, 164, 
             165, 121, 1}, {41, 2, 109, 51, 9, 24, 23, 6}, {557, 560, 542, 
             470, 556, 565, 564, 561}, {62, 12, 7, 38, 37, 81, 110, 72}, {74, 
             13, 31, 14, 46, 45, 450, 75}, {258, 179, 209, 210, 175, 174, 178,
              193}, {371, 385, 211, 183, 313, 428, 262, 263}, {454, 324, 325, 
             390, 434, 421, 242, 243}, {206, 464, 299, 300, 136, 135, 554, 
             478}, {407, 302, 301, 395, 177, 432, 255, 406}, {488, 489, 451, 
             40, 449, 205, 189, 94}, {4, 361, 545, 536, 541, 298, 507, 369}, {
             312, 253, 254, 346, 347, 145, 122, 272}, {321, 286, 357, 337, 
             335, 351, 348, 322}, {409, 383, 384, 457, 458, 378, 379, 455}, {
             278, 279, 404, 442, 425, 283, 284, 396}, {227, 228, 292, 291, 
             214, 215, 377, 65}, {97, 142, 173, 172, 88, 163, 162, 100}, {123,
              224, 238, 287, 261, 138, 139, 236}}], 
           Annotation[#, "Geometry"]& ]}}], 
       MouseAppearanceTag["LinkHand"]], AllowKernelInitialization -> False], 
     "MeshGraphics3D", {
     AutoDelete -> True, Editable -> False, Selectable -> False}], {
    Boxed -> False, Lighting -> {{"Ambient", 
        GrayLevel[0.45]}, {"Directional", 
        GrayLevel[0.3], 
        ImageScaled[{2, 0, 2}]}, {"Directional", 
        GrayLevel[0.33], 
        ImageScaled[{2, 2, 2}]}, {"Directional", 
        GrayLevel[0.3], 
        ImageScaled[{0, 2, 2}]}}, Method -> {"ShrinkWrap" -> True}, 
     DefaultBaseStyle -> {
      "MeshGraphics3D", FrontEnd`GraphicsHighlightColor -> 
       Hue[0.1, 1, 0.7]}}]},
  "RowWithSeparator"]], "Output",
 CellChangeTimes->{3.861775577454393*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"5e5fd0d3-f54d-449f-86c3-a2848045ef28"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Export STL", "Section",
 CellChangeTimes->{{3.855643352804229*^9, 3.85564335386801*^9}, {
  3.855660681951285*^9, 
  3.855660682797426*^9}},ExpressionUUID->"ffa4724d-8f28-4936-85e9-\
6a2bc6fc2652"],

Cell["\<\
Before exporting, it\[CloseCurlyQuote]s generally a good idea to inspect your \
mesh to be sure the face polygons are oriented properly. The input below will \
color the outside of each face yellow and the inside black.\
\>", "Text",
 CellChangeTimes->{{3.855998056030302*^9, 3.855998159150853*^9}, {
  3.856072326337165*^9, 
  3.856072327167309*^9}},ExpressionUUID->"343bd9bd-e255-4446-a0d8-\
74da3073829d"],

Cell[BoxData[
 RowBox[{"HighlightMesh", "[", 
  RowBox[{"jb", ",", 
   RowBox[{"Style", "[", 
    RowBox[{"2", ",", 
     RowBox[{"FaceForm", "[", 
      RowBox[{"Yellow", ",", "Black"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.855998006362956*^9, 3.855998026168641*^9}},
 CellLabel->
  "In[147]:=",ExpressionUUID->"38c4237a-ef7b-4d3f-986d-5fb6ceafa97e"],

Cell["If you see any black faces, you can fix it:", "Text",
 CellChangeTimes->{{3.855998189719489*^9, 
  3.855998199765563*^9}},ExpressionUUID->"797e46a1-ae6c-4429-ba08-\
32f4af3d0982"],

Cell[BoxData[
 RowBox[{"jb", "=", 
  RowBox[{"RepairMesh", "[", 
   RowBox[{"jb", ",", " ", "\"\<FlippedFaces\>\""}], "]"}]}]], "Input",
 CellChangeTimes->{{3.855998166050911*^9, 3.8559981660548487`*^9}, {
  3.855998202582109*^9, 
  3.855998203357706*^9}},ExpressionUUID->"f1616829-6592-447a-b840-\
7c15964437f5"],

Cell[TextData[{
 "Finally, the input below will generate an STL file  for the MeshRegion \
named jb (like the examples above), and place it in the same directory as \
this notebook. It\[CloseCurlyQuote]s a good idea to set the \
\[OpenCurlyDoubleQuote]radius\[CloseCurlyDoubleQuote] value ",
 Cell[BoxData[
  FormBox["r", TraditionalForm]],ExpressionUUID->
  "7017542b-2c00-4635-bcb4-c682bc8f29c4"],
 " to the desired value in millimeters when you create jb, before exporting. \
Then your STL file will not need to be scaled later. Note that the origin in \
the STL file will be at the center of the jig."
}], "Text",
 CellChangeTimes->{{3.855643619991727*^9, 3.855643717168779*^9}, {
  3.855660539579392*^9, 3.855660596075564*^9}, {3.855660710346464*^9, 
  3.855660717562644*^9}, {3.855828023565133*^9, 3.855828088929427*^9}, {
  3.8617769537684813`*^9, 
  3.8617769557423143`*^9}},ExpressionUUID->"9ca98709-aea0-4c6f-8f2c-\
eec0e23938e3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{"\"\<jigBody.stl\>\"", ",", "jb"}], "]"}]}], "Input",
 CellChangeTimes->{{3.855643426647112*^9, 3.855643462806397*^9}},
 CellLabel->
  "(Debug) In[881]:=",ExpressionUUID->"34f1a4b9-c860-4d26-ae1e-a7a9ec7d9ce3"],

Cell[CellGroupData[{

Cell["Extracting the raw data", "Subsection",
 CellChangeTimes->{{3.855656877449575*^9, 3.855656933532887*^9}, {
  3.8556583819740973`*^9, 
  3.855658389620018*^9}},ExpressionUUID->"538a5840-5fe4-425c-82f2-\
54c8ea0cf670"],

Cell["\<\
Vertices for the polygonal jig body jb (Coordinates are machine numbers):\
\>", "Text",
 CellChangeTimes->{{3.855656946868128*^9, 3.855657003657501*^9}, {
  3.855658395971572*^9, 
  3.8556584074274483`*^9}},ExpressionUUID->"996f4f35-bcd3-41cd-985f-\
edf5c70f9038"],

Cell[BoxData[
 RowBox[{"MeshCoordinates", "[", "jb", "]"}]], "Input",
 CellChangeTimes->{{3.8556569395663013`*^9, 3.855656942780748*^9}},
 CellLabel->
  "In[906]:=",ExpressionUUID->"e54cf492-4502-4a79-80a5-a0d1cf7dab3d"],

Cell["\<\
Faces can be specified by the indices of their vertices in the list above.\
\>", "Text",
 CellChangeTimes->{{3.855657032221203*^9, 
  3.855657056852919*^9}},ExpressionUUID->"5f9d8497-b138-4b95-a20d-\
72bc704e260e"],

Cell[BoxData[
 RowBox[{"MeshCells", "[", 
  RowBox[{"jb", ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.855657018358842*^9, 3.8556570238774776`*^9}},
 CellLabel->
  "In[907]:=",ExpressionUUID->"afe5bdf7-9728-4925-81c0-5dc1d1747100"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MeshCells", "[", 
   RowBox[{"jb", ",", "2"}], "]"}], "/.", 
  RowBox[{
   RowBox[{"Polygon", "[", "x_", "]"}], ":>", "x"}]}]], "Input",
 CellChangeTimes->{{3.855657018358842*^9, 3.8556570238774776`*^9}, {
  3.8556570652313843`*^9, 3.855657077940641*^9}},
 CellLabel->
  "In[908]:=",ExpressionUUID->"ce3597ee-1396-4400-9166-dd9e2c9d7310"],

Cell["\<\
And the drill-hole axes, of course, are specified by the generators used to \
construct jb. Depending on the CAD software you use to fashion your exported \
jig body, you could use Mathematica to create and export meshes for cylinders \
around each axis, then use these to bore the holes in your model. For \
instance:\
\>", "Text",
 CellChangeTimes->{{3.855657102537888*^9, 3.8556571131875153`*^9}, {
  3.8556571665697393`*^9, 3.855657198582502*^9}, {3.855658431338149*^9, 
  3.855658459269717*^9}, {3.855828104368878*^9, 3.855828110632943*^9}, {
  3.856072387086637*^9, 3.856072502538414*^9}, {3.856072927776513*^9, 
  3.856072928089045*^9}, {3.856072982353368*^9, 3.856072983137579*^9}, {
  3.8560730466980543`*^9, 
  3.856073047522318*^9}},ExpressionUUID->"c7f1342b-1598-4b57-ab2f-\
9f2ad9072259"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"star", "=", 
   RowBox[{"Normalize", "/@", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"r", "=", "15"}], ";", 
  RowBox[{
   RowBox[{
    RowBox[{"DiscretizeRegion", "[", 
     RowBox[{"Cylinder", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"#", ",", 
         RowBox[{"-", "#"}]}], "}"}], ",", "2.5"}], "]"}], "]"}], "&"}], "/@", 
   RowBox[{"(", 
    RowBox[{"r", "*", "star"}], ")"}], 
   RowBox[{"(*", " ", 
    RowBox[{"5", "mm", " ", "cylinder", " ", "diameter"}], " ", 
    "*)"}]}]}]}], "Input",
 CellChangeTimes->{{3.8560725233070183`*^9, 3.856072678980057*^9}, {
  3.856072738644717*^9, 3.8560727741719418`*^9}, {3.856072808613361*^9, 
  3.856072843262801*^9}, {3.856072901359123*^9, 3.856072911812231*^9}, {
  3.861683660074382*^9, 3.861683674369966*^9}, {3.8616837369244432`*^9, 
  3.8616837735305367`*^9}},ExpressionUUID->"785120ef-e413-428b-937a-\
cdbff30f2140"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{979, 759},
WindowMargins->{{Automatic, 154}, {Automatic, 0}},
FrontEndVersion->"13.0 for Mac OS X x86 (64-bit) (February 4, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"901ef7e0-2846-4a0a-a765-93b9c5b19ae9"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 159, 3, 98, "Title",ExpressionUUID->"9956dd7b-78bc-4fa9-bd3f-f48c57d3d15b"],
Cell[742, 27, 444, 10, 58, "Text",ExpressionUUID->"0458f607-d3b7-418e-b84f-6224dae5cc8d"],
Cell[CellGroupData[{
Cell[1211, 41, 215, 4, 67, "Section",ExpressionUUID->"c7f204ba-eccb-485e-9b15-1e3da8ab36bb"],
Cell[1429, 47, 518, 11, 35, "Text",ExpressionUUID->"3b1f2b7b-1af8-4646-9ae0-32d481c9853a"],
Cell[1950, 60, 657, 15, 81, "Text",ExpressionUUID->"549307b2-bd09-4b0e-819e-3546b8c493d4"],
Cell[2610, 77, 500, 9, 81, "Text",ExpressionUUID->"d467f942-8fcb-4c4e-a034-dafe5fa97b0f"],
Cell[3113, 88, 1768, 38, 143, "Input",ExpressionUUID->"7de1543b-eefc-42a4-b64c-703ae7209bea",
 InitializationCell->True],
Cell[4884, 128, 5133, 114, 278, "Input",ExpressionUUID->"e8fc1517-70ab-4b4d-8f8d-634895a8ee22",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[10042, 246, 330, 5, 54, "Subsection",ExpressionUUID->"94cac2de-3900-4605-adf0-d8d5ae3e3ec9"],
Cell[CellGroupData[{
Cell[10397, 255, 165, 3, 45, "Subsubsection",ExpressionUUID->"278c524f-b2f5-4c25-a92e-fb4b5144bba0"],
Cell[10565, 260, 1835, 52, 81, "Text",ExpressionUUID->"173139c0-98d7-48c3-aab0-212cd3d3e679"],
Cell[12403, 314, 1441, 37, 58, "Text",ExpressionUUID->"b03bcc8e-ea4c-4c7d-ac4b-3eeb3be4db3d"],
Cell[13847, 353, 3717, 98, 104, "Text",ExpressionUUID->"4bf057ad-0581-4671-b9ca-3ac1d6daa0b0"],
Cell[17567, 453, 4433, 114, 127, "Text",ExpressionUUID->"5a82032e-6151-4101-b1b2-a426394b01c5"],
Cell[CellGroupData[{
Cell[22025, 571, 6786, 167, 748, "Input",ExpressionUUID->"377d0458-7232-47b7-86e2-56a702d5e384"],
Cell[28814, 740, 2140, 48, 469, "Output",ExpressionUUID->"f151aaf0-cc98-48d8-b6c0-dd0a142d984c"]
}, {2}]],
Cell[30966, 791, 2689, 81, 104, "Text",ExpressionUUID->"862b712b-d73c-4898-83ce-009779d9f18f"],
Cell[33658, 874, 2279, 72, 80, "Text",ExpressionUUID->"991fb734-5623-44cc-aebb-346b8f859818"],
Cell[35940, 948, 583, 16, 46, "Text",ExpressionUUID->"75646237-2b85-4e6b-a67c-b9e7a7add96e"],
Cell[36526, 966, 917, 29, 46, "Text",ExpressionUUID->"a310fc98-3456-4257-bdf0-421ef5d438bb"],
Cell[37446, 997, 937, 31, 43, "Text",ExpressionUUID->"0dde4d8e-410e-4dfa-b356-0d8837a3ebcf"],
Cell[38386, 1030, 1261, 42, 35, "Text",ExpressionUUID->"1c05b340-befd-47ed-a590-3079079fa3f8"],
Cell[CellGroupData[{
Cell[39672, 1076, 1263, 35, 115, "Input",ExpressionUUID->"0e137e64-bab0-45ee-9e33-9638fe7c34d8"],
Cell[40938, 1113, 233, 4, 34, "Output",ExpressionUUID->"d457b07e-8f24-4c3a-8a72-30e77ff7c74c"]
}, Open  ]],
Cell[41186, 1120, 2469, 83, 45, "Text",ExpressionUUID->"95e94bcc-2d98-49e3-9ab5-e7ed8aec85a2"]
}, Closed]],
Cell[CellGroupData[{
Cell[43692, 1208, 157, 3, 37, "Subsubsection",ExpressionUUID->"127c5efd-fe1d-4def-9196-841a8e966791"],
Cell[43852, 1213, 2000, 43, 150, "Text",ExpressionUUID->"e21f978d-aa10-4823-bfd3-7354370e2d60"],
Cell[45855, 1258, 1556, 26, 127, "Text",ExpressionUUID->"eb305c61-1b21-4054-8fac-0490471e18ce"],
Cell[47414, 1286, 1072, 22, 81, "Text",ExpressionUUID->"698cbbb0-4dd6-4b93-93a1-27a89128f3ae"],
Cell[48489, 1310, 1741, 31, 81, "Text",ExpressionUUID->"d6deb725-8e0c-4a59-851c-ad4bd165ed2c"],
Cell[50233, 1343, 1835, 34, 173, "Text",ExpressionUUID->"bd91a53e-5e5e-40a0-9148-d9b776ae561e"],
Cell[52071, 1379, 702, 13, 58, "Text",ExpressionUUID->"2287bfc1-0222-4b53-a0b6-107198563f10"],
Cell[52776, 1394, 925, 20, 81, "Text",ExpressionUUID->"2ebc7348-8a33-4530-a91d-3e097351e07c"],
Cell[53704, 1416, 982, 20, 81, "Text",ExpressionUUID->"853dab33-00c2-401e-99e7-a0a8b9f2582a"],
Cell[54689, 1438, 619, 14, 35, "Text",ExpressionUUID->"eef161d0-c1e7-43b8-a19c-acd77dde6664"],
Cell[55311, 1454, 496, 9, 58, "Text",ExpressionUUID->"83def9d8-ce7f-424d-a263-530dbc65c77b"],
Cell[55810, 1465, 2087, 61, 81, "Text",ExpressionUUID->"e8767919-5b58-499a-8059-9a24702ada02"],
Cell[57900, 1528, 2896, 88, 58, "Text",ExpressionUUID->"9679140f-5767-46f5-b937-4b821b1bd8c2"],
Cell[60799, 1618, 2205, 62, 58, "Text",ExpressionUUID->"44e94d11-136a-443e-8123-2720624ffa02"],
Cell[63007, 1682, 4432, 122, 127, "Text",ExpressionUUID->"84f4964e-6c0f-48af-9c96-7872928851a4"]
}, Closed]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[67500, 1811, 157, 3, 53, "Section",ExpressionUUID->"bd02c5f7-b037-456f-8f41-92ba2f41fb7d"],
Cell[CellGroupData[{
Cell[67682, 1818, 464, 8, 54, "Subsection",ExpressionUUID->"4068db0d-c743-4553-9557-5d3b430e75e8"],
Cell[68149, 1828, 272, 4, 35, "Text",ExpressionUUID->"c7e13241-642b-4922-b877-3610e2015f5e"],
Cell[68424, 1834, 1096, 29, 30, "Input",ExpressionUUID->"bad8573e-6548-482b-914d-5d520ecd6f58"],
Cell[69523, 1865, 183, 3, 35, "Text",ExpressionUUID->"82cffc53-821a-46a6-9507-48146cba3251"],
Cell[CellGroupData[{
Cell[69731, 1872, 237, 5, 30, "Input",ExpressionUUID->"9abe7fcf-c668-4665-a690-3c8ee4d834ca"],
Cell[69971, 1879, 2614, 57, 365, "Output",ExpressionUUID->"b2b191c8-9680-472a-9c80-c967bfae92d0"]
}, Open  ]],
Cell[72600, 1939, 548, 10, 58, "Text",ExpressionUUID->"65342108-dc23-4f95-aec0-74b797cdd485"],
Cell[CellGroupData[{
Cell[73173, 1953, 1549, 40, 73, "Input",ExpressionUUID->"690de0fc-b734-42d1-8adf-4400a9d45baa"],
Cell[74725, 1995, 1374, 32, 364, "Output",ExpressionUUID->"e38104dc-7e8a-45be-a9e9-df854eebccaa"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[76148, 2033, 253, 4, 54, "Subsection",ExpressionUUID->"e9fb95c3-6c33-48f5-8978-6392df9f5862"],
Cell[76404, 2039, 267, 6, 35, "Text",ExpressionUUID->"7beeed32-8a08-47e0-ab83-f2e5b74b02cc"],
Cell[76674, 2047, 294, 5, 41, "Input",ExpressionUUID->"a8fae508-e035-4f91-b013-0567274c0042"],
Cell[CellGroupData[{
Cell[76993, 2056, 944, 17, 52, "Input",ExpressionUUID->"6d431e4e-5376-478e-9b65-718b2c731460"],
Cell[77940, 2075, 663, 10, 34, "Output",ExpressionUUID->"ebe1bcd1-0c4a-4d6f-9b7f-1f1f90ef3bf5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78640, 2090, 1499, 39, 73, "Input",ExpressionUUID->"86cf3e00-3d0c-46a7-9f57-fd021c002721"],
Cell[80142, 2131, 2351, 47, 372, "Output",ExpressionUUID->"5b2cdc4c-867b-4c68-8329-f27b52097c9a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[82530, 2183, 963, 17, 52, "Input",ExpressionUUID->"a9ea7ed5-1b89-4a59-95e4-b11a11449d3e"],
Cell[83496, 2202, 685, 10, 34, "Output",ExpressionUUID->"fd556048-381f-4bf9-84a8-a2008204b000"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84218, 2217, 1499, 39, 73, "Input",ExpressionUUID->"da6c4b14-9a49-433b-b9ce-33fae269aec5"],
Cell[85720, 2258, 1554, 35, 384, "Output",ExpressionUUID->"5bc1a26f-4356-4377-8dd5-97ed9a71621a"]
}, Open  ]],
Cell[87289, 2296, 272, 6, 35, "Text",ExpressionUUID->"24441d7e-0b62-4492-8c72-1899dab17f50"],
Cell[87564, 2304, 355, 7, 35, "Text",ExpressionUUID->"b7df3bbd-d2ca-424b-86d2-b6537acbbd9d"],
Cell[CellGroupData[{
Cell[87944, 2315, 1316, 24, 73, "Input",ExpressionUUID->"f8440ec4-95c3-4b38-b0c1-4403e85ee8f6"],
Cell[89263, 2341, 302, 6, 34, "Output",ExpressionUUID->"83410ec0-8f0d-416f-8fc2-5cc47a4cbc56"]
}, Open  ]],
Cell[CellGroupData[{
Cell[89602, 2352, 1500, 39, 73, "Input",ExpressionUUID->"4a428e7f-11bd-434a-81c1-8cba436c6cbb"],
Cell[91105, 2393, 3279, 61, 381, "Output",ExpressionUUID->"8dd0abf1-b8df-4fec-bd7e-9e69b9563660"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[94433, 2460, 244, 4, 38, "Subsection",ExpressionUUID->"084d98e7-18db-487f-910d-98c2513ad9d7"],
Cell[94680, 2466, 192, 3, 35, "Text",ExpressionUUID->"709193f6-44be-4834-9208-dea35d91d514"],
Cell[CellGroupData[{
Cell[94897, 2473, 954, 17, 52, "Input",ExpressionUUID->"b31b4a7e-f2f7-434f-b2e9-169dd2b90cea"],
Cell[95854, 2492, 664, 10, 34, "Output",ExpressionUUID->"e62025ba-182f-4032-9758-a284d141ac32"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96555, 2507, 1453, 39, 73, "Input",ExpressionUUID->"fd9901f3-0965-4027-b1a4-a94273185bc5"],
Cell[98011, 2548, 1166, 27, 348, "Output",ExpressionUUID->"bf5fa9bc-7909-4673-8e2e-7cfe59d9a137"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99214, 2580, 1012, 18, 52, "Input",ExpressionUUID->"2f4da7e9-0807-4ed0-a887-569e85521de4"],
Cell[100229, 2600, 662, 10, 34, "Output",ExpressionUUID->"f3506a7c-75e7-433f-b030-fe8c4b508754"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100928, 2615, 1453, 39, 73, "Input",ExpressionUUID->"e6ac2073-4ca5-47cd-90eb-bc82cb180941"],
Cell[102384, 2656, 1223, 27, 409, "Output",ExpressionUUID->"d87d96a7-9d6b-4275-89af-93827da53337"]
}, Open  ]],
Cell[103622, 2686, 215, 5, 35, "Text",ExpressionUUID->"96ddf636-b6b2-4603-98ca-9edcb7fe93c9"],
Cell[CellGroupData[{
Cell[103862, 2695, 1187, 23, 52, "Input",ExpressionUUID->"8bf06040-3834-4215-87ca-c272ef6a7b83"],
Cell[105052, 2720, 244, 4, 34, "Output",ExpressionUUID->"21c41045-8966-4917-a3d0-7fff745aca5c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[105333, 2729, 1453, 39, 73, "Input",ExpressionUUID->"1219a96f-8130-401b-90c4-bd1718679c03"],
Cell[106789, 2770, 1594, 35, 372, "Output",ExpressionUUID->"09f63991-06ae-4a6f-8166-b646739dbf3a"]
}, Open  ]],
Cell[108398, 2808, 602, 12, 58, "Text",ExpressionUUID->"9bead9ef-7512-4630-bf8a-ab4972fe0e75"],
Cell[CellGroupData[{
Cell[109025, 2824, 1191, 30, 136, "Input",ExpressionUUID->"f5613b32-29d2-4bb1-be31-fe372f6225c4"],
Cell[110219, 2856, 35888, 597, 390, 2737, 52, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"bd737829-c0a0-41d3-8755-24e8be669adf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146144, 3458, 1626, 28, 115, "Input",ExpressionUUID->"b3faf77a-a80d-4db8-bdb4-c293fbe1187f"],
Cell[147773, 3488, 427, 7, 34, "Output",ExpressionUUID->"e93c88c9-7703-408f-a398-dafbf6e1bd41"]
}, Open  ]],
Cell[CellGroupData[{
Cell[148237, 3500, 1453, 39, 73, "Input",ExpressionUUID->"72ec1ef8-5b25-4a5e-98e6-42a98aea6f8c"],
Cell[149693, 3541, 2075, 42, 394, "Output",ExpressionUUID->"4a26652c-48e2-4b62-a28e-b5ddf14cc719"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[151817, 3589, 325, 5, 38, "Subsection",ExpressionUUID->"6d5476fd-948a-42e4-bf30-1080646e8da4"],
Cell[152145, 3596, 1153, 24, 58, "Text",ExpressionUUID->"27fe1def-337a-4df2-a6a1-e2cb491fdfe2"],
Cell[CellGroupData[{
Cell[153323, 3624, 1423, 30, 73, "Input",ExpressionUUID->"40dad83e-841f-4939-af08-09f209e4f3a7"],
Cell[154749, 3656, 2756, 77, 119, "Output",ExpressionUUID->"1fd09c71-9174-490f-a4f7-016318b506d3"]
}, Open  ]],
Cell[157520, 3736, 244, 4, 35, "Text",ExpressionUUID->"f7d345f8-a358-4dce-9d98-5a8c41aa49e3"],
Cell[CellGroupData[{
Cell[157789, 3744, 1500, 36, 94, "Input",ExpressionUUID->"da3302a2-f98d-4ce2-851b-30db897e14d0"],
Cell[159292, 3782, 37755, 632, 503, 3929, 77, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"bacb5e75-d661-42f9-9428-c08848b3026d"]
}, Open  ]],
Cell[197062, 4417, 498, 12, 35, "Text",ExpressionUUID->"b7807275-ecaa-455f-b98c-8b334fc58e1e"],
Cell[CellGroupData[{
Cell[197585, 4433, 1453, 39, 73, "Input",ExpressionUUID->"2de384de-80e9-4da9-a1a5-591b493e4f88"],
Cell[199041, 4474, 1959, 41, 386, "Output",ExpressionUUID->"b9b7a764-b236-4807-bb20-10e51cf78434"]
}, Open  ]],
Cell[201015, 4518, 714, 15, 58, "Text",ExpressionUUID->"4e00401a-5e9a-4562-943b-79d33ed26589"],
Cell[CellGroupData[{
Cell[201754, 4537, 1634, 44, 73, "Input",ExpressionUUID->"45acb777-f267-46b2-b153-58d5f56531a2"],
Cell[203391, 4583, 2073, 43, 299, "Output",ExpressionUUID->"38f8feaf-4b2b-4578-8241-2d2779585b1d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[205513, 4632, 277, 4, 38, "Subsection",ExpressionUUID->"84e45d3a-35a4-4b8f-acc4-8e43cb93be1a"],
Cell[205793, 4638, 302, 7, 58, "Text",ExpressionUUID->"c050039b-8c8e-4deb-bd1f-29c7cd73c159"],
Cell[206098, 4647, 633, 11, 58, "Text",ExpressionUUID->"48317514-2203-4be3-9fc7-661dfb3e686f"],
Cell[206734, 4660, 955, 26, 52, "Input",ExpressionUUID->"4b9a56fd-de5c-4b8e-bf39-148df89c7ec9"],
Cell[CellGroupData[{
Cell[207714, 4690, 1453, 39, 73, "Input",ExpressionUUID->"6e24f4a0-10bd-4fe4-9d0e-a8cbb6d4eb49"],
Cell[209170, 4731, 1850, 39, 314, "Output",ExpressionUUID->"8d3bedcf-827f-42d4-9285-17127c083ce8"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[211069, 4776, 482, 7, 38, "Subsection",ExpressionUUID->"32cc2d0f-b344-4612-aeed-e50a05b8740f"],
Cell[211554, 4785, 672, 14, 58, "Text",ExpressionUUID->"b9010852-8f49-4532-b8d8-7765c40186f0"],
Cell[CellGroupData[{
Cell[212251, 4803, 447, 8, 30, "Input",ExpressionUUID->"e8881cb5-6a9d-495c-a889-8de52a485350"],
Cell[212701, 4813, 15522, 241, 408, "Output",ExpressionUUID->"6813a4c2-ec2e-4e1a-8816-16d02adec554"]
}, Open  ]],
Cell[CellGroupData[{
Cell[228260, 5059, 1044, 19, 52, "Input",ExpressionUUID->"e2f2e1fe-03a1-4377-994a-07496ae1c512"],
Cell[229307, 5080, 920, 14, 34, "Output",ExpressionUUID->"1e9c310b-701b-43e6-97d1-751a27104080"]
}, Open  ]],
Cell[CellGroupData[{
Cell[230264, 5099, 1453, 39, 73, "Input",ExpressionUUID->"ff8b7ab4-cb0d-4c91-ae8a-b7ff4e612aa4"],
Cell[231720, 5140, 3881, 67, 376, "Output",ExpressionUUID->"c337ef07-8cf2-4df4-87cf-b775fd08e823"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[235650, 5213, 396, 6, 38, "Subsection",ExpressionUUID->"0ecbbea7-c5bd-4afa-b153-55280eb87520"],
Cell[236049, 5221, 558, 10, 58, "Text",ExpressionUUID->"9372f7ac-331c-4cb0-943f-f236d4547d6b"],
Cell[CellGroupData[{
Cell[236632, 5235, 312, 5, 41, "Input",ExpressionUUID->"9238f037-4f55-45f8-97b4-b50f7acdd771"],
Cell[236947, 5242, 4967, 94, 391, "Output",ExpressionUUID->"5b46702b-8b0c-4834-82f5-3616c26d6ed1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[241951, 5341, 902, 17, 52, "Input",ExpressionUUID->"cde00149-9ef2-456b-b89f-8995fad854f1"],
Cell[242856, 5360, 318, 5, 34, "Output",ExpressionUUID->"43594329-613a-4c25-b923-24ac359a6564"]
}, Open  ]],
Cell[CellGroupData[{
Cell[243211, 5370, 1453, 39, 73, "Input",ExpressionUUID->"c6027f2c-0ab6-4fb7-8020-9bd292696e81"],
Cell[244667, 5411, 1492, 35, 368, "Output",ExpressionUUID->"66c5260e-c8b9-4ef3-8b36-a3229f79031b"]
}, Open  ]],
Cell[246174, 5449, 653, 13, 81, "Text",ExpressionUUID->"91adfd7a-b0ad-4c2e-9593-d3ed60d7d77b"],
Cell[CellGroupData[{
Cell[246852, 5466, 937, 17, 52, "Input",ExpressionUUID->"5ab6fd36-6eee-4d99-9d50-2e1301fa87fd"],
Cell[247792, 5485, 301, 6, 34, "Output",ExpressionUUID->"c2c0d7e5-38e8-44c4-a9ff-88e826ce985d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[248130, 5496, 1453, 39, 73, "Input",ExpressionUUID->"6df14cb0-76e3-4d0f-a134-f1a864783ad2"],
Cell[249586, 5537, 2055, 40, 379, "Output",ExpressionUUID->"ded9ca47-6477-4112-aac4-28deca0b776c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[251678, 5582, 937, 17, 52, "Input",ExpressionUUID->"665a55d3-3b90-47c4-9428-297b1ddf8f3d"],
Cell[252618, 5601, 320, 6, 34, "Output",ExpressionUUID->"d1569a51-5fcb-431f-83f2-709b404e5b93"]
}, Open  ]],
Cell[252953, 5610, 339, 7, 35, "Text",ExpressionUUID->"5b4bf6be-e6f5-4cf9-8b53-998727c23f01"],
Cell[CellGroupData[{
Cell[253317, 5621, 1453, 39, 73, "Input",ExpressionUUID->"9316d609-01aa-4788-be59-7b695d8af143"],
Cell[254773, 5662, 1892, 41, 372, "Output",ExpressionUUID->"85fb46a6-7e83-4407-ac4e-1c3b895a7ef3"]
}, Open  ]],
Cell[256680, 5706, 328, 7, 35, "Text",ExpressionUUID->"9aa9b228-c702-4a8f-b1c5-19d21418300c"],
Cell[CellGroupData[{
Cell[257033, 5717, 937, 17, 52, "Input",ExpressionUUID->"3b94d8f7-54bf-47fb-9cd7-3fc3e88bb79d"],
Cell[257973, 5736, 321, 6, 34, "Output",ExpressionUUID->"cee9b8db-4812-41e8-af38-82600ae8446e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[258331, 5747, 1453, 39, 73, "Input",ExpressionUUID->"d0206a15-04a8-496a-891d-c919da5afc2e"],
Cell[259787, 5788, 2381, 46, 379, "Output",ExpressionUUID->"e886fec8-86df-470c-8c37-a0c38b7cd05d"]
}, Open  ]],
Cell[262183, 5837, 428, 8, 58, "Text",ExpressionUUID->"881ea734-3049-4248-9c8a-f1382121742d"],
Cell[CellGroupData[{
Cell[262636, 5849, 3120, 59, 220, "Input",ExpressionUUID->"f867a64b-dbb9-4589-81bd-2cc36c96fd0a"],
Cell[265759, 5910, 76380, 1247, 109, "Output",ExpressionUUID->"5e5fd0d3-f54d-449f-86c3-a2848045ef28"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[342200, 7164, 203, 4, 67, "Section",ExpressionUUID->"ffa4724d-8f28-4936-85e9-6a2bc6fc2652"],
Cell[342406, 7170, 418, 8, 58, "Text",ExpressionUUID->"343bd9bd-e255-4446-a0d8-74da3073829d"],
Cell[342827, 7180, 371, 9, 30, "Input",ExpressionUUID->"38c4237a-ef7b-4d3f-986d-5fb6ceafa97e"],
Cell[343201, 7191, 185, 3, 35, "Text",ExpressionUUID->"797e46a1-ae6c-4429-ba08-32f4af3d0982"],
Cell[343389, 7196, 313, 7, 30, "Input",ExpressionUUID->"f1616829-6592-447a-b840-7c15964437f5"],
Cell[343705, 7205, 940, 17, 81, "Text",ExpressionUUID->"9ca98709-aea0-4c6f-8f2c-eec0e23938e3"],
Cell[344648, 7224, 387, 9, 63, "Input",ExpressionUUID->"34f1a4b9-c860-4d26-ae1e-a7a9ec7d9ce3"],
Cell[CellGroupData[{
Cell[345060, 7237, 222, 4, 54, "Subsection",ExpressionUUID->"538a5840-5fe4-425c-82f2-54c8ea0cf670"],
Cell[345285, 7243, 274, 6, 35, "Text",ExpressionUUID->"996f4f35-bcd3-41cd-985f-edf5c70f9038"],
Cell[345562, 7251, 220, 4, 30, "Input",ExpressionUUID->"e54cf492-4502-4a79-80a5-a0d1cf7dab3d"],
Cell[345785, 7257, 224, 5, 35, "Text",ExpressionUUID->"5f9d8497-b138-4b95-a20d-72bc704e260e"],
Cell[346012, 7264, 237, 5, 30, "Input",ExpressionUUID->"afe5bdf7-9728-4925-81c0-5dc1d1747100"],
Cell[346252, 7271, 373, 9, 30, "Input",ExpressionUUID->"ce3597ee-1396-4400-9166-dd9e2c9d7310"],
Cell[346628, 7282, 811, 14, 81, "Text",ExpressionUUID->"c7f1342b-1598-4b57-ab2f-9f2ad9072259"],
Cell[347442, 7298, 1597, 45, 73, "Input",ExpressionUUID->"785120ef-e413-428b-937a-cdbff30f2140"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

